@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2007-2008 Kim Woelders
+ * Copyright (C) 2007-2010 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -21,22 +21,23 @@
  * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
-#include "dox.h"
-
+#include "config.h"
+#ifdef HAVE_LOCALE_H
+#include <locale.h>
+#endif
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <unistd.h>
 #include <X11/Xlib.h>
-#include <X11/Xutil.h>
-#include <X11/Xosdefs.h>
 #include <X11/Xproto.h>
-#include <X11/keysym.h>
+#include <X11/Xutil.h>
 #include <X11/Xatom.h>
-
 #ifdef USE_XINERAMA
 #include <X11/extensions/Xinerama.h>
 #endif
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
+#include <X11/keysym.h>
+#include "dox.h"
 
 #define EDOX_DEFAULT_W  512
 #define EDOX_DEFAULT_H  400
@@ -321,34 +322,32 @@ main(int argc, char **argv)
 	else
 	   docdir = strdup(argv[i]);
      }
-   if (docdir == NULL)
+   if (!docdir)
       docdir = strdup(doxdir);
    s = EMALLOC(char, strlen(docdir) + strlen(docfile) + 2 + 20);
 
    if (strstr(docdir, "/ABOUT"))
       show_top_bar = 0;
 
-   sprintf(s, "%s/%s", docdir, docfile);
-   findLocalizedFile(s);
-
-   LoadFile(s, docfile);
-
-   if ((disp = XOpenDisplay(NULL)) == NULL)
-     {
-	printf("%s: Cannot open X display.\n", argv[0]);
-	exit(0);
-     }
-
    /* now we'll set the locale */
    setlocale(LC_ALL, "");
    if (!XSupportsLocale())
       setlocale(LC_ALL, "C");
    XSetLocaleModifiers("");
    setlocale(LC_ALL, NULL);
-
    /* I dont want any internationalisation of my numeric input & output */
    setlocale(LC_NUMERIC, "C");
 
+   sprintf(s, "%s/%s", docdir, docfile);
+
+   LoadFile(s, docfile);
+
+   if (!(disp = XOpenDisplay(NULL)))
+     {
+	printf("%s: Cannot open X display.\n", argv[0]);
+	exit(0);
+     }
+
    VRootInit();
 
    t = (show_top_bar) ? 16 : 0;
@@ -570,7 +569,6 @@ main(int argc, char **argv)
 				 if (exe[0] != '/')
 				   {
 				      sprintf(tmp, "%s/%s", docdir, exe);
-				      findLocalizedFile(tmp);
 				      exe = tmp;
 				   }
 				 p = popen(exe, "r");
