@@ -119,15 +119,16 @@
 
 /* Server extensions */
 #define XEXT_SHAPE       0
-#define XEXT_SYNC        1
-#define XEXT_SCRSAVER    2
-#define XEXT_RANDR       3
-#define XEXT_COMPOSITE   4
-#define XEXT_DAMAGE      5
-#define XEXT_FIXES       6
-#define XEXT_RENDER      7
-#define XEXT_GLX         8
-#define XEXT_XI          9
+#define XEXT_XINERAMA    1
+#define XEXT_SYNC        2
+#define XEXT_SCRSAVER    3
+#define XEXT_RANDR       4
+#define XEXT_COMPOSITE   5
+#define XEXT_DAMAGE      6
+#define XEXT_FIXES       7
+#define XEXT_RENDER      8
+#define XEXT_GLX         9
+#define XEXT_XI         10
 
 #define XEXT_CM_ALL     16
 
@@ -188,6 +189,7 @@ typedef struct {
       char                transientsfollowleader;
       char                switchfortransientmap;
       char                all_new_windows_get_focus;
+      char                new_windows_get_focus_if_group_focused;
       char                new_transients_get_focus;
       char                new_transients_get_focus_if_group_focused;
       char                raise_on_next;
@@ -292,6 +294,7 @@ typedef struct {
       char                warpfocused;
       char                raise_on_select;
       char                warp_on_select;
+      char                show_shape;
       int                 icon_mode;
    } warplist;
 
@@ -323,6 +326,7 @@ typedef struct {
    } backgrounds;
    struct {
       char               *name;
+      char               *prefix;
       char               *dir;
       char               *cache_dir;
    } conf;
@@ -368,7 +372,6 @@ typedef struct {
    struct {
       char                check;	/* Avoid losing windows offscreen */
       char                swap;
-      int                 swapcoord_x, swapcoord_y;
    } move;
    struct {
       signed char         enable_features;
@@ -378,6 +381,9 @@ typedef struct {
    struct {
       int                 w_old;
       int                 h_old;
+#ifdef USE_XRANDR
+      unsigned short      rotation;
+#endif
    } screen;
    struct {
       unsigned int        extensions;
@@ -406,7 +412,7 @@ typedef struct {
       char                exit_now;
       char                save_ok;
       char                coredump;
-      int                 win_w, win_h;
+      int                 win_x, win_y, win_w, win_h;
       int                 exit_mode;
       char               *exit_param;
       int                 child_count;
@@ -422,7 +428,6 @@ typedef struct {
    Win                 context_win;
    char                constrained;
    char                nogroup;
-   char                keybinds_changed;
    char                showing_desktop;
    Window              button_proxy_win;
    char                firsttime;
@@ -445,15 +450,20 @@ void                EspawnCmd(const char *cmd);
 int                 Esystem(const char *cmd);
 
 /* config.c */
+#define FILE_TYPE_CONFIG     0
+#define FILE_TYPE_BACKGROUND 1
+#define FILE_TYPE_IMAGE      1
+#define FILE_TYPE_CURSOR     1
+#define FILE_TYPE_SOUND      1
+#define FILE_TYPE_MENU       2
+#define FILE_TYPE_ICON       3
 void                SkipTillEnd(FILE * ConfigFile);
 char               *GetLine(char *s, int size, FILE * f);
 int                 ConfigParseline1(char *str, char *s2, char **p2, char **p3);
 void                ConfigParseError(const char *where, const char *line);
 void                ConfigAlertLoad(const char *txt);
-char               *FindFile(const char *file, const char *themepath);
-char               *ThemeFileFind(const char *file);
-char               *ConfigFileFind(const char *name, const char *themepath,
-				   int pp);
+char               *FindFile(const char *file, const char *themepath, int type);
+char               *ThemeFileFind(const char *file, int type);
 int                 ConfigFileLoad(const char *name, const char *themepath,
 				   int (*parse) (FILE * fs), int preparse);
 int                 ConfigFileRead(FILE * fs);
@@ -496,12 +506,14 @@ void                SignalsRestore(void);
 
 /* main.c */
 __NORETURN__ void   EExit(int exitcode);
-__EXPORT__ const char *EDirRoot(void);
-const char         *EDirBin(void);
-const char         *EDirUser(void);
-const char         *EDirUserCache(void);
-void                EDirMake(const char *base, const char *name);
-const char         *EGetSavePrefix(void);
+
+#define EDirRoot()       ENLIGHTENMENT_ROOT
+#define EDirBin()        ENLIGHTENMENT_BIN
+#define EDirLib()        ENLIGHTENMENT_LIB
+#define EDirUser()       Mode.conf.dir
+#define EDirUserCache()  Mode.conf.cache_dir
+#define EGetSavePrefix() Mode.conf.prefix
+
 void                Etmp(char *s);
 
 /* misc.c */
