@@ -69,6 +69,7 @@ static Ecore_List  *aclass_list = NULL;
 static Ecore_List  *aclass_list_global = NULL;
 
 static char         mode_action_destroy = 0;
+static char         mode_keybinds_changed = 0;
 
 static void
 RemoveActionType(ActionType * ActionTypeToRemove)
@@ -92,6 +93,8 @@ ActionCreate(char event, char anymod, int mod, int anybut, int but,
    Action             *aa;
 
    aa = EMALLOC(Action, 1);
+   if (!aa)
+      return NULL;
    aa->action = NULL;
    aa->event = event;
    aa->anymodifier = anymod;
@@ -169,6 +172,8 @@ ActionclassCreate(const char *name, int global)
    ActionClass        *ac;
 
    ac = ECALLOC(ActionClass, 1);
+   if (!ac)
+      return NULL;
    ac->name = Estrdup(name);
 
    if (global)
@@ -208,7 +213,7 @@ ActionclassDestroy(ActionClass * ac)
 
    if (ac->ref_count > 0)
      {
-	DialogOK("ActionClass Error!", _("%u references remain\n"),
+	DialogOK("ActionClass Error!", _("%u references remain"),
 		 ac->ref_count);
 	return;
      }
@@ -303,10 +308,11 @@ AclassConfigLoad(FILE * fs)
 	     key[0] = '\0';
 	     break;
 	  case CONFIG_CLOSE:
-	     ac->tooltipstring =
-		(aclass_tooltipstring) ? Estrdup((aclass_tooltipstring[0]) ?
-						 aclass_tooltipstring :
-						 "?!?") : NULL;
+	     if (ac)
+		ac->tooltipstring =
+		   (aclass_tooltipstring) ? Estrdup((aclass_tooltipstring[0]) ?
+						    aclass_tooltipstring :
+						    "?!?") : NULL;
 	     err = 0;
 	     goto done;
 
@@ -316,7 +322,7 @@ AclassConfigLoad(FILE * fs)
 	     if (ac)
 	       {
 		  if (!strcmp(s2, "KEYBINDINGS"))
-		     Mode.keybinds_changed = 1;
+		     mode_keybinds_changed = 1;
 		  ActionclassEmpty(ac);
 	       }
 	     else
@@ -609,7 +615,7 @@ ActionEncode(Action * aa, char *buf, int len)
       *p++ = '5';
    if (p == mod)
       *p++ = '-';
-   *p++ = '\0';
+   *p = '\0';
 
    switch (aa->event)
      {
@@ -721,7 +727,7 @@ AclassConfigLineParse(char *s, ActionClass ** pac, Action ** paa)
 	if (!ac)
 	   ac = ActionclassCreate(prm2, prm3[0] == 'g');
 
-	Mode.keybinds_changed = 1;
+	mode_keybinds_changed = 1;
 	aa = NULL;
      }
    else if (!strncmp(prm1, "Key", 3) || !strncmp(prm1, "Mouse", 5))
@@ -753,7 +759,7 @@ AclassConfigLineParse(char *s, ActionClass ** pac, Action ** paa)
    *paa = aa;
 }
 
-static void
+static int
 AclassConfigLoad2(FILE * fs)
 {
    char                s[FILEPATH_LEN_MAX], *ss;
@@ -768,6 +774,8 @@ AclassConfigLoad2(FILE * fs)
 
 	AclassConfigLineParse(s, &ac, &aa);
      }
+
+   return 0;
 }
 
 static void
@@ -800,21 +808,7 @@ AclassConfigParseIpc(const char *p)
 static void
 AclassConfigLoadConfig(const char *name)
 {
-   char               *file;
-   FILE               *fs;
-
-   file = ConfigFileFind(name, NULL, 0);
-   if (!file)
-      return;
-
-   fs = fopen(file, "r");
-   Efree(file);
-   if (!fs)
-      return;
-
-   AclassConfigLoad2(fs);
-
-   fclose(fs);
+   ConfigFileLoad(name, NULL, AclassConfigLoad2, 0);
 }
 
 static void
@@ -830,7 +824,7 @@ AclassConfigWrite(const ActionClass * ac, void (*prf) (const char *fmt, ...))
    prf("Aclass %s %s\n", ac->name, (ac->global)? "global" : "normal");
    if (ac->tooltipstring)
      {
-	len = AclassEncodeTT(ac->tooltipstring, s, sizeof(s));
+	AclassEncodeTT(ac->tooltipstring, s, sizeof(s));
 	prf(s);
      }
    for (i = 0; i < ac->num; i++)
@@ -842,7 +836,7 @@ AclassConfigWrite(const ActionClass * ac, void (*prf) (const char *fmt, ...))
 	prf(s);
 	if (aa->tooltipstring)
 	  {
-	     len = AclassEncodeTT(aa->tooltipstring, s, sizeof(s));
+	     AclassEncodeTT(aa->tooltipstring, s, sizeof(s));
 	     prf(s);
 	  }
      }
@@ -854,10 +848,9 @@ static void
 _ac_prf(const char *fmt, ...)
 {
    va_list             args;
-   int                 len;
 
    va_start(args, fmt);
-   len = vfprintf(_ac_fs, fmt, args);
+   vfprintf(_ac_fs, fmt, args);
    va_end(args);
 }
 
@@ -867,7 +860,7 @@ BindingsSave(void)
    char                s[FILEPATH_LEN_MAX], ss[FILEPATH_LEN_MAX];
    FILE               *fs;
 
-   if (!Mode.keybinds_changed)
+   if (!mode_keybinds_changed)
       return;
 
    Etmp(ss);
@@ -1336,7 +1329,7 @@ IPC_KeybindingsSet(const char *params)
    if (!ss || !ss[0])
       return;
 
-   Mode.keybinds_changed = 1;
+   mode_keybinds_changed = 1;
 
    ac = ActionclassFindGlobal("KEYBINDINGS");
    if (ac)
@@ -1449,6 +1442,7 @@ static const IpcItem AclassIpcArray[] = {
  * Module descriptor
  */
 extern const EModule ModAclass;
+
 const EModule       ModAclass = {
    "aclass", "ac",
    AclassSighan,
