@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2009 Kim Woelders
+ * Copyright (C) 2004-2010 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -58,9 +58,14 @@ ExecSetupEnv(int flags)
    if (flags & EXEC_SET_STARTUP_ID)
       StartupIdExport();
 
-#if USE_ROOTHACKLIB
+#if USE_LIBHACK
    if (Mode.wm.window)
-      Esetenv("LD_PRELOAD", ENLIGHTENMENT_LIB "/libhack.so");
+     {
+	char                buf[1024];
+
+	Esnprintf(buf, sizeof(buf), "%s/libhack.so", EDirLib());
+	Esetenv("LD_PRELOAD", buf);
+     }
 #endif
 }
 
@@ -186,7 +191,7 @@ Espawn(int argc __UNUSED__, char **argv)
 
    execvp(argv[0], argv);
 
-   AlertOK(_("There was an error running the program:\n%s\n"), argv[0]);
+   AlertOK(_("There was an error running the program:\n%s"), argv[0]);
    exit(100);
 }
 
