@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2008 Kim Woelders
+ * Copyright (C) 2004-2010 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -490,15 +490,15 @@ SnapEwin(EWin * ewin, int dx, int dy, int *new_dx, int *new_dy)
    bottom_bound = top_bound + h;
    screen_snap_dist = Mode.constrained ? (w + h) : Conf.snap.screen_snap_dist;
 
-   lst = NULL;
    lst1 = EwinListOrderGet(&num);
-   if (lst1)
-     {
-	lst = EMALLOC(EWin *, num);
-	if (!lst)
-	   return;
-	memcpy(lst, lst1, num * sizeof(EWin *));
-     }
+   if (!lst1)
+      return;
+
+   lst = EMALLOC(EWin *, num);
+   if (!lst)
+      return;
+   memcpy(lst, lst1, num * sizeof(EWin *));
+
    gwins = ListWinGroupMembersForEwin(ewin, GROUP_ACTION_MOVE, Mode.nogroup
 				      || Mode.move.swap, &gnum);
    if (gwins)
@@ -523,11 +523,11 @@ SnapEwin(EWin * ewin, int dx, int dy, int *new_dx, int *new_dy)
 	  {
 	     dx = left_bound - ewin->shape_x;
 	  }
-	else if (lst)
+	else
 	  {
 	     for (i = 0; i < num; i++)
 	       {
-		  if (lst[i] == NULL)
+		  if (!lst[i])
 		     continue;
 
 		  if ((EoGetDesk(ewin) == EoGetDesk(lst[i]) ||
@@ -562,11 +562,11 @@ SnapEwin(EWin * ewin, int dx, int dy, int *new_dx, int *new_dy)
 	  {
 	     dx = right_bound - (ewin->shape_x + EoGetW(ewin));
 	  }
-	else if (lst)
+	else
 	  {
 	     for (i = 0; i < num; i++)
 	       {
-		  if (lst[i] == NULL)
+		  if (!lst[i])
 		     continue;
 
 		  if ((EoGetDesk(ewin) == EoGetDesk(lst[i]) ||
@@ -599,11 +599,11 @@ SnapEwin(EWin * ewin, int dx, int dy, int *new_dx, int *new_dy)
 	  {
 	     dy = top_bound - ewin->shape_y;
 	  }
-	else if (lst)
+	else
 	  {
 	     for (i = 0; i < num; i++)
 	       {
-		  if (lst[i] == NULL)
+		  if (!lst[i])
 		     continue;
 
 		  if ((EoGetDesk(ewin) == EoGetDesk(lst[i]) ||
@@ -639,11 +639,11 @@ SnapEwin(EWin * ewin, int dx, int dy, int *new_dx, int *new_dy)
 	  {
 	     dy = bottom_bound - (ewin->shape_y + EoGetH(ewin));
 	  }
-	else if (lst)
+	else
 	  {
 	     for (i = 0; i < num; i++)
 	       {
-		  if (lst[i] == NULL)
+		  if (!lst[i])
 		     continue;
 
 		  if ((EoGetDesk(ewin) == EoGetDesk(lst[i]) ||
@@ -724,7 +724,6 @@ ArrangeGetRectList(RectBox ** pfixed, int *nfixed, RectBox ** pfloating,
    fixed = EMALLOC(RectBox, num);
    if (!fixed)
       goto done;
-   rb = fixed;
 
    dsk = (ewin) ? EoGetDesk(ewin) : DesksGetCurrent();
 
@@ -845,14 +844,13 @@ ArrangeGetRectList(RectBox ** pfixed, int *nfixed, RectBox ** pfloating,
 void
 ArrangeEwinXY(EWin * ewin, int *px, int *py)
 {
-   EWin               *const *lst;
    int                 i, num;
    RectBox            *fixed, *ret, newrect;
 
    fixed = NULL;
    ret = NULL;
 
-   lst = EwinListGetAll(&num);
+   EwinListGetAll(&num);
    if (num <= 1)
      {
 	ArrangeEwinCenteredXY(ewin, px, py);
@@ -869,6 +867,8 @@ ArrangeEwinXY(EWin * ewin, int *px, int *py)
    newrect.p = EoGetLayer(ewin);
 
    ret = ECALLOC(RectBox, num + 1);
+   if (!ret)
+      return;
    ArrangeRects(fixed, num, &newrect, 1, ret, 0, 0,
 		WinGetW(VROOT), WinGetH(VROOT), ARRANGE_BY_SIZE, 1);
 
@@ -926,6 +926,8 @@ ArrangeEwins(const char *params)
    ArrangeGetRectList(&fixed, &nfix, &floating, &nflt, NULL);
 
    ret = ECALLOC(RectBox, nflt + nfix);
+   if (!ret)
+      return;
    ArrangeRects(fixed, nfix, floating, nflt, ret, 0, 0,
 		WinGetW(VROOT), WinGetH(VROOT), method, 1);
 
