@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2009 Kim Woelders
+ * Copyright (C) 2004-2010 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -38,7 +38,6 @@
 
 typedef struct {
    char               *file;
-   char               *real_file;
    EImage             *im;
    char                keep_aspect;
    int                 xjust, yjust;
@@ -67,12 +66,45 @@ static unsigned int bg_seq_no = 0;
 #define N_BG_ASSIGNED 32
 static Background  *bg_assigned[N_BG_ASSIGNED];
 
-char               *
-BackgroundGetUniqueString(const Background * bg)
+static char        *
+_BackgroundGetFile(char **ptr)
 {
-   char                s[256];
-   const char         *chmap =
+   char               *path = *ptr;
+
+   if (isabspath(path))
+      goto done;
+
+   path = ThemeFileFind(path, FILE_TYPE_BACKGROUND);
+   if (!path)
+      goto done;
+   Efree(*ptr);
+   *ptr = path;
+ done:
+   return path;
+}
+
+static char        *
+_BackgroundGetBgFile(Background * bg)
+{
+   if (!bg || !bg->bg.file)
+      return NULL;
+   return _BackgroundGetFile(&bg->bg.file);
+}
+
+static char        *
+_BackgroundGetFgFile(Background * bg)
+{
+   if (!bg || !bg->top.file)
+      return NULL;
+   return _BackgroundGetFile(&bg->top.file);
+}
+
+char               *
+BackgroundGetUniqueString(Background * bg)
+{
+   static const char  *chmap =
       "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ-_";
+   char                s[256], *f;
    int                 r, g, b;
    int                 n1, n2, n3, n4, n5, f1, f2, f3, f4, f5, f6;
 
@@ -89,32 +121,22 @@ BackgroundGetUniqueString(const Background * bg)
    f4 = 0;
    f5 = 0;
    f6 = 0;
-   if (bg->bg.file)
-     {
-	char               *f;
 
-	f = ThemeFileFind(bg->bg.file);
-	if (f)
-	  {
-	     f1 = fileinode(f);
-	     f2 = filedev(f);
-	     f3 = (int)moddate(f);
-	     Efree(f);
-	  }
-     }
-   if (bg->top.file)
+   f = _BackgroundGetBgFile(bg);
+   if (f)
      {
-	char               *f;
-
-	f = ThemeFileFind(bg->top.file);
-	if (f)
-	  {
-	     f4 = fileinode(f);
-	     f5 = filedev(f);
-	     f6 = (int)moddate(f);
-	     Efree(f);
-	  }
+	f1 = fileinode(f);
+	f2 = filedev(f);
+	f3 = (int)moddate(f);
      }
+   f = _BackgroundGetFgFile(bg);
+   if (f)
+     {
+	f4 = fileinode(f);
+	f5 = filedev(f);
+	f6 = (int)moddate(f);
+     }
+
    Esnprintf(s, sizeof(s),
 	     "%c%c%c%c%c%c" "%c%c%c%c%c%c" "%c%c%c%c%c%c" "%c%c%c%c%c%c"
 	     "%c%c%c%c%c%c" "%c%c%c%c%c%c" "%c%c%c%c%c%c" "%c%c%c%c%c%c"
@@ -211,15 +233,9 @@ BackgroundFilesRemove(Background * bg)
    Efree(bg->bg.file);
    bg->bg.file = NULL;
 
-   Efree(bg->bg.real_file);
-   bg->bg.real_file = NULL;
-
    Efree(bg->top.file);
    bg->top.file = NULL;
 
-   Efree(bg->top.real_file);
-   bg->top.real_file = NULL;
-
    BackgroundImagesFree(bg);
 
    bg->keepim = 0;
@@ -230,11 +246,12 @@ BackgroundDestroy(Background * bg)
 {
    if (!bg)
       return -1;
-
+#if 0
+   Eprintf("%s: %s\n", __func__, bg->name);
+#endif
    if (bg->ref_count > 0)
      {
-	DialogOK("Background Error!", _("%u references remain\n"),
-		 bg->ref_count);
+	DialogOK("Background Error!", _("%u references remain"), bg->ref_count);
 	return -1;
      }
 
@@ -256,28 +273,23 @@ BackgroundDelete(Background * bg)
 {
    char               *f;
 
-   if (BackgroundDestroy(bg))
+   if (!bg)
+      return;
+#if 0
+   Eprintf("%s: %s\n", __func__, bg->name);
+#endif
+   if (bg->ref_count > 0)
       return;
 
    /* And delete the actual image files */
-   if (bg->bg.file)
-     {
-	f = ThemeFileFind(bg->bg.file);
-	if (f)
-	  {
-	     E_rm(f);
-	     Efree(f);
-	  }
-     }
-   if (bg->top.file)
-     {
-	f = ThemeFileFind(bg->top.file);
-	if (f)
-	  {
-	     E_rm(f);
-	     Efree(f);
-	  }
-     }
+   f = _BackgroundGetBgFile(bg);
+   if (f)
+      E_rm(f);
+   f = _BackgroundGetFgFile(bg);
+   if (f)
+      E_rm(f);
+
+   BackgroundDestroy(bg);
 }
 #endif /* ENABLE_DIALOGS */
 
@@ -329,7 +341,7 @@ BackgroundCreate(const char *name, unsigned int solid, const char *bgn,
 }
 
 static int
-BackgroundCmp(Background * bg, Background * bgx)
+BackgroundCmp(const Background * bg, const Background * bgx)
 {
    if (*bgx->name != '.')	/* Discard only generated backgrounds */
       return 1;
@@ -338,8 +350,9 @@ BackgroundCmp(Background * bg, Background * bgx)
      {
 	if ((strcmp(bg->bg.file, bgx->bg.file)) ||
 	    (bg->bg.keep_aspect != bgx->bg.keep_aspect) ||
-	    (bg->bg.xjust != bgx->bg.xjust || bg->bg.xjust != bgx->bg.xjust) ||
-	    (bg->bg.xperc != bgx->bg.xperc || bg->bg.xperc != bgx->bg.xperc))
+	    (bg->bg.xjust != bgx->bg.xjust) ||
+	    (bg->bg.yjust != bgx->bg.yjust) ||
+	    (bg->bg.xperc != bgx->bg.xperc) || (bg->bg.yperc != bgx->bg.yperc))
 	   return 1;
      }
    else if (bg->bg.file || bgx->bg.file)
@@ -349,10 +362,10 @@ BackgroundCmp(Background * bg, Background * bgx)
      {
 	if ((strcmp(bg->top.file, bgx->top.file)) ||
 	    (bg->top.keep_aspect != bgx->top.keep_aspect) ||
-	    (bg->top.xjust != bgx->top.xjust ||
-	     bg->top.xjust != bgx->top.xjust) ||
-	    (bg->top.xperc != bgx->top.xperc ||
-	     bg->top.xperc != bgx->top.xperc))
+	    (bg->top.xjust != bgx->top.xjust) ||
+	    (bg->top.yjust != bgx->top.yjust) ||
+	    (bg->top.xperc != bgx->top.xperc) ||
+	    (bg->top.yperc != bgx->top.yperc))
 	   return 1;
      }
    else if (bg->top.file || bgx->top.file)
@@ -419,7 +432,7 @@ BackgroundModify(Background * bg, unsigned int solid, const char *bgn,
    else
       updated = 1;
    Efree(bg->bg.file);
-   bg->bg.file = (bgn[0]) ? Estrdup(bgn) : NULL;
+   bg->bg.file = (bgn && bgn[0]) ? Estrdup(bgn) : NULL;
    if ((int)tile != bg->bg_tile)
       updated = 1;
    if ((int)keep_aspect != bg->bg.keep_aspect)
@@ -447,7 +460,7 @@ BackgroundModify(Background * bg, unsigned int solid, const char *bgn,
    else
       updated = 1;
    Efree(bg->top.file);
-   bg->top.file = (top[0]) ? Estrdup(top) : NULL;
+   bg->top.file = (top && top[0]) ? Estrdup(top) : NULL;
    if ((int)tkeep_aspect != bg->top.keep_aspect)
       updated = 1;
    if (txjust != bg->top.xjust)
@@ -545,30 +558,28 @@ BackgroundRealize(Background * bg, Win win, Drawable draw, unsigned int rw,
    GC                  gc;
    int                 x, y, ww, hh;
    unsigned int        w, h;
-   char                hasbg, hasfg;
+   char               *file, hasbg, hasfg;
    EImage             *im;
 
-   if (bg->bg.file && !bg->bg.im)
+   if (!bg->bg.im)
      {
-	if (!bg->bg.real_file)
-	   bg->bg.real_file = ThemeFileFind(bg->bg.file);
-	if (bg->bg.real_file)
-	   bg->bg.im = EImageLoad(bg->bg.real_file);
+	file = _BackgroundGetBgFile(bg);
+	if (file)
+	   bg->bg.im = EImageLoad(file);
      }
 
-   if (bg->top.file && !bg->top.im)
+   if (!bg->top.im)
      {
-	if (!bg->top.real_file)
-	   bg->top.real_file = ThemeFileFind(bg->top.file);
-	if (bg->top.real_file)
-	   bg->top.im = EImageLoad(bg->top.real_file);
+	file = _BackgroundGetFgFile(bg);
+	if (file)
+	   bg->top.im = EImageLoad(bg->top.file);
      }
 
    if (!draw)
       draw = WinGetXwin(win);
 
-   hasbg = bg->bg.im != NULL;
-   hasfg = bg->top.im != NULL;
+   hasbg = ! !bg->bg.im;
+   hasfg = ! !bg->top.im;
 
    if (!hasbg && !hasfg)
      {
@@ -861,7 +872,7 @@ BrackgroundCreateFromImage(const char *bgid, const char *file,
 void
 BackgroundIncRefcount(Background * bg)
 {
-   if (bg == NULL)
+   if (!bg)
       return;
    bg->ref_count++;
 }
@@ -869,7 +880,7 @@ BackgroundIncRefcount(Background * bg)
 void
 BackgroundDecRefcount(Background * bg)
 {
-   if (bg == NULL)
+   if (!bg)
       return;
    bg->ref_count--;
    if (bg->ref_count <= 0)
@@ -879,7 +890,7 @@ BackgroundDecRefcount(Background * bg)
 void
 BackgroundTouch(Background * bg)
 {
-   if (bg == NULL)
+   if (!bg)
       return;
    bg->last_viewed = time(NULL);
 }
@@ -966,15 +977,15 @@ BackgroundGetInfoString1(const Background * bg, char *buf, int len)
    COLOR32_TO_RGB(bg->bg_solid, r, g, b);
    Esnprintf(buf, len,
 	     "%s ref_count %u keepim %u\n"
-	     " bg.solid\t %i %i %i \n"
+	     " bg.solid\t %i %i %i\n"
 	     " bg.file\t %s\n"
-	     " top.file\t %s \n"
-	     " bg.tile\t %i \n"
-	     " bg.keep_aspect\t %i \ttop.keep_aspect\t %i \n"
-	     " bg.xjust\t %i \ttop.xjust\t %i \n"
-	     " bg.yjust\t %i \ttop.yjust\t %i \n"
-	     " bg.xperc\t %i \ttop.xperc\t %i \n"
-	     " bg.yperc\t %i \ttop.yperc\t %i \n", bg->name,
+	     " top.file\t %s\n"
+	     " bg.tile\t %i\n"
+	     " bg.keep_aspect\t %i \ttop.keep_aspect\t %i\n"
+	     " bg.xjust\t %i \ttop.xjust\t %i\n"
+	     " bg.yjust\t %i \ttop.yjust\t %i\n"
+	     " bg.xperc\t %i \ttop.xperc\t %i\n"
+	     " bg.yperc\t %i \ttop.yperc\t %i\n", bg->name,
 	     bg->ref_count, bg->keepim, r, g, b,
 	     bg->bg.file, bg->top.file, bg->bg_tile,
 	     bg->bg.keep_aspect, bg->top.keep_aspect,
@@ -1083,8 +1094,8 @@ BackgroundsConfigLoad(FILE * fs)
 	  {
 	  case CONFIG_CLOSE:
 	     if (!ignore && !bg && name)
-		bg = BackgroundCreate(name, color, bg1, i1, i2, i3, i4, i5,
-				      i6, bg2, j1, j2, j3, j4, j5);
+		BackgroundCreate(name, color, bg1, i1, i2, i3, i4, i5,
+				 i6, bg2, j1, j2, j3, j4, j5);
 	     goto done;
 
 	  case CONFIG_COLORMOD:
@@ -1137,7 +1148,7 @@ BackgroundsConfigLoad(FILE * fs)
 	     r = g = b = 0;
 	     sscanf(s, "%*s %d %d %d", &r, &g, &b);
 	     COLOR32_FROM_RGB(color, r, g, b);
-	     if (ignore)
+	     if (bg && ignore)
 		bg->bg_solid = color;
 	     break;
 
@@ -1149,7 +1160,7 @@ BackgroundsConfigLoad(FILE * fs)
 		  Efree(bg1);
 		  bg1 = Estrdup(s2);
 	       }
-	     else
+	     else if (bg)
 	       {
 		  Efree(bg->bg.file);
 		  Efree(bg->top.file);
@@ -1172,7 +1183,7 @@ BackgroundsConfigLoad(FILE * fs)
 		  Efree(bg2);
 		  bg2 = Estrdup(s2);
 	       }
-	     else
+	     else if (bg)
 	       {
 		  bg->top.file = Estrdup(s2);
 		  bg->top.keep_aspect = j1;
@@ -1232,47 +1243,32 @@ BackgroundsConfigSave(void)
 	if (!bg)
 	   continue;
 
+	/* Get full path to files */
+	_BackgroundGetBgFile(bg);
+	_BackgroundGetFgFile(bg);
+	/* Discard if bg file is given but cannot be found (ignore bad fg) */
+	if (bg->bg.file && !isabspath(bg->bg.file))
+	  {
+	     Eprintf("Discard broken background %s (%s)\n",
+		     bg->name, bg->bg.file);
+	     continue;
+	  }
+
 	fprintf(fs, "5 999\n");
 
 	fprintf(fs, "100 %s\n", bg->name);
 	COLOR32_TO_RGB(bg->bg_solid, r, g, b);
 	fprintf(fs, "560 %d %d %d\n", r, g, b);
 
-	if ((bg->bg.file) && (!bg->bg.real_file))
-	   bg->bg.real_file = ThemeFileFind(bg->bg.file);
+	if (bg->bg.file)
+	   fprintf(fs, "561 %s %d %d %d %d %d %d\n",
+		   bg->bg.file, bg->bg_tile, bg->bg.keep_aspect,
+		   bg->bg.xjust, bg->bg.yjust, bg->bg.xperc, bg->bg.yperc);
 
-	if ((bg->top.file) && (!bg->top.real_file))
-	   bg->top.real_file = ThemeFileFind(bg->top.file);
-
-	if ((bg->bg.file) && (bg->bg.real_file))
-	  {
-	     fprintf(fs, "561 %s %d %d %d %d %d %d\n",
-		     bg->bg.real_file, bg->bg_tile,
-		     bg->bg.keep_aspect, bg->bg.xjust,
-		     bg->bg.yjust, bg->bg.xperc, bg->bg.yperc);
-	  }
-	else if (bg->bg.file)
-	  {
-	     fprintf(fs, "561 %s %d %d %d %d %d %d\n",
-		     bg->bg.file, bg->bg_tile,
-		     bg->bg.keep_aspect, bg->bg.xjust,
-		     bg->bg.yjust, bg->bg.xperc, bg->bg.yperc);
-	  }
-
-	if ((bg->top.file) && (bg->top.real_file))
-	  {
-	     fprintf(fs, "562 %s %d %d %d %d %d\n",
-		     bg->top.real_file,
-		     bg->top.keep_aspect, bg->top.xjust,
-		     bg->top.yjust, bg->top.xperc, bg->top.yperc);
-	  }
-	else if (bg->top.file)
-	  {
-	     fprintf(fs, "562 %s %d %d %d %d %d\n",
-		     bg->top.file, bg->top.keep_aspect,
-		     bg->top.xjust, bg->top.yjust, bg->top.xperc,
-		     bg->top.yperc);
-	  }
+	if (bg->top.file)
+	   fprintf(fs, "562 %s %d %d %d %d %d\n",
+		   bg->top.file, bg->top.keep_aspect,
+		   bg->top.xjust, bg->top.yjust, bg->top.xperc, bg->top.yperc);
 
 	for (j = 0; j < N_BG_ASSIGNED; j++)
 	  {
@@ -1305,7 +1301,7 @@ BackgroundsCheckDups(void)
 	bg = (Background *) ecore_list_next(bg_list);
 	if (!bg)
 	   break;
-	for (; (bgx = (Background *) ecore_list_next(bg_list)) != NULL;)
+	for (; (bgx = (Background *) ecore_list_next(bg_list));)
 	  {
 	     if (bgx->ref_count > 0 || bgx->referenced)
 		continue;
@@ -1361,8 +1357,6 @@ BackgroundsSighan(int sig, void *prm __UNUSED__)
    switch (sig)
      {
      case ESIGNAL_INIT:
-	EDirMake(EDirUserCache(), "cached/bgsel");
-	EDirMake(EDirUserCache(), "cached/img");
 	/* create a fallback background in case no background is found */
 	BackgroundCreate(NULL, 0, NULL, 0, 0, 0, 0, 0, 0, NULL, 0, 0, 0, 0, 0);
 	break;
@@ -1513,7 +1507,7 @@ BG_DialogSetFileName(DItem * di)
 
    stmp = fullfileof(BackgroundGetBgFile(tmp_bg));
    Esnprintf(s, sizeof(s),
-	     _("Background definition information:\nName: %s\nFile: %s\n"),
+	     _("Background definition information:\nName: %s\nFile: %s"),
 	     BackgroundGetName(tmp_bg), (stmp) ? stmp : _("-NONE-"));
    DialogItemSetText(di, s);
 }
@@ -2004,21 +1998,21 @@ _DlgFillBackground(Dialog * d, DItem * table, void *data)
    DialogItemSetAlign(table2, 512, 0);
 
    di = DialogAddItem(table2, DITEM_BUTTON);
-   DialogItemSetText(di, _("Move to Front\n"));
+   DialogItemSetText(di, _("Move to Front"));
    DialogItemSetCallback(di, CB_ConfigureFrontBG, 0, NULL);
    DialogBindKey(d, "F", CB_ConfigureFrontBG, 0, NULL);
 
    di = DialogAddItem(table2, DITEM_BUTTON);
-   DialogItemSetText(di, _("Duplicate\n"));
+   DialogItemSetText(di, _("Duplicate"));
    DialogItemSetCallback(di, CB_ConfigureNewBG, 0, NULL);
 
    di = DialogAddItem(table2, DITEM_BUTTON);
-   DialogItemSetText(di, _("Unlist\n"));
+   DialogItemSetText(di, _("Unlist"));
    DialogItemSetCallback(di, CB_ConfigureDelBG, 0, NULL);
    DialogBindKey(d, "D", CB_ConfigureDelBG, 0, NULL);
 
    di = DialogAddItem(table2, DITEM_BUTTON);
-   DialogItemSetText(di, _("Delete File\n"));
+   DialogItemSetText(di, _("Delete File"));
    DialogItemSetCallback(di, CB_ConfigureDelBG, 1, NULL);
    DialogBindKey(d, "Delete", CB_ConfigureDelBG, 1, NULL);
 
@@ -2035,7 +2029,7 @@ _DlgFillBackground(Dialog * d, DItem * table, void *data)
    table3 = DialogAddItem(table2, DITEM_TABLE);
    DialogItemTableSetOptions(table3, 3, 0, 0, 0);
 
-   di = DialogAddItem(table3, DITEM_NONE);
+   DialogAddItem(table3, DITEM_NONE);
 
    di = tmp_w[6] = DialogAddItem(table3, DITEM_SLIDER);
    DialogItemSliderSetMinLength(di, 10);
@@ -2044,7 +2038,7 @@ _DlgFillBackground(Dialog * d, DItem * table, void *data)
    DialogItemSliderSetJump(di, 64);
    DialogItemSliderSetValPtr(di, &tmp_bg_xjust);
 
-   di = DialogAddItem(table3, DITEM_NONE);
+   DialogAddItem(table3, DITEM_NONE);
 
    di = tmp_w[7] = DialogAddItem(table3, DITEM_SLIDER);
    DialogItemSliderSetMinLength(di, 10);
@@ -2070,7 +2064,7 @@ _DlgFillBackground(Dialog * d, DItem * table, void *data)
    DialogItemSliderSetJump(di, 64);
    DialogItemSliderSetValPtr(di, &tmp_bg_yperc);
 
-   di = DialogAddItem(table3, DITEM_NONE);
+   DialogAddItem(table3, DITEM_NONE);
 
    di = tmp_w[9] = DialogAddItem(table3, DITEM_SLIDER);
    DialogItemSliderSetMinLength(di, 10);
@@ -2086,12 +2080,12 @@ _DlgFillBackground(Dialog * d, DItem * table, void *data)
    DialogItemSetColSpan(di, 2);
    DialogItemSetFill(di, 0, 0);
    DialogItemSetAlign(di, 512, 512);
-   DialogItemSetText(di, _("BG Colour\n"));
+   DialogItemSetText(di, _("BG Colour"));
 
    di = DialogAddItem(table3, DITEM_TEXT);
    DialogItemSetFill(di, 0, 0);
    DialogItemSetAlign(di, 1024, 512);
-   DialogItemSetText(di, _("Red:\n"));
+   DialogItemSetText(di, _("Red:"));
 
    di = tmp_w[3] = DialogAddItem(table3, DITEM_SLIDER);
    DialogItemSliderSetBounds(di, 0, 255);
@@ -2102,7 +2096,7 @@ _DlgFillBackground(Dialog * d, DItem * table, void *data)
    di = DialogAddItem(table3, DITEM_TEXT);
    DialogItemSetFill(di, 0, 0);
    DialogItemSetAlign(di, 1024, 512);
-   DialogItemSetText(di, _("Green:\n"));
+   DialogItemSetText(di, _("Green:"));
 
    di = tmp_w[4] = DialogAddItem(table3, DITEM_SLIDER);
    DialogItemSliderSetBounds(di, 0, 255);
@@ -2113,7 +2107,7 @@ _DlgFillBackground(Dialog * d, DItem * table, void *data)
    di = DialogAddItem(table3, DITEM_TEXT);
    DialogItemSetFill(di, 0, 0);
    DialogItemSetAlign(di, 1024, 512);
-   DialogItemSetText(di, _("Blue:\n"));
+   DialogItemSetText(di, _("Blue:"));
 
    di = tmp_w[5] = DialogAddItem(table3, DITEM_SLIDER);
    DialogItemSliderSetBounds(di, 0, 255);
@@ -2124,7 +2118,7 @@ _DlgFillBackground(Dialog * d, DItem * table, void *data)
    for (i = 0; i < 10; i++)
       DialogItemSetCallback(tmp_w[i], CB_DesktopMiniDisplayRedraw, 0, area);
 
-   di = DialogAddItem(table, DITEM_SEPARATOR);
+   DialogAddItem(table, DITEM_SEPARATOR);
 
    table2 = DialogAddItem(table, DITEM_TABLE);
    DialogItemTableSetOptions(table2, 3, 0, 0, 0);
@@ -2182,7 +2176,7 @@ _DlgFillBackground(Dialog * d, DItem * table, void *data)
    DialogItemSliderSetValPtr(di, &tmp_bg_sel_sliderval);
    DialogItemSetCallback(bg_sel_slider, CB_BGAreaSlide, 0, NULL);
 
-   di = DialogAddItem(table, DITEM_SEPARATOR);
+   DialogAddItem(table, DITEM_SEPARATOR);
 
    di = DialogAddItem(table, DITEM_CHECKBUTTON);
    DialogItemSetText(di, _("Use dithering in Hi-Colour"));
@@ -2197,7 +2191,7 @@ _DlgFillBackground(Dialog * d, DItem * table, void *data)
 		     _("Enable background transparency compatibility mode"));
    DialogItemCheckButtonSetPtr(di, &tmp_root_hint);
 
-   di = DialogAddItem(table, DITEM_SEPARATOR);
+   DialogAddItem(table, DITEM_SEPARATOR);
 
    di = label = DialogAddItem(table, DITEM_TEXT);
    DialogItemSetAlign(di, 512, 512);
@@ -2222,7 +2216,7 @@ const DialogDef     DlgBackground = {
    N_("Desktop Background Settings"),
    SOUND_SETTINGS_BG,
    "pix/bg.png",
-   N_("Enlightenment Desktop\n" "Background Settings Dialog\n"),
+   N_("Enlightenment Desktop\n" "Background Settings Dialog"),
    _DlgFillBackground,
    DLG_OAC, CB_ConfigureBG,
 };
@@ -2338,23 +2332,22 @@ BackgroundSet2(const char *name, const char *params)
 {
    Background         *bg;
    unsigned int        color;
-   unsigned int        i;
    int                 r, g, b;
    char                bgf[FILEPATH_LEN_MAX], topf[FILEPATH_LEN_MAX];
    int                 tile, keep_aspect, tkeep_aspect;
    int                 xjust, yjust, xperc, yperc;
    int                 txjust, tyjust, txperc, typerc;
 
-   if (params == NULL)
+   if (!params)
       return;
 
    bgf[0] = topf[0] = '\0';
    r = g = b = 99;
-   i = sscanf(params,
-	      "%i %i %i %4000s %i %i %i %i %i %i %4000s %i %i %i %i %i",
-	      &r, &g, &b,
-	      bgf, &tile, &keep_aspect, &xjust, &yjust, &xperc, &yperc,
-	      topf, &tkeep_aspect, &txjust, &tyjust, &txperc, &typerc);
+   sscanf(params,
+	  "%i %i %i %4000s %i %i %i %i %i %i %4000s %i %i %i %i %i",
+	  &r, &g, &b,
+	  bgf, &tile, &keep_aspect, &xjust, &yjust, &xperc, &yperc,
+	  topf, &tkeep_aspect, &txjust, &tyjust, &txperc, &typerc);
    COLOR32_FROM_RGB(color, r, g, b);
 
    bg = BackgroundFind(name);
@@ -2366,9 +2359,9 @@ BackgroundSet2(const char *name, const char *params)
      }
    else
      {
-	bg = BackgroundCreate(name, color, bgf, tile, keep_aspect, xjust,
-			      yjust, xperc, yperc, topf, tkeep_aspect,
-			      txjust, tyjust, txperc, typerc);
+	BackgroundCreate(name, color, bgf, tile, keep_aspect, xjust,
+			 yjust, xperc, yperc, topf, tkeep_aspect,
+			 txjust, tyjust, txperc, typerc);
      }
 }
 
@@ -2435,7 +2428,7 @@ BackgroundsIpc(const char *params)
 	  }
 	else
 	  {
-	     bg = BrackgroundCreateFromImage(prm, p, NULL, 0);
+	     BrackgroundCreateFromImage(prm, p, NULL, 0);
 	  }
      }
    else if (!strncmp(cmd, "set", 2))
@@ -2557,6 +2550,7 @@ static const CfgItem BackgroundsCfgItems[] = {
  * Module descriptor
  */
 extern const EModule ModBackgrounds;
+
 const EModule       ModBackgrounds = {
    "backgrounds", "bg",
    BackgroundsSighan,
