@@ -47,7 +47,7 @@
 
 static Ecore_List  *border_list = NULL;
 
-static void         BorderDestroy(const Border * b);
+static void         BorderDestroy(Border * b);
 static void         BorderWinpartHandleEvents(Win win, XEvent * ev, void *prm);
 static void         BorderFrameHandleEvents(Win win, XEvent * ev, void *prm);
 static Border      *BorderGetFallback(void);
@@ -148,6 +148,7 @@ BorderWinpartITclassApply(EWin * ewin, int i, int force)
 		       break;
 		    case FONT_TO_UP:
 		       y = h - w;
+		       /* FALLTHROUGH */
 		    case FONT_TO_DOWN:
 		       h = w;
 		       break;
@@ -178,11 +179,10 @@ static int
 BorderWinpartDraw(EWin * ewin, int i)
 {
    EWinBit            *ewb = &ewin->bits[i];
-   int                 move = 0, resize = 0, ret = 0;
+   int                 resize = 0, ret = 0;
 
    if ((ewb->x != ewb->cx) || (ewb->y != ewb->cy))
      {
-	move = 1;
 	ewb->cx = ewb->x;
 	ewb->cy = ewb->y;
 	ret = 1;
@@ -549,7 +549,7 @@ EwinBorderSetTo(EWin * ewin, const Border * b)
    if (ewin->border == b)
       return;
 
-   if (b == NULL)
+   if (!b)
      {
 	b = ewin->border;
 	ewin->border = NULL;
@@ -601,6 +601,8 @@ EwinBorderSetTo(EWin * ewin, const Border * b)
       int                 j = 0;
 
       wl = EMALLOC(Window, b->num_winparts + 1);
+      if (!wl)
+	 return;
       for (i = b->num_winparts - 1; i >= 0; i--)
 	{
 	   if (b->part[i].ontop)
@@ -681,7 +683,7 @@ BorderCreate(const char *name)
 }
 
 static void
-BorderDestroy(const Border * b)
+BorderDestroy(Border * b)
 {
    int                 i;
 
@@ -690,7 +692,7 @@ BorderDestroy(const Border * b)
 
    if (b->ref_count > 0)
      {
-	DialogOK("Border Error!", _("%u references remain\n"), b->ref_count);
+	DialogOK("Border Error!", _("%u references remain"), b->ref_count);
 	return;
      }
 
@@ -708,6 +710,7 @@ BorderDestroy(const Border * b)
    Efree(b->name);
    Efree(b->group_border_name);
    ActionclassFree(b->aclass);
+   Efree(b);
 }
 
 static int
@@ -876,7 +879,9 @@ BorderWinpartEventMouseDown(EWinBit * wbit, XEvent * ev)
    EWin               *ewin = wbit->ewin;
    int                 part = wbit - ewin->bits;
 
+#if 0				/* Remove? */
    GrabPointerSet(wbit->win, 0, 0);
+#endif
 
    wbit->state = STATE_CLICKED;
 #if DEBUG_BORDER_EVENTS
@@ -900,7 +905,9 @@ BorderWinpartEventMouseUp(EWinBit * wbit, XEvent * ev)
 
    if (ev)
      {
+#if 0				/* Remove? */
 	GrabPointerRelease();
+#endif
 	/*
 	 * During a move/resize operation initiated by a border part click
 	 * the ButtonRelease event may be reported on the border part window
@@ -942,15 +949,11 @@ BorderWinpartEventEnter(EWinBit * wbit, XEvent * ev)
 #endif
    if (wbit->state == STATE_CLICKED)
       wbit->left = 0;
-#if 0				/* Hmmm.. */
-   else
-#endif
-     {
-	wbit->state = STATE_HILITED;
-	BorderWinpartChange(ewin, part, 0);
-	if (ewin->border->part[part].aclass)
-	   ActionclassEvent(ewin->border->part[part].aclass, ev, ewin);
-     }
+
+   wbit->state = STATE_HILITED;
+   BorderWinpartChange(ewin, part, 0);
+   if (ewin->border->part[part].aclass)
+      ActionclassEvent(ewin->border->part[part].aclass, ev, ewin);
 }
 
 static void
@@ -1293,14 +1296,25 @@ BorderConfigLoad(FILE * fs)
 }
 
 Border             *
-BorderCreateFiller(int left, int right, int top, int bottom)
+BorderCreateFiller(int w, int h, int sw, int sh)
 {
    Border             *b;
+   int                 left, right, top, bottom;
+
+   if (w > sw || h > sh)	/* Borders must be >= 0 */
+      return NULL;
 
    b = BorderCreate("__FILLER");
    if (!b)
       return b;
 
+   left = (sw - w) / 2;
+   left = (left < 0) ? 0 : left;
+   right = sw - w - left;
+   top = (sh - h) / 2;
+   top = (top < 0) ? 0 : top;
+   bottom = sh - h - top;
+
    b->throwaway = 1;
 
    b->border.left = left;
@@ -1384,13 +1398,12 @@ BorderGetFallback(void)
     * least E won't barf on us then.
     */
    Border             *b;
-   ActionClass        *ac;
 
    b = BorderFind("__fb_bd");
    if (b)
       return b;
 
-   ac = BorderGetFallbackAclass();	/* Creates the fallback ac */
+   BorderGetFallbackAclass();	/* Creates the fallback ac */
 
    /* Create fallback border */
    b = BorderCreate("__fb_bd");
