@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2009 Kim Woelders
+ * Copyright (C) 2004-2010 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -68,7 +68,9 @@ struct _button {
 
    int                 state;
    Window              inside_win;
+#if 0				/* Unused */
    Window              event_win;
+#endif
    char                left;
    unsigned int        ref_count;
 };
@@ -127,6 +129,8 @@ ButtonCreate(const char *name, int id, const char *iclass,
       desk = 0;
 
    b = ECALLOC(Button, 1);
+   if (!b)
+      return b;
 
    if (!button_list)
       button_list = ecore_list_new();
@@ -180,7 +184,7 @@ ButtonDestroy(Button * b)
 
    if (b->ref_count > 0)
      {
-	DialogOK("Button Error!", _("%u references remain\n"), b->ref_count);
+	DialogOK("Button Error!", _("%u references remain"), b->ref_count);
 	return;
      }
 
@@ -214,8 +218,6 @@ ButtonCalc(Button * b)
    int                 w, h, x, y, xo, yo;
    EImage             *im;
 
-   x = 0;
-   y = 0;
    w = 32;
    h = 32;
    if (b->geom.size_from_image)
@@ -728,7 +730,6 @@ ButtonsConfigLoad(FILE * fs)
 	       }
 	     goto done;
 	  case CONFIG_CLASSNAME:
-	  case BUTTON_NAME:
 	     STRCPY(name, s2);
 	     pbt = ButtonFind(name);
 	     break;
@@ -736,11 +737,9 @@ ButtonsConfigLoad(FILE * fs)
 	     STRCPY(label, s2);
 	     break;
 	  case CONFIG_IMAGECLASS:
-	  case BUTTON_ICLASS:
 	     STRCPY(iclass, s2);
 	     break;
 	  case CONFIG_ACTIONCLASS:
-	  case BUTTON_ACLASS:
 	     STRCPY(aclass, s2);
 	     break;
 	  case CONFIG_TEXT:
@@ -1086,6 +1085,7 @@ static const CfgItem ButtonsCfgItems[] = {
  * Module descriptor
  */
 extern const EModule ModButtons;
+
 const EModule       ModButtons = {
    "buttons", "btn",
    ButtonsSighan,
