@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2009 Kim Woelders
+ * Copyright (C) 2004-2010 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -40,16 +40,19 @@
 
 #define MAX_E_CFG_VERSION 2	/* Max. supported configuration version */
 
+static char        *ConfigFileFind(const char *name, const char *themepath,
+				   int pp);
+
 void
 SkipTillEnd(FILE * fs)
 {
    char                s[FILEPATH_LEN_MAX];
-   int                 i1, i2, fields;
+   int                 i1, i2;
 
    while (GetLine(s, sizeof(s), fs))
      {
 	i1 = i2 = 0;
-	fields = sscanf(s, "%i %i", &i1, &i2);
+	sscanf(s, "%i %i", &i1, &i2);
 	if (i1 == CONFIG_CLOSE)
 	   return;
 	if (i2 == CONFIG_OPEN)
@@ -72,11 +75,11 @@ GetLine(char *s, int size, FILE * f)
    const char         *si;
    size_t              nr;
 
-   if (buffer == NULL)
+   if (!buffer)
      {
 	buffer = EMALLOC(char, LINE_BUFFER_SIZE);
 
-	if (buffer == NULL)
+	if (!buffer)
 	   return NULL;
 	buffer[LINE_BUFFER_SIZE - 1] = '\0';
      }
@@ -88,7 +91,7 @@ GetLine(char *s, int size, FILE * f)
    for (;;)
      {
 	/* Get a line from the input file */
-	if (si == NULL)
+	if (!si)
 	  {
 	     nr = fread(buffer, 1, LINE_BUFFER_SIZE - 1, f);
 	     if (nr == 0)
@@ -107,6 +110,7 @@ GetLine(char *s, int size, FILE * f)
 	  case ';':		/* Line separator */
 	     if (escape || quote)
 		goto case_char;
+	     /* FALLTHROUGH */
 	  case '\n':
 	     if (so == s)	/* Skip empty lines */
 		break;
@@ -147,7 +151,7 @@ GetLine(char *s, int size, FILE * f)
 
  done:
    bufptr = si;
-   if (si == NULL)
+   if (!si)
      {
 	/* EOF */
 	Efree(buffer);
@@ -195,7 +199,7 @@ ConfigParseline1(char *str, char *s2, char **p2, char **p3)
      {
 	if (fields != 1)
 	  {
-	     Alert(_("CONFIG: ignoring extra data in \"%s\"\n"), str);
+	     Alert(_("CONFIG: ignoring extra data in \"%s\""), str);
 	  }
      }
    else if (i1 != CONFIG_INVALID)
@@ -203,7 +207,7 @@ ConfigParseline1(char *str, char *s2, char **p2, char **p3)
 	if (fields != 2)
 	  {
 	     i1 = CONFIG_INVALID;
-	     Alert(_("CONFIG: missing required data in \"%s\"\n"), str);
+	     Alert(_("CONFIG: missing required data in \"%s\""), str);
 	  }
      }
 
@@ -229,7 +233,6 @@ static int
 ConfigFilePreparse(const char *src, const char *dst, const char *themepath)
 {
    char                execline[FILEPATH_LEN_MAX];
-   const char         *epp_path = ENLIGHTENMENT_BIN "/epp";
    char               *def_home, *def_user, *def_shell;
    const char         *variant;
 
@@ -246,7 +249,7 @@ ConfigFilePreparse(const char *src, const char *dst, const char *themepath)
       themepath = Mode.theme.path;
    variant = (Mode.theme.variant) ? Mode.theme.variant : "";
 
-   Esnprintf(execline, sizeof(execline), "%s " "-P " "-nostdinc " "-undef "
+   Esnprintf(execline, sizeof(execline), "%s/epp " "-P " "-nostdinc " "-undef "
 	     "-include %s/config/definitions " "-I%s " "-I%s/config "
 	     "-D ENLIGHTENMENT_VERSION=%s " "-D ENLIGHTENMENT_ROOT=%s "
 	     "-D ENLIGHTENMENT_BIN=%s "
@@ -257,7 +260,7 @@ ConfigFilePreparse(const char *src, const char *dst, const char *themepath)
 	     "-D SCREEN_DEPTH_%i=1 " "-D USER_NAME=%s " "-D HOME_DIR=%s "
 	     "-D USER_SHELL=%s "
 	     "%s %s",
-	     epp_path, EDirRoot(), themepath, EDirRoot(),
+	     EDirBin(), EDirRoot(), themepath, EDirRoot(),
 	     e_wm_version, EDirRoot(), EDirBin(), themepath, variant,
 	     EDirUser(), EDirUserCache(),
 	     WinGetW(VROOT), WinGetH(VROOT), WinGetW(VROOT), WinGetH(VROOT),
@@ -298,14 +301,14 @@ ConfigFileRead(FILE * fs)
 	  {
 	     if (fields != 1)
 	       {
-		  Alert(_("CONFIG: ignoring extra data in \"%s\"\n"), s);
+		  Alert(_("CONFIG: ignoring extra data in \"%s\""), s);
 	       }
 	  }
 	else if (i1 != CONFIG_INVALID)
 	  {
 	     if (fields != 2)
 	       {
-		  Alert(_("CONFIG: missing required data in \"%s\"\n"), s);
+		  Alert(_("CONFIG: missing required data in \"%s\""), s);
 		  i1 = CONFIG_INVALID;
 	       }
 	  }
@@ -420,6 +423,9 @@ FindFilePath(const char *name, const char *path)
    char                s[FILEPATH_LEN_MAX];
    int                 len;
 
+#if 0
+   Eprintf("%s: %s (%s)\n", __func__, name, path);
+#endif
    if (path)
      {
 	len = Esnprintf(s, sizeof(s), "%s/%s", path, name);
@@ -438,9 +444,21 @@ FindFilePath(const char *name, const char *path)
       return NULL;
 }
 
+/* *INDENT-OFF* */
+static const struct {
+   const char         *where, *subdir;
+} fprm[] = {
+   { "utE",  "config" },
+   { "ute",   NULL    },
+   { "UuE",  "menus"  },
+   { "UuE",  "icons"  }
+};
+/* *INDENT-ON* */
+
 char               *
-FindFile(const char *file, const char *themepath)
+FindFile(const char *file, const char *themepath, int type)
 {
+   const char         *w, *f, *path;
    char                s[FILEPATH_LEN_MAX];
    char               *p;
 
@@ -448,47 +466,63 @@ FindFile(const char *file, const char *themepath)
    if (isabspath(file))
      {
 	p = FindFilePath(file, NULL);
-	if (p)
-	   return p;
+	/* Absolute path - no need to look elsewhere */
+	goto done;
      }
 
-   /* look in ~/.e16 first */
-   p = FindFilePath(file, EDirUser());
-   if (p)
-      return p;
-
-   if (themepath)
+   p = NULL;
+   for (w = fprm[type].where; *w; w++)
      {
-	/* look in theme dir */
-	p = FindFilePath(file, themepath);
+	f = file;
+	if (*w <= 'Z')
+	  {
+	     /* Look in subdir */
+	     Esnprintf(s, sizeof(s), "%s/%s", fprm[type].subdir, file);
+	     f = s;
+	  }
+
+	switch (*w & 0xdf)
+	  {
+	  default:
+	     continue;
+	  case 'U':		/* User config */
+	     path = EDirUser();
+	     break;
+	  case 'E':		/* e16 config */
+	     path = EDirRoot();
+	     break;
+	  case 'T':		/* Theme */
+	     path = themepath;
+	     if (!path)
+		continue;
+	     break;
+	  }
+	p = FindFilePath(f, path);
 	if (p)
-	   return p;
+	   break;
      }
 
-   /* look in system config dir */
-   Esnprintf(s, sizeof(s), "%s/config", EDirRoot());
-   p = FindFilePath(file, s);
-   if (p)
-      return p;
-
-   /* not found.... NULL */
-   return NULL;
+ done:
+#if 0
+   Eprintf("%s %d: %s (%s): %s\n", __func__, type, file, themepath, p);
+#endif
+   return p;
 }
 
 char               *
-ThemeFileFind(const char *file)
+ThemeFileFind(const char *file, int type)
 {
-   return FindFile(file, Mode.theme.path);
+   return FindFile(file, Mode.theme.path, type);
 }
 
-char               *
+static char        *
 ConfigFileFind(const char *name, const char *themepath, int pp)
 {
    char                s[FILEPATH_LEN_MAX];
    char               *fullname, *file, *ppfile;
    int                 i, err;
 
-   fullname = FindFile(name, themepath);
+   fullname = FindFile(name, themepath, FILE_TYPE_CONFIG);
    if (!fullname)
       return NULL;
 
