@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2009 Kim Woelders
+ * Copyright (C) 2004-2010 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -30,6 +30,7 @@
 #include "ewins.h"
 #include "hints.h"
 #include "iclass.h"
+#include "icons.h"
 #include "menus.h"
 
 extern const ContainerOps IconboxOps;
@@ -215,6 +216,8 @@ _ContainerEwinInit(EWin * ewin)
 {
    Container          *ct = (Container *) ewin->data;
 
+   ct->ewin = ewin;
+
    EwinSetTitle(ewin, ct->wm_name);
    EwinSetClass(ewin, ct->name, "Enlightenment_IconBox");
 
@@ -283,7 +286,6 @@ ContainerShow(Container * ct)
 
    ewin = AddInternalToFamily(ct->win, "ICONBOX", EWIN_TYPE_ICONBOX,
 			      &_ContainerEwinOps, ct);
-   ct->ewin = ewin;
    if (!ewin)
       return;
 
@@ -418,11 +420,12 @@ ContainerLayoutImageWin(Container * ct)
 	item_pad = 2;
      }
 
+   pad = (ct->ic_box) ? ImageclassGetPadding(ct->ic_box) : NULL;
+
    xo = 0;
    yo = 0;
-   if (ct->ic_box)
+   if (pad)
      {
-	pad = ImageclassGetPadding(ct->ic_box);
 	xo += pad->left;
 	yo += pad->top;
      }
@@ -484,9 +487,8 @@ ContainerLayoutImageWin(Container * ct)
 	   xo += cto->wo + item_pad;
      }
 
-   if (ct->ic_box)
+   if (pad)
      {
-	pad = ImageclassGetPadding(ct->ic_box);
 	xo += pad->right;
 	yo += pad->bottom;
      }
@@ -499,7 +501,7 @@ ContainerLayoutImageWin(Container * ct)
    if (ct->orientation)
      {
 	ct->iwin_fixh = ct->iconsize;
-	if (ct->ic_box)
+	if (pad)
 	   ct->iwin_fixh += pad->left + pad->right;
 	if (ct->draw_icon_base)
 	   ct->iwin_fixh += padl + padr;
@@ -508,7 +510,7 @@ ContainerLayoutImageWin(Container * ct)
    else
      {
 	ct->iwin_fixh = ct->iconsize;
-	if (ct->ic_box)
+	if (pad)
 	   ct->iwin_fixh += pad->top + pad->bottom;
 	if (ct->draw_icon_base)
 	   ct->iwin_fixh += padt + padb;
@@ -1573,7 +1575,7 @@ _DlgFillContainer(Dialog * d, DItem * table, void *data)
    DialogItemSliderSetJump(di, 8);
    DialogItemSliderSetValPtr(di, &dd->autoresize_anchor);
 
-   di = DialogAddItem(table, DITEM_SEPARATOR);
+   DialogAddItem(table, DITEM_SEPARATOR);
 
    label = di = DialogAddItem(table, DITEM_TEXT);
    DialogItemSetFill(di, 0, 0);
@@ -1588,7 +1590,7 @@ _DlgFillContainer(Dialog * d, DItem * table, void *data)
    DialogItemSliderSetValPtr(di, &dd->iconsize);
    DialogItemSetCallback(di, CB_IconSizeSlider, 0, label);
 
-   di = DialogAddItem(table, DITEM_SEPARATOR);
+   DialogAddItem(table, DITEM_SEPARATOR);
 
    table2 = DialogAddItem(table, DITEM_TABLE);
    DialogItemTableSetOptions(table2, 5, 0, 0, 0);
@@ -1609,8 +1611,8 @@ _DlgFillContainer(Dialog * d, DItem * table, void *data)
    DialogItemRadioButtonGroupSetVal(di, 1);
    DialogItemRadioButtonGroupSetValPtr(radio, &dd->vert);
 
-   di = DialogAddItem(table2, DITEM_NONE);
-   di = DialogAddItem(table2, DITEM_NONE);
+   DialogAddItem(table2, DITEM_NONE);
+   DialogAddItem(table2, DITEM_NONE);
 
    di = DialogAddItem(table2, DITEM_TEXT);
    DialogItemSetFill(di, 0, 0);
@@ -1628,8 +1630,8 @@ _DlgFillContainer(Dialog * d, DItem * table, void *data)
    DialogItemRadioButtonGroupSetVal(di, 1);
    DialogItemRadioButtonGroupSetValPtr(radio, &dd->side);
 
-   di = DialogAddItem(table2, DITEM_NONE);
-   di = DialogAddItem(table2, DITEM_NONE);
+   DialogAddItem(table2, DITEM_NONE);
+   DialogAddItem(table2, DITEM_NONE);
 
    di = DialogAddItem(table2, DITEM_TEXT);
    DialogItemSetFill(di, 0, 0);
@@ -1657,7 +1659,7 @@ _DlgFillContainer(Dialog * d, DItem * table, void *data)
    DialogItemRadioButtonGroupSetVal(di, 3);
    DialogItemRadioButtonGroupSetValPtr(radio, &dd->arrows);
 
-   di = DialogAddItem(table, DITEM_SEPARATOR);
+   DialogAddItem(table, DITEM_SEPARATOR);
 
    if (ct->type == IB_TYPE_ICONBOX)
      {
@@ -1700,7 +1702,7 @@ _DlgFillContainer(Dialog * d, DItem * table, void *data)
 	DialogItemSliderSetJump(di, 50);
 	DialogItemSliderSetValPtr(di, &dd->anim_speed);
 
-	di = DialogAddItem(table, DITEM_SEPARATOR);
+	DialogAddItem(table, DITEM_SEPARATOR);
 
 	di = DialogAddItem(table, DITEM_TEXT);
 	DialogItemSetFill(di, 0, 0);
@@ -1714,19 +1716,19 @@ _DlgFillContainer(Dialog * d, DItem * table, void *data)
 			  _
 			  ("Snapshot Windows, Use application icon, Use Enlightenment Icon"));
 	DialogItemRadioButtonSetFirst(di, radio);
-	DialogItemRadioButtonGroupSetVal(di, 0);
+	DialogItemRadioButtonGroupSetVal(di, EWIN_ICON_MODE_SNAP);
 
 	di = DialogAddItem(table, DITEM_RADIOBUTTON);
 	DialogItemSetText(di,
 			  _
 			  ("Use application icon, Use Enlightenment Icon, Snapshot Window"));
 	DialogItemRadioButtonSetFirst(di, radio);
-	DialogItemRadioButtonGroupSetVal(di, 1);
+	DialogItemRadioButtonGroupSetVal(di, EWIN_ICON_MODE_APP_IMG_SNAP);
 
 	di = DialogAddItem(table, DITEM_RADIOBUTTON);
 	DialogItemSetText(di, _("Use Enlightenment Icon, Snapshot Window"));
 	DialogItemRadioButtonSetFirst(di, radio);
-	DialogItemRadioButtonGroupSetVal(di, 2);
+	DialogItemRadioButtonGroupSetVal(di, EWIN_ICON_MODE_IMG_APP_SNAP);
 	DialogItemRadioButtonGroupSetValPtr(radio, &dd->icon_mode);
      }
 }
@@ -1737,7 +1739,7 @@ static const DialogDef DlgContainer = {
    NULL,
    SOUND_SETTINGS_ICONBOX,
    "pix/iconbox.png",
-   N_("Enlightenment Iconbox\n" "Settings Dialog\n"),
+   N_("Enlightenment Iconbox\n" "Settings Dialog"),
    _DlgFillContainer,
    DLG_OAC, CB_ConfigureContainer,
 };
@@ -1748,21 +1750,15 @@ static const DialogDef DlgContainer = {
  */
 #include "conf.h"
 
-static void
-ContainersConfigLoad(void)
+static int
+_ContainersConfigLoad(FILE * fs)
 {
    int                 err = 0;
-   FILE               *fs;
    char                s[FILEPATH_LEN_MAX];
    char                s2[FILEPATH_LEN_MAX];
    int                 i1, i2;
    Container          *ct, ct_dummy;
 
-   Esnprintf(s, sizeof(s), "%s.ibox", EGetSavePrefix());
-   fs = fopen(s, "r");
-   if (!fs)
-      return;
-
    ct = &ct_dummy;
    while (fgets(s, sizeof(s), fs))
      {
@@ -1830,11 +1826,22 @@ ContainersConfigLoad(void)
 	     break;
 	  }
      }
+
+ done:
    if (err)
       Eprintf("Error: Iconbox configuration file load problem.\n");
 
- done:
-   fclose(fs);
+   return err;
+}
+
+static void
+ContainersConfigLoad(void)
+{
+   char                s[4096];
+
+   Esnprintf(s, sizeof(s), "%s.ibox", EGetSavePrefix());
+
+   ConfigFileLoad(s, NULL, _ContainersConfigLoad, 0);
 }
 
 static void
@@ -2007,6 +2014,7 @@ static const CfgItem ContainersCfgItems[] = {
  * Module descriptor
  */
 extern const EModule ModIconboxes;
+
 const EModule       ModIconboxes = {
    "iconboxes", "ibox",
    ContainersSighan,
