@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2008 Kim Woelders
+ * Copyright (C) 2004-2009 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -78,19 +78,17 @@ struct _container {
    EWin               *ewin;
    int                 w, h;
    int                 pos;
-   int                 max, max_min;
+   int                 iwin_maxl, iwin_maxl_min;
+   int                 iwin_fixh;
    ImageClass         *ic_box;
    ImageClass         *ic_item_base;
    EImage             *im_item_base;
 
-   char                arrow1_hilited;
-   char                arrow1_clicked;
-   char                arrow2_hilited;
-   char                arrow2_clicked;
-   char                icon_clicked;
-   char                scrollbar_hilited;
-   char                scrollbar_clicked;
+   unsigned char       scrollbar_state;
+   unsigned char       arrow1_state;
+   unsigned char       arrow2_state;
    char                scrollbox_clicked;
+   char                icon_clicked;
 
    Win                 win;
    Win                 cover_win;
@@ -112,6 +110,7 @@ struct _container {
 
    /* State flags */
    char                do_update;
+   int                 scroll_thickness_set;
 };
 
 extern ContainerCfg Conf_containers;
