@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2009 Kim Woelders
+ * Copyright (C) 2004-2010 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -128,7 +128,7 @@ ECursorDestroy(ECursor * ec)
 
    if (ec->ref_count > 0)
      {
-	DialogOK("ECursor Error!", _("%u references remain\n"), ec->ref_count);
+	DialogOK("ECursor Error!", _("%u references remain"), ec->ref_count);
 	return;
      }
 
@@ -150,7 +150,7 @@ ECursorRealize(ECursor * ec)
 
    if (ec->file)
      {
-	img = FindFile(ec->file, Mode.theme.path);
+	img = ThemeFileFind(ec->file, FILE_TYPE_CURSOR);
 	_EFREE(ec->file);	/* Ok or not - we never need file again */
 	if (!img)
 	   goto done;
@@ -398,7 +398,6 @@ CursorsIpc(const char *params)
      {
 	len = 0;
 	sscanf(p, "%100s %4000s %n", cmd, prm, &len);
-	p += len;
      }
 
    if (!strncmp(cmd, "list", 2))
@@ -420,6 +419,7 @@ static const IpcItem CursorIpcArray[] = {
  * Module descriptor
  */
 extern const EModule ModCursors;
+
 const EModule       ModCursors = {
    "cursor", "csr",
    NULL,
