@@ -150,7 +150,7 @@ DeskControlsCreate(Desk * dsk)
 	ActionclassAddAction(ac, a);
 
 	ActionAddTo(a, "desk next");
-	t = _("Click here to raise this desktop\nto the top.\n");
+	t = _("Click here to raise this desktop\nto the top.");
 	ActionclassSetTooltipString(ac, t);
      }
 
@@ -162,7 +162,7 @@ DeskControlsCreate(Desk * dsk)
 	ActionclassAddAction(ac, a);
 
 	ActionAddTo(a, "desk prev");
-	t = _("Click here to lower this desktop\nto the bottom.\n");
+	t = _("Click here to lower this desktop\nto the bottom.");
 	ActionclassSetTooltipString(ac, t);
      }
 
@@ -375,6 +375,8 @@ DeskCreate(int desk, int configure)
       return NULL;
 
    dsk = ECALLOC(Desk, 1);
+   if (!dsk)
+      return dsk;
 
    desks.desk[desk] = dsk;
    dsk->num = desk;
@@ -639,7 +641,7 @@ DeskBackgroundRefresh(Desk * dsk, int why)
      }
 
    if (bg && dsk->viewable)
-      if (Conf.hints.set_xroot_info_on_root_window && dsk->num > 0)
+      if (Conf.hints.set_xroot_info_on_root_window)
 	 HintsSetRootInfo(VROOT, pmap, pixel);
 
    if (changed)
@@ -730,11 +732,13 @@ DeskGetValid(unsigned int desk)
 Desk               *
 DeskGetRelative(Desk * dsk, int inc)
 {
-   unsigned int        desk;
+   unsigned int        desk, num;
 
+   num = Conf.desks.num;
    desk = (dsk) ? dsk->num : 0;
-   desk += inc;
-   desk %= Conf.desks.num;
+   inc %= (int)num;
+   desk += num + inc;
+   desk %= num;
 
    return _DeskGet(desk);
 }
@@ -1970,8 +1974,14 @@ DeskHandleEvents(Win win __UNUSED__, XEvent * ev, void *prm)
 	break;
 
      case ConfigureNotify:
-	if (ev->xconfigure.window == WinGetXwin(VROOT))
-	   DeskRootResize(0, ev->xconfigure.width, ev->xconfigure.height);
+	if (ev->xconfigure.window != WinGetXwin(VROOT))
+	   break;
+	if (Mode.wm.window)	/* This test should not be necessary but... */
+	  {
+	     Mode.wm.win_x = ev->xconfigure.x;
+	     Mode.wm.win_y = ev->xconfigure.y;
+	  }
+	DeskRootResize(0, ev->xconfigure.width, ev->xconfigure.height);
 	break;
 
      case PropertyNotify:
@@ -1984,6 +1994,8 @@ DeskHandleEvents(Win win __UNUSED__, XEvent * ev, void *prm)
 	{
 	   XRRScreenChangeNotifyEvent *rrev = (XRRScreenChangeNotifyEvent *) ev;
 
+	   XRRUpdateConfiguration(ev);
+	   Mode.screen.rotation = rrev->rotation;
 	   DeskRootResize(1, rrev->width, rrev->height);
 	}
 	break;
@@ -2219,6 +2231,8 @@ CB_ConfigureDesktops(Dialog * d, int val, void *data __UNUSED__)
 	Conf.desks.dragdir = dd->dragdir;
 	DesksControlsRefresh();
      }
+
+   autosave();
 }
 
 static void
@@ -2329,7 +2343,7 @@ _DlgFillDesks(Dialog * d, DItem * table, void *data __UNUSED__)
 
    di = DialogAddItem(table, DITEM_TEXT);
    DialogItemSetColSpan(di, 2);
-   DialogItemSetText(di, _("Number of virtual desktops:\n"));
+   DialogItemSetText(di, _("Number of virtual desktops:"));
 
    di = dd->desk_text = DialogAddItem(table, DITEM_TEXT);
    DialogItemSetColSpan(di, 2);
@@ -2360,7 +2374,7 @@ _DlgFillDesks(Dialog * d, DItem * table, void *data __UNUSED__)
    di = DialogAddItem(table, DITEM_TEXT);
    DialogItemSetColSpan(di, 2);
    DialogItemSetAlign(di, 1024, 512);
-   DialogItemSetText(di, _("Desktop Slide speed:\n"));
+   DialogItemSetText(di, _("Desktop Slide speed:"));
 
    di = DialogAddItem(table, DITEM_SLIDER);
    DialogItemSetColSpan(di, 2);
@@ -2422,7 +2436,7 @@ const DialogDef     DlgDesks = {
    N_("Multiple Desktop Settings"),
    SOUND_SETTINGS_DESKTOPS,
    "pix/desktops.png",
-   N_("Enlightenment Multiple Desktop\n" "Settings Dialog\n"),
+   N_("Enlightenment Multiple Desktop\n" "Settings Dialog"),
    _DlgFillDesks,
    DLG_OAC, CB_ConfigureDesktops,
 };
@@ -2452,6 +2466,8 @@ CB_ConfigureAreas(Dialog * d, int val, void *data __UNUSED__)
    if (dd->edge_resist < 1)
       dd->edge_resist = 1;
    Conf.desks.edge_flip_resistance = dd->edge_resist;
+
+   autosave();
 }
 
 static void
@@ -2522,7 +2538,7 @@ _DlgFillAreas(Dialog * d, DItem * table, void *data __UNUSED__)
    DialogItemTableSetOptions(table, 1, 0, 0, 0);
 
    di = DialogAddItem(table, DITEM_TEXT);
-   DialogItemSetText(di, _("Virtual Desktop size:\n"));
+   DialogItemSetText(di, _("Virtual Desktop size:"));
 
    di = dd->area_text = DialogAddItem(table, DITEM_TEXT);
    DialogItemSetText(di, "X");
@@ -2530,7 +2546,7 @@ _DlgFillAreas(Dialog * d, DItem * table, void *data __UNUSED__)
    table2 = DialogAddItem(table, DITEM_TABLE);
    DialogItemTableSetOptions(table2, 2, 0, 0, 0);
 
-   di = DialogAddItem(table2, DITEM_NONE);
+   DialogAddItem(table2, DITEM_NONE);
 
    di = slider = DialogAddItem(table2, DITEM_SLIDER);
    DialogItemSliderSetMinLength(di, 10);
@@ -2555,13 +2571,13 @@ _DlgFillAreas(Dialog * d, DItem * table, void *data __UNUSED__)
    DialogItemSetCallback(slider, CB_AreaDisplayRedraw, 0, di);
    DialogItemSetCallback(slider2, CB_AreaDisplayRedraw, 0, di);
 
-   di = DialogAddItem(table, DITEM_SEPARATOR);
+   DialogAddItem(table, DITEM_SEPARATOR);
 
    di = DialogAddItem(table, DITEM_CHECKBUTTON);
    DialogItemSetText(di, _("Wrap virtual desktops around"));
    DialogItemCheckButtonSetPtr(di, &dd->area_wraparound);
 
-   di = DialogAddItem(table, DITEM_SEPARATOR);
+   DialogAddItem(table, DITEM_SEPARATOR);
 
    di = DialogAddItem(table, DITEM_TEXT);
    DialogItemSetAlign(di, 0, 512);
@@ -2584,7 +2600,7 @@ _DlgFillAreas(Dialog * d, DItem * table, void *data __UNUSED__)
    DialogItemRadioButtonGroupSetValPtr(radio, &dd->edge_flip);
 
    di = DialogAddItem(table, DITEM_TEXT);
-   DialogItemSetText(di, _("Resistance at edge of screen:\n"));
+   DialogItemSetText(di, _("Resistance at edge of screen:"));
 
    di = DialogAddItem(table, DITEM_SLIDER);
    DialogItemSliderSetMinLength(di, 10);
@@ -2600,7 +2616,7 @@ const DialogDef     DlgAreas = {
    N_("Virtual Desktop Settings"),
    SOUND_SETTINGS_AREA,
    "pix/areas.png",
-   N_("Enlightenment Virtual Desktop\n" "Settings Dialog\n"),
+   N_("Enlightenment Virtual Desktop\n" "Settings Dialog"),
    _DlgFillAreas,
    DLG_OAC, CB_ConfigureAreas,
 };
@@ -2881,6 +2897,7 @@ static const CfgItem DesksCfgItems[] = {
  * Module descriptor
  */
 extern const EModule ModDesktops;
+
 const EModule       ModDesktops = {
    "desktops", "desk",
    DesksSighan,
