@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2009 Kim Woelders
+ * Copyright (C) 2004-2010 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -73,7 +73,7 @@ typedef struct {
 
 typedef struct {
    Win                 check_win;
-   int                 check_orig_w, check_orig_h;
+   int                 orig_w, orig_h;
    char                onoff;
    char               *onoff_ptr;
 } DItemCheckButton;
@@ -97,13 +97,12 @@ typedef struct {
 
 typedef struct {
    Win                 radio_win;
-   int                 radio_orig_w, radio_orig_h;
+   int                 orig_w, orig_h;
    char                onoff;
    int                 val;
    int                *val_ptr;
    DItem              *next;
    DItem              *first;
-   DialogItemCallbackFunc *event_func;
 } DItemRadioButton;
 
 struct _ditem {
@@ -260,7 +259,7 @@ DialogDestroy(Dialog * d)
    ImageclassFree(d->iclass);
    TextclassFree(d->tclass);
 
-   FreePmapMask(&(d->pmm_bg));
+   PmapMaskFree(&d->pmm_bg);
 
    Efree(d);
 }
@@ -338,7 +337,7 @@ DialogRedraw(Dialog * d)
 	   WinGetXwin(d->win), WinGetPmap(d->win));
 #endif
 
-   FreePmapMask(&(d->pmm_bg));
+   PmapMaskFree(&d->pmm_bg);
    ImageclassApplyCopy(d->iclass, d->win, d->w, d->h, 0, 0, STATE_NORMAL,
 		       &(d->pmm_bg), IC_FLAG_FULL_SIZE, ST_DIALOG);
    if (d->pmm_bg.pmap == None)
@@ -357,6 +356,8 @@ _DialogEwinInit(EWin * ewin)
 {
    Dialog             *d = (Dialog *) ewin->data;
 
+   d->ewin = ewin;
+
    EwinSetTitle(ewin, d->title);
    EwinSetClass(ewin, d->name, "Enlightenment_Dialog");
    d->set_title = 0;
@@ -439,7 +440,6 @@ DialogShowArranged(Dialog * d, int center)
 
    ewin = AddInternalToFamily(d->win, "DIALOG", EWIN_TYPE_DIALOG,
 			      &_DialogEwinOps, d);
-   d->ewin = ewin;
    if (!ewin)
       return;
 
@@ -558,6 +558,8 @@ DialogItemCreate(int type)
    DItem              *di;
 
    di = ECALLOC(DItem, 1);
+   if (!di)
+      return di;
 
    di->type = type;
    di->align_h = 512;
@@ -611,8 +613,8 @@ DialogAddItem(DItem * dii, int type)
      case DITEM_CHECKBUTTON:
 	di->item.check_button.onoff = 0;
 	di->item.check_button.onoff_ptr = &(di->item.check_button.onoff);
-	di->item.check_button.check_orig_w = 10;
-	di->item.check_button.check_orig_h = 10;
+	di->item.check_button.orig_w = 10;
+	di->item.check_button.orig_h = 10;
 	break;
      case DITEM_TABLE:
 	di->item.table.num_columns = 1;
@@ -624,8 +626,8 @@ DialogAddItem(DItem * dii, int type)
 	di->item.separator.horizontal = 0;
 	break;
      case DITEM_RADIOBUTTON:
-	di->item.radio_button.radio_orig_w = 10;
-	di->item.radio_button.radio_orig_h = 10;
+	di->item.radio_button.orig_w = 10;
+	di->item.radio_button.orig_h = 10;
 	break;
      case DITEM_SLIDER:
 	di->item.slider.horizontal = 1;
@@ -670,39 +672,37 @@ DialogAddHeader(Dialog * d __UNUSED__, DItem * parent, const char *img,
    di = DialogAddItem(table, DITEM_TEXT);
    DialogItemSetText(di, txt);
 
-   di = DialogAddItem(parent, DITEM_SEPARATOR);
+   DialogAddItem(parent, DITEM_SEPARATOR);
 }
 
 static void
 DialogAddFooter(Dialog * d, DItem * parent, int flags, DialogCallbackFunc * cb)
 {
-   DItem              *table, *di;
+   DItem              *table;
    int                 n_buttons;
 
    if (!(flags & DLG_NO_SEPARATOR))
-      di = DialogAddItem(parent, DITEM_SEPARATOR);
+      DialogAddItem(parent, DITEM_SEPARATOR);
 
    table = DialogAddItem(parent, DITEM_TABLE);
    DialogItemSetAlign(table, 512, 0);
    DialogItemSetFill(table, 0, 0);
 
-   /* FIXME - The "real" dialog buttons are slightly different */
    n_buttons = 0;
    if (flags & 1)
      {
-	di = DialogItemAddButton(table, _("OK"), cb, 0, 1, DLG_BUTTON_OK);
+	DialogItemAddButton(table, _("OK"), cb, 0, 1, DLG_BUTTON_OK);
 	n_buttons++;
      }
    if (flags & 2)
      {
-	di = DialogItemAddButton(table, _("Apply"), cb, 1, 0, DLG_BUTTON_APPLY);
+	DialogItemAddButton(table, _("Apply"), cb, 1, 0, DLG_BUTTON_APPLY);
 	DialogBindKey(d, "Return", cb, 1, NULL);
 	n_buttons++;
      }
    if (flags & 4)
      {
-	di =
-	   DialogItemAddButton(table, _("Close"), NULL, 0, 1, DLG_BUTTON_CLOSE);
+	DialogItemAddButton(table, _("Close"), NULL, 0, 1, DLG_BUTTON_CLOSE);
 	DialogBindKey(d, "Escape", DialogCallbackClose, 0, NULL);
 	n_buttons++;
      }
@@ -954,14 +954,14 @@ DialogRealizeItem(Dialog * d, DItem * di)
 	im = ImageclassGetImage(di->iclass, 0, 0, 0);
 	if (im)
 	  {
-	     EImageGetSize(im, &di->item.check_button.check_orig_w,
-			   &di->item.check_button.check_orig_h);
+	     EImageGetSize(im, &di->item.check_button.orig_w,
+			   &di->item.check_button.orig_h);
 	     EImageFree(im);
 	  }
 	TextSize(di->tclass, 0, 0, STATE_NORMAL, di->text, &iw, &ih, 17);
-	if (ih < di->item.check_button.check_orig_h)
-	   ih = di->item.check_button.check_orig_h;
-	iw += di->item.check_button.check_orig_w + pad->left;
+	if (ih < di->item.check_button.orig_h)
+	   ih = di->item.check_button.orig_h;
+	iw += di->item.check_button.orig_w + pad->left;
 	di->item.check_button.check_win =
 	   ECreateWindow(d->win, -20, -20, 2, 2, 0);
 	di->win = ECreateEventWindow(d->win, -20, -20, 2, 2);
@@ -1004,14 +1004,14 @@ DialogRealizeItem(Dialog * d, DItem * di)
 	im = ImageclassGetImage(di->iclass, 0, 0, 0);
 	if (im)
 	  {
-	     EImageGetSize(im, &di->item.radio_button.radio_orig_w,
-			   &di->item.radio_button.radio_orig_h);
+	     EImageGetSize(im, &di->item.radio_button.orig_w,
+			   &di->item.radio_button.orig_h);
 	     EImageFree(im);
 	  }
 	TextSize(di->tclass, 0, 0, STATE_NORMAL, di->text, &iw, &ih, 17);
-	if (ih < di->item.radio_button.radio_orig_h)
-	   ih = di->item.radio_button.radio_orig_h;
-	iw += di->item.radio_button.radio_orig_w + pad->left;
+	if (ih < di->item.radio_button.orig_h)
+	   ih = di->item.radio_button.orig_h;
+	iw += di->item.radio_button.orig_w + pad->left;
 	di->item.radio_button.radio_win =
 	   ECreateWindow(d->win, -20, -20, 2, 2, 0);
 	di->win = ECreateEventWindow(d->win, -20, -20, 2, 2);
@@ -1039,6 +1039,9 @@ DialogRealizeItem(Dialog * d, DItem * di)
 		col_size = EMALLOC(int, cols);
 		row_size = EMALLOC(int, rows);
 
+		if (!col_size || !row_size)
+		   goto bail_out;
+
 		row_size[0] = 0;
 		for (i = 0; i < cols; i++)
 		   col_size[i] = 0;
@@ -1072,6 +1075,9 @@ DialogRealizeItem(Dialog * d, DItem * di)
 			  rows++;
 			  row_size = EREALLOC(int, row_size, rows);
 
+			  if (!row_size)
+			     goto bail_out;
+
 			  row_size[rows - 1] = 0;
 		       }
 		  }
@@ -1165,27 +1171,21 @@ DialogRealizeItem(Dialog * d, DItem * di)
 			     EMoveResizeWindow(dii->win, dii->x, dii->y,
 					       dii->w, dii->h);
 			  if (dii->type == DITEM_CHECKBUTTON)
-			     EMoveResizeWindow(dii->item.check_button.
-					       check_win, dii->x,
+			     EMoveResizeWindow(dii->item.check_button.check_win,
+					       dii->x,
 					       dii->y +
-					       ((dii->h -
-						 dii->item.check_button.
-						 check_orig_h) / 2),
-					       dii->item.check_button.
-					       check_orig_w,
-					       dii->item.check_button.
-					       check_orig_h);
+					       (dii->h -
+						dii->item.check_button.orig_h) /
+					       2, dii->item.check_button.orig_w,
+					       dii->item.check_button.orig_h);
 			  if (dii->type == DITEM_RADIOBUTTON)
-			     EMoveResizeWindow(dii->item.radio_button.
-					       radio_win, dii->x,
+			     EMoveResizeWindow(dii->item.radio_button.radio_win,
+					       dii->x,
 					       dii->y +
-					       ((dii->h -
-						 dii->item.radio_button.
-						 radio_orig_h) / 2),
-					       dii->item.radio_button.
-					       radio_orig_w,
-					       dii->item.radio_button.
-					       radio_orig_h);
+					       (dii->h -
+						dii->item.radio_button.orig_h) /
+					       2, dii->item.radio_button.orig_w,
+					       dii->item.radio_button.orig_h);
 			  if (dii->type == DITEM_AREA)
 			    {
 			       pad = ImageclassGetPadding(dii->iclass);
@@ -1219,13 +1219,10 @@ DialogRealizeItem(Dialog * d, DItem * di)
 			       if (dii->win)
 				  EMoveResizeWindow(dii->win,
 						    dii->x +
-						    dii->item.slider.
-						    numeric_x,
+						    dii->item.slider.numeric_x,
 						    dii->y +
-						    dii->item.slider.
-						    numeric_y,
-						    dii->item.slider.
-						    numeric_w,
+						    dii->item.slider.numeric_y,
+						    dii->item.slider.numeric_w,
 						    dii->item.slider.numeric_h);
 			    }
 		       }
@@ -1240,6 +1237,7 @@ DialogRealizeItem(Dialog * d, DItem * di)
 			  r++;
 		       }
 		  }
+	      bail_out:
 		Efree(col_size);
 		Efree(row_size);
 	     }
@@ -1286,12 +1284,12 @@ MoveTableBy(Dialog * d, DItem * di, int dx, int dy)
 	  case DITEM_CHECKBUTTON:
 	     EMoveWindow(dii->item.check_button.check_win, dii->x,
 			 dii->y +
-			 ((dii->h - dii->item.check_button.check_orig_h) / 2));
+			 ((dii->h - dii->item.check_button.orig_h) / 2));
 	     break;
 	  case DITEM_RADIOBUTTON:
 	     EMoveWindow(dii->item.radio_button.radio_win, dii->x,
 			 dii->y +
-			 ((dii->h - dii->item.radio_button.radio_orig_h) / 2));
+			 ((dii->h - dii->item.radio_button.orig_h) / 2));
 	     break;
 	  case DITEM_SLIDER:
 	     {
@@ -1498,8 +1496,8 @@ DialogDrawItem(Dialog * d, DItem * di)
 	     TextclassGetTextState(di->tclass, state, 0, 0)))
 	   break;
 	pad = ImageclassGetPadding(di->iclass);
-	x = di->x + di->item.check_button.check_orig_w + pad->left;
-	w = di->w - di->item.check_button.check_orig_w - pad->left;
+	x = di->x + di->item.check_button.orig_w + pad->left;
+	w = di->w - di->item.check_button.orig_w - pad->left;
 	goto draw_text;
 
      case DITEM_RADIOBUTTON:
@@ -1517,8 +1515,8 @@ DialogDrawItem(Dialog * d, DItem * di)
 	     TextclassGetTextState(di->tclass, state, 0, 0)))
 	   break;
 	pad = ImageclassGetPadding(di->iclass);
-	x = di->x + di->item.radio_button.radio_orig_w + pad->left;
-	w = di->w - di->item.radio_button.radio_orig_w - pad->left;
+	x = di->x + di->item.radio_button.orig_w + pad->left;
+	w = di->w - di->item.radio_button.orig_w - pad->left;
 	goto draw_text;
 
      default:
@@ -1605,12 +1603,6 @@ DialogItemSetText(DItem * di, const char *text)
       DialogDrawItems(di->dlg, di, di->x, di->y, di->w, di->h);
 }
 
-void
-DialogItemRadioButtonSetEventFunc(DItem * di, DialogItemCallbackFunc * func)
-{
-   di->item.radio_button.event_func = func;
-}
-
 void
 DialogItemRadioButtonSetFirst(DItem * di, DItem * first)
 {
@@ -2168,11 +2160,6 @@ DItemEventMouseIn(Win win __UNUSED__, DItem * di, XEvent * ev)
 	if (di->item.area.event_func)
 	   di->item.area.event_func(di, 0, ev);
 	break;
-
-     case DITEM_RADIOBUTTON:
-	if (di->item.radio_button.event_func)
-	   di->item.radio_button.event_func(di, di->item.radio_button.val, ev);
-	break;
      }
 
    di->hilited = 1;
@@ -2189,12 +2176,6 @@ DItemEventMouseOut(Win win __UNUSED__, DItem * di, XEvent * ev)
 	if (di->item.area.event_func)
 	   di->item.area.event_func(di, 0, ev);
 	break;
-
-     case DITEM_RADIOBUTTON:
-	if (di->item.radio_button.event_func)
-	   di->item.radio_button.event_func(di, di->item.radio_button.val,
-					    NULL);
-	break;
      }
 
    if (!di->clicked)
