@@ -824,7 +824,7 @@ ECompMgrWinSetExtents(EObj * eo)
    D1printf("extents %#lx %d %d %d %d\n", EobjGetXwin(eo), r.x, r.y, r.width,
 	    r.height);
 
-   if (EDebug(EDBUG_TYPE_COMPMGR))
+   if (EDebug(EDBUG_TYPE_COMPMGR2))
       ERegionShow("extents", cw->extents, NULL);
 }
 
@@ -837,6 +837,13 @@ ECompMgrWinSetShape(EObj * eo)
 
    if (cw->shape == None)
      {
+#if 0				/* FIXME - TBD */
+	/* If the window shape is changed on OR windows, cw->shape set below
+	 * may not reflect the shape change. Adding a sync fixes things in
+	 * some situations. */
+	if (eo->type == EOBJ_TYPE_EXT)
+	   ESync(0);
+#endif
 	cw->shape = ERegionCreateFromWindow(EobjGetWin(eo));
 
 	if (WinIsShaped(EobjGetWin(eo)))
@@ -861,7 +868,7 @@ ECompMgrWinSetShape(EObj * eo)
    cw->have_shape = 1;
 
    D1printf("shape %#lx: %d %d\n", EobjGetXwin(eo), cw->shape_x, cw->shape_y);
-   if (EDebug(EDBUG_TYPE_COMPMGR))
+   if (EDebug(EDBUG_TYPE_COMPMGR2))
       ERegionShow("shape", cw->shape, NULL);
 }
 
@@ -884,6 +891,12 @@ ECompMgrWinGetPixmap(const EObj * eo)
    return cw->pixmap;
 }
 
+Picture
+ECompMgrWinGetAlphaPict(const EObj * eo)
+{
+   return (eo->cmhook) ? eo->cmhook->pict_alpha : None;
+}
+
 static void
 ECompMgrWinInvalidate(EObj * eo, int what)
 {
@@ -893,7 +906,7 @@ ECompMgrWinInvalidate(EObj * eo, int what)
    if (!cw)
       return;
 
-   D2printf("ECompMgrWinInvalidate %#lx: %#x\n", EobjGetXwin(eo), what);
+   D1printf("ECompMgrWinInvalidate %#lx: %#x\n", EobjGetXwin(eo), what);
 
    if ((what & (INV_SIZE | INV_PIXMAP)) && cw->pixmap != None)
      {
@@ -1170,7 +1183,7 @@ ECompMgrWinSetPicts(EObj * eo)
        (Mode_compmgr.use_pixmap || (eo->fade && Conf_compmgr.fading.enable)))
      {
 	cw->pixmap = EWindowGetPixmap(EobjGetWin(eo));
-	D2printf("ECompMgrWinSetPicts %#lx: Pmap=%#lx\n", EobjGetXwin(eo),
+	D1printf("ECompMgrWinSetPicts %#lx: Pmap=%#lx\n", EobjGetXwin(eo),
 		 cw->pixmap);
      }
 
@@ -1189,11 +1202,11 @@ ECompMgrWinSetPicts(EObj * eo)
 	pa.subwindow_mode = IncludeInferiors;
 	cw->picture = XRenderCreatePicture(disp, draw,
 					   pictfmt, CPSubwindowMode, &pa);
-	D2printf("ECompMgrWinSetPicts %#lx: Pict=%#lx (drawable=%#lx)\n",
+	D1printf("ECompMgrWinSetPicts %#lx: Pict=%#lx (drawable=%#lx)\n",
 		 EobjGetXwin(eo), cw->picture, draw);
 
-	/* Hmm.. What good does this actually do? */
-	if (draw == cw->pixmap && EobjIsShaped(eo))
+#if 0				/* Pixmap must be clipped by window shape */
+	if (draw == cw->pixmap && WinIsShaped(EobjGetWin(eo)))
 	  {
 	     XserverRegion       clip;
 
@@ -1201,6 +1214,7 @@ ECompMgrWinSetPicts(EObj * eo)
 	     EPictureSetClip(cw->picture, clip);
 	     ERegionDestroy(clip);
 	  }
+#endif
      }
 }
 
@@ -1233,6 +1247,8 @@ ECompMgrWinNew(EObj * eo)
 	eo->fade = 0;
 	eo->shadow = 0;
      }
+   if (eo->type == EOBJ_TYPE_EXT)
+      XShapeSelectInput(disp, EobjGetXwin(eo), ShapeNotifyMask);
 
    if (eo->noredir)
      {
@@ -1618,6 +1634,9 @@ ECompMgrDetermineOrder(EObj * const *lst, int num, EObj ** first,
 	if ((!eo->shown && !eo->fading) || eo->desk != dsk)
 	   continue;
 
+	if (EobjHasEmptyShape(eo))
+	   continue;
+
 	/* Region of shaped window in screen coordinates */
 	if (!cw->have_shape)
 	   ECompMgrWinSetShape(eo);
@@ -1754,6 +1773,25 @@ ECompMgrRepaintObjSetClip(XserverRegion rgn, XserverRegion damage,
    return rgn;
 }
 
+static              XserverRegion
+ECompMgrRepaintObjSetClip2(EObj * eo, XserverRegion clip, int x, int y)
+{
+#if 1
+   /* This is only needed when source clipping in XRenderComposite() is broken.
+    * otherwise it should be possible to set the source clip mask in
+    * ECompMgrWinSetPicts() (when needed, i.e. source pict is pixmap). */
+   if (WinIsShaped(EobjGetWin(eo)))
+     {
+	clip = ERegionCopy(rgn_tmp, clip);
+	ERegionIntersectOffset(clip, x, y, eo->cmhook->shape, rgn_tmp2);
+     }
+#else
+   eo = NULL;
+   x = y = 0;
+#endif
+   return clip;
+}
+
 static void
 ECompMgrRepaintObj(Picture pbuf, XserverRegion region, EObj * eo, int mode)
 {
@@ -1762,7 +1800,7 @@ ECompMgrRepaintObj(Picture pbuf, XserverRegion region, EObj * eo, int mode)
    ECmWinInfo         *cw;
    Desk               *dsk = eo->desk;
    int                 x, y;
-   XserverRegion       clip;
+   XserverRegion       clip, clip2;
    Picture             alpha;
 
    cw = eo->cmhook;
@@ -1789,9 +1827,10 @@ ECompMgrRepaintObj(Picture pbuf, XserverRegion region, EObj * eo, int mode)
 	  case WINDOW_UNREDIR:
 	  case WINDOW_SOLID:
 	     clip = ECompMgrRepaintObjSetClip(rgn_clip, region, cw->clip, x, y);
+	     clip2 = ECompMgrRepaintObjSetClip2(eo, clip, x, y);
 	     if (EDebug(EDBUG_TYPE_COMPMGR2))
 		ECompMgrWinDumpInfo("ECompMgrRepaintObj solid", eo, clip, 0);
-	     EPictureSetClip(pbuf, clip);
+	     EPictureSetClip(pbuf, clip2);
 	     XRenderComposite(dpy, PictOpSrc, cw->picture, None, pbuf,
 			      0, 0, 0, 0, x + cw->rcx, y + cw->rcy, cw->rcw,
 			      cw->rch);
@@ -1811,9 +1850,10 @@ ECompMgrRepaintObj(Picture pbuf, XserverRegion region, EObj * eo, int mode)
 	  case WINDOW_TRANS:
 	  case WINDOW_ARGB:
 	     clip = ECompMgrRepaintObjSetClip(rgn_clip, region, cw->clip, x, y);
+	     clip2 = ECompMgrRepaintObjSetClip2(eo, clip, x, y);
 	     if (EDebug(EDBUG_TYPE_COMPMGR2))
 		ECompMgrWinDumpInfo("ECompMgrRepaintObj trans", eo, clip, 0);
-	     EPictureSetClip(pbuf, clip);
+	     EPictureSetClip(pbuf, clip2);
 	     if (cw->opacity != OPAQUE && !cw->pict_alpha)
 		cw->pict_alpha =
 		   EPictureCreateSolid(Mode_compmgr.root, True,
@@ -1908,6 +1948,7 @@ ECompMgrPaintGhosts(Picture pict, XserverRegion damage)
 	/* Subtract window region from damage region */
 	ERegionSubtract(damage, eo->cmhook->shape);
      }
+   EPictureSetClip(pict, None);
 }
 
 void
@@ -2376,6 +2417,11 @@ ECompMgrHandleWindowEvent(Win win __UNUSED__, XEvent * ev, void *prm)
 	break;
 #endif
 
+     case EX_EVENT_SHAPE_NOTIFY:
+	/* Only EOBJ_TYPE_EXT window shape changes will go here */
+	ECompMgrWinChangeShape(eo);
+	break;
+
      case EX_EVENT_DAMAGE_NOTIFY:
 	ECompMgrWinDamage(eo, ev);
 	break;
@@ -2619,6 +2665,7 @@ static const CfgItem CompMgrCfgItems[] = {
  * Module descriptor
  */
 extern const EModule ModCompMgr;
+
 const EModule       ModCompMgr = {
    "compmgr", "cm",
    ECompMgrSighan,
