@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2009 Kim Woelders
+ * Copyright (C) 2004-2010 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -604,7 +604,25 @@ EDrawableDumpImage(Drawable draw, const char *txt)
 #endif
 
 void
-FreePmapMask(PmapMask * pmm)
+PmapMaskInit(PmapMask * pmm, Win win, int w, int h)
+{
+   if (pmm->pmap)
+     {
+	if (pmm->w == w && pmm->h == h && pmm->depth == WinGetDepth(win))
+	   return;
+	PmapMaskFree(pmm);
+     }
+
+   pmm->type = 0;
+   pmm->depth = WinGetDepth(win);
+   pmm->pmap = ECreatePixmap(win, w, h, 0);
+   pmm->mask = None;
+   pmm->w = w;
+   pmm->h = h;
+}
+
+void
+PmapMaskFree(PmapMask * pmm)
 {
    /* type !=0: Created by imlib_render_pixmaps_for_whole_image... */
    if (pmm->pmap)
