@@ -40,6 +40,9 @@
 #if USE_XRANDR
 #include <X11/extensions/Xrandr.h>
 #endif
+#if USE_XINERAMA
+#include <X11/extensions/Xinerama.h>
+#endif
 #if USE_COMPOSITE
 #include <X11/extensions/Xcomposite.h>
 #include <X11/extensions/Xdamage.h>
@@ -62,24 +65,24 @@ static const char  *EventName(unsigned int type);
  */
 
 typedef struct {
-   int                 event_base, error_base;
    int                 major, minor;
+   int                 major_op, event_base, error_base;
 } EServerExtData;
 
 typedef struct {
    const char         *name;
    unsigned int        ix;
-   int                 (*query_ext) (Display * dpy, int *event, int *error);
    int                 (*query_ver) (Display * dpy, int *major, int *minor);
    void                (*init) (int avaliable);
 } EServerExt;
 
-static EServerExtData ExtData[8];
+static EServerExtData ExtData[11];
 
 #define event_base_shape ExtData[XEXT_SHAPE].event_base
 #define event_base_randr ExtData[XEXT_RANDR].event_base
 #define event_base_damage ExtData[XEXT_DAMAGE].event_base
 #define event_base_saver  ExtData[XEXT_SCRSAVER].event_base
+#define major_op_xi       ExtData[XEXT_XI].major_op
 
 static void
 ExtInitShape(int available)
@@ -111,7 +114,7 @@ ExtInitSync(int available)
      {
 	if (!strcmp(xssc[i].name, "SERVERTIME"))
 	   Mode.display.server_time = xssc[i].counter;
-	if (EDebug(EDBUG_TYPE_SYNC))
+	if (EDebug(EDBUG_TYPE_VERBOSE))
 	   Eprintf(" Sync counter %2d: %10s %#lx %#x:%#x\n", i,
 		   xssc[i].name, xssc[i].counter,
 		   XSyncValueHigh32(xssc[i].resolution),
@@ -148,25 +151,61 @@ ExtInitSS(int available)
 static void
 ExtInitRR(int available)
 {
+   Rotation            rot;
+
    if (!available)
       return;
 
    /* Listen for RandR events */
    XRRSelectInput(disp, WinGetXwin(VROOT), RRScreenChangeNotifyMask);
+   XRRRotations(disp, Dpy.screen, &rot);
+   Mode.screen.rotation = rot;
+
+#if 0				/* Debug */
+   if (EDebug(EDBUG_TYPE_VERBOSE))
+     {
+	XRRScreenResources *psr;
+	XRRCrtcInfo        *pci;
+	XRROutputInfo      *poi;
+	int                 i;
+
+	psr = XRRGetScreenResources(disp, WinGetXwin(VROOT));
+	if (!psr)
+	   return;
+
+	Eprintf("CRTC  ID      X,Y         WxH     mode   rot   nout\n");
+	for (i = 0; i < psr->ncrtc; i++)
+	  {
+	     pci = XRRGetCrtcInfo(disp, psr, psr->crtcs[i]);
+	     if (!pci)
+		break;
+	     Eprintf("%3d  %#04lx  %4d,%4d   %4ux%4u  %#04lx %4d %5d\n",
+		     i, psr->crtcs[i],
+		     pci->x, pci->y, pci->width, pci->height,
+		     pci->mode, pci->rotation, pci->noutput);
+	     XRRFreeCrtcInfo(pci);
+	  }
+
+	Eprintf("OUTP  ID  Name            WxH     crtc  ncrtc nclon nmode\n");
+	for (i = 0; i < psr->noutput; i++)
+	  {
+	     poi = XRRGetOutputInfo(disp, psr, psr->outputs[i]);
+	     if (!poi)
+		break;
+	     Eprintf("%3d  %#04lx %-8s     %4lux%4lu  %#04lx %4d %5d %5d\n",
+		     i, psr->outputs[i],
+		     poi->name, poi->mm_width, poi->mm_height,
+		     poi->crtc, poi->ncrtc, poi->nclone, poi->nmode);
+	     XRRFreeOutputInfo(poi);
+	  }
+
+	XRRFreeScreenResources(psr);
+     }
+#endif
 }
 #endif
 
 #if USE_XI2
-static int          xi_major_op = 0;
-
-static              Bool
-EInputQueryExtension(Display * dpy,
-		     int *event_base_return, int *error_base_return)
-{
-   return XQueryExtension(dpy, "XInputExtension", &xi_major_op,
-			  event_base_return, error_base_return);
-}
-
 static              Status
 EInputQueryVersion(Display * dpy,
 		   int *major_version_return, int *minor_version_return)
@@ -215,30 +254,30 @@ ExtInitInput(int available)
 #endif
 
 static const EServerExt Extensions[] = {
-   {"Shape", XEXT_SHAPE, XShapeQueryExtension, XShapeQueryVersion,
-    ExtInitShape},
+   {"SHAPE", XEXT_SHAPE, XShapeQueryVersion, ExtInitShape},
 #if USE_XSYNC
-   {"Sync", XEXT_SYNC, XSyncQueryExtension, XSyncInitialize, ExtInitSync},
+   {"SYNC", XEXT_SYNC, XSyncInitialize, ExtInitSync},
 #endif
 #if USE_XSCREENSAVER
-   {"ScrSaver", XEXT_SCRSAVER, XScreenSaverQueryExtension,
-    XScreenSaverQueryVersion, ExtInitSS},
+   {"MIT-SCREEN-SAVER", XEXT_SCRSAVER, XScreenSaverQueryVersion, ExtInitSS},
 #endif
 #if USE_XRANDR
-   {"RandR", XEXT_RANDR, XRRQueryExtension, XRRQueryVersion, ExtInitRR},
+   {"RANDR", XEXT_RANDR, XRRQueryVersion, ExtInitRR},
+#endif
+#if USE_XINERAMA
+   {"XINERAMA", XEXT_XINERAMA, XineramaQueryVersion, NULL},
 #endif
 #if USE_COMPOSITE
-   {"Composite", XEXT_COMPOSITE, XCompositeQueryExtension,
-    XCompositeQueryVersion, NULL},
-   {"Damage", XEXT_DAMAGE, XDamageQueryExtension, XDamageQueryVersion, NULL},
-   {"Fixes", XEXT_FIXES, XFixesQueryExtension, XFixesQueryVersion, NULL},
-   {"Render", XEXT_RENDER, XRenderQueryExtension, XRenderQueryVersion, NULL},
+   {"Composite", XEXT_COMPOSITE, XCompositeQueryVersion, NULL},
+   {"DAMAGE", XEXT_DAMAGE, XDamageQueryVersion, NULL},
+   {"XFIXES", XEXT_FIXES, XFixesQueryVersion, NULL},
+   {"RENDER", XEXT_RENDER, XRenderQueryVersion, NULL},
 #endif
 #if USE_GLX
-   {"GLX", XEXT_GLX, glXQueryExtension, glXQueryVersion, NULL},
+   {"GLX", XEXT_GLX, glXQueryVersion, NULL},
 #endif
 #if USE_XI2
-   {"Input", XEXT_XI, EInputQueryExtension, EInputQueryVersion, ExtInitInput},
+   {"XInputExtension", XEXT_XI, EInputQueryVersion, ExtInitInput},
 #endif
 };
 
@@ -248,7 +287,8 @@ ExtQuery(const EServerExt * ext)
    int                 available;
    EServerExtData     *exd = ExtData + ext->ix;
 
-   available = ext->query_ext(disp, &(exd->event_base), &(exd->error_base));
+   available = XQueryExtension(disp, ext->name, &(exd->major_op),
+			       &(exd->event_base), &(exd->error_base));
 
    if (available)
      {
@@ -257,9 +297,10 @@ ExtQuery(const EServerExt * ext)
 	ext->query_ver(disp, &(exd->major), &(exd->minor));
 
 	if (EDebug(EDBUG_TYPE_VERBOSE))
-	   Eprintf("Found extension %-10s version %d.%d -"
-		   " Event/error base = %d/%d\n", ext->name,
-		   exd->major, exd->minor, exd->event_base, exd->error_base);
+	   Eprintf("Extension %-15s version %d.%d -"
+		   " req/evt/err base = %3d/%3d/%3d\n", ext->name,
+		   exd->major, exd->minor,
+		   exd->major_op, exd->event_base, exd->error_base);
      }
 
    if (ext->init)
@@ -271,7 +312,9 @@ ExtQuery(const EServerExt * ext)
  */
 
 struct _EventFdDesc {
+#if 0				/* Unused */
    const char         *name;
+#endif
    int                 fd;
    void                (*handler) (void);
 };
@@ -324,14 +367,50 @@ EventsInit(void)
    EventFdRegister(ConnectionNumber(disp), NULL);
 }
 
+static const char  *
+EventsGetExtensionName(int req)
+{
+   unsigned int        i;
+   EServerExtData     *exd;
+
+   for (i = 0; i < sizeof(Extensions) / sizeof(EServerExt); i++)
+     {
+	exd = ExtData + Extensions[i].ix;
+	if (req == exd->major_op)
+	   return Extensions[i].name;
+     }
+
+   return "?";
+}
+
+void
+EventShowError(const XErrorEvent * ev)
+{
+   Display            *dpy = disp;
+   char                buf[64], buf1[64];
+
+   if (ev->request_code < 128)
+      Esnprintf(buf, sizeof(buf), "%d", ev->request_code);
+   else
+      Esnprintf(buf, sizeof(buf), "%s.%d",
+		EventsGetExtensionName(ev->request_code), ev->minor_code);
+   XGetErrorDatabaseText(dpy, "XRequest", buf, "", buf1, sizeof(buf1));
+   XGetErrorText(dpy, ev->error_code, buf, sizeof(buf));
+   Eprintf("*** ERROR: xid=%#lx req=%i/%i err=%i: %s: %s\n",
+	   ev->resourceid, ev->request_code, ev->minor_code,
+	   ev->error_code, buf1, buf);
+}
+
 int
-EventsGetXY(int *px, int *py)
+EventsUpdateXY(int *px, int *py)
 {
    int                 ss;
 
-   ss = EQueryPointer(NULL, px, py, NULL, NULL);
-   Mode.events.cx = *px;
-   Mode.events.cy = *py;
+   ss = EQueryPointer(NULL, &Mode.events.cx, &Mode.events.cy, NULL, NULL);
+   if (px)
+      *px = Mode.events.cx;
+   if (py)
+      *py = Mode.events.cy;
 
    return ss;
 }
@@ -339,15 +418,14 @@ EventsGetXY(int *px, int *py)
 static void
 ModeGetXY(int rx, int ry)
 {
+   /* Mode.wm.win_x/y should always be 0 if not in window mode */
+   Mode.events.cx = rx - Mode.wm.win_x;
+   Mode.events.cy = ry - Mode.wm.win_y;
    if (Mode.wm.window)
      {
-	ETranslateCoordinates(RROOT, VROOT, rx, ry,
-			      &Mode.events.cx, &Mode.events.cy, NULL);
-     }
-   else
-     {
-	Mode.events.cx = rx;
-	Mode.events.cy = ry;
+	if (rx < Mode.wm.win_x || rx >= Mode.wm.win_x + Mode.wm.win_w ||
+	    ry < Mode.wm.win_y || ry >= Mode.wm.win_y + Mode.wm.win_h)
+	   Mode.events.on_screen = 0;
      }
 }
 
@@ -368,6 +446,7 @@ HandleEvent(XEvent * ev)
      case KeyPress:
 	Mode.events.last_keycode = ev->xkey.keycode;
 	Mode.events.last_keystate = ev->xkey.state;
+	/* FALLTHROUGH */
      case KeyRelease:
 	Mode.events.time = ev->xkey.time;
 	ModeGetXY(ev->xkey.x_root, ev->xkey.y_root);
@@ -761,7 +840,7 @@ EventsFetch(XEvent ** evq_p, int *evq_n)
 #if USE_XI2
 	     if (ev->type == GenericEvent)
 	       {
-		  if (ev->xcookie.extension == xi_major_op)
+		  if (ev->xcookie.extension == major_op_xi)
 		     EventFetchXI2(ev);
 		  continue;
 	       }
