@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2009 Kim Woelders
+ * Copyright (C) 2004-2010 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -26,6 +26,7 @@
 #include "desktops.h"
 #include "emodule.h"
 #include "eobj.h"
+#include "events.h"
 #include "ewins.h"
 #include "ewin-ops.h"
 #include "focus.h"
@@ -169,6 +170,9 @@ doEwinMoveResize(EWin * ewin, Desk * dsk, int x, int y, int w, int h, int flags)
    int                 i, num;
    Desk               *pdesk;
 
+   if (ewin->state.zoomed)
+      return;
+
    if (call_depth > 256)
       return;
    call_depth++;
@@ -186,7 +190,7 @@ doEwinMoveResize(EWin * ewin, Desk * dsk, int x, int y, int w, int h, int flags)
      {
 	if (floating == 0)
 	  {
-	     dsk = (pdesk == NULL) ? EoGetDesk(ewin) : pdesk;
+	     dsk = (!pdesk) ? EoGetDesk(ewin) : pdesk;
 	     floating = 1;
 	  }
 	else if (floating == 1)
@@ -530,14 +534,10 @@ EwinIconify(EWin * ewin)
    static int          call_depth = 0;
    EWin              **lst, *e;
    int                 i, num;
-   char                was_shaded;
 
    if (!ewin)
       return;
 
-   if (GetZoomEWin() == ewin)
-      Zoom(NULL);
-
    if (ewin->state.inhibit_iconify)
       return;
 
@@ -548,7 +548,10 @@ EwinIconify(EWin * ewin)
       return;
    call_depth++;
 
-   was_shaded = ewin->state.shaded;
+   Zoom(ewin, 0);
+
+   /* Save position at which the window was iconified */
+   EwinRememberPositionSet(ewin);
 
    if (!EwinIsTransient(ewin))
       ModulesSignal(ESIGNAL_EWIN_ICONIFY, ewin);
@@ -556,12 +559,6 @@ EwinIconify(EWin * ewin)
    ewin->state.iconified = 1;
    EwinHide(ewin);
 
-   /* Save position at which the window was iconified */
-   EwinRememberPositionSet(ewin);
-
-   if (was_shaded != ewin->state.shaded)
-      EwinInstantShade(ewin, 0);
-
    ICCCM_Iconify(ewin);
 
    lst = EwinListTransients(ewin, &num, 0);
@@ -757,7 +754,7 @@ EwinInstantShade(EWin * ewin, int force)
    if ((ewin->border->border.left == 0) && (ewin->border->border.right == 0)
        && (ewin->border->border.top == 0) && (ewin->border->border.bottom == 0))
       return;
-   if (GetZoomEWin() == ewin)
+   if (ewin->state.zoomed)
       return;
    if (ewin->state.shaded && !force)
       return;
@@ -778,7 +775,7 @@ EwinInstantShade(EWin * ewin, int force)
 	break;
      case 1:
 	att.win_gravity = WestGravity;
-	if (!Mode.wm.startup)
+	if (!force)
 	   x = x + w - minw;
 	w = minw;
 	break;
@@ -788,7 +785,7 @@ EwinInstantShade(EWin * ewin, int force)
 	break;
      case 3:
 	att.win_gravity = SouthGravity;
-	if (!Mode.wm.startup)
+	if (!force)
 	   y = y + h - minh;
 	h = minh;
 	break;
@@ -798,7 +795,7 @@ EwinInstantShade(EWin * ewin, int force)
    ewin->state.shaded = 2;
    EoMoveResize(ewin, x, y, w, h);
    EMoveResizeWindow(ewin->win_container, -30, -30, 1, 1);
-   EwinBorderCalcSizes(ewin, 1);
+   EwinMoveResize(ewin, x, y, ewin->client.w, ewin->client.h);
 }
 
 void
@@ -807,32 +804,23 @@ EwinInstantUnShade(EWin * ewin)
    XSetWindowAttributes att;
    int                 x, y, w, h;
 
-   if (GetZoomEWin() == ewin)
+   if (ewin->state.zoomed)
       return;
    if (!ewin->state.shaded)
       return;
 
    x = EoGetX(ewin);
    y = EoGetY(ewin);
-   w = EoGetW(ewin);
-   h = EoGetH(ewin);
 
    switch (ewin->border->shadedir)
      {
      default:
-     case 0:
-	w = ewin->client.w + ewin->border->border.left +
-	   ewin->border->border.right;
 	break;
      case 1:
 	w = ewin->client.w + ewin->border->border.left +
 	   ewin->border->border.right;
 	x = x + EoGetW(ewin) - w;
 	break;
-     case 2:
-	h = ewin->client.h + ewin->border->border.top +
-	   ewin->border->border.bottom;
-	break;
      case 3:
 	h = ewin->client.h + ewin->border->border.top +
 	   ewin->border->border.bottom;
@@ -843,6 +831,9 @@ EwinInstantUnShade(EWin * ewin)
    /* Reset gravity */
    att.win_gravity = NorthWestGravity;
    EChangeWindowAttributes(EwinGetClientWin(ewin), CWWinGravity, &att);
+   /* Force move after gravity change */
+   EWindowSetGeometry(EwinGetClientWin(ewin), -1, -1,
+		      ewin->client.w, ewin->client.h, 0);
 
    ewin->state.shaded = 0;
    EwinMoveResize(ewin, x, y, ewin->client.w, ewin->client.h);
@@ -862,7 +853,7 @@ typedef struct {
    int                 k, dk;
    _xywh               start;
    _xywh               final;
-   int                 a, b, c, d;
+   int                 a, b, c;
 } _ewin_shade_data;
 
 static void
@@ -1048,7 +1039,7 @@ EwinShade(EWin * ewin)
    if ((ewin->border->border.left == 0) && (ewin->border->border.right == 0) &&
        (ewin->border->border.top == 0) && (ewin->border->border.bottom == 0))
       return;
-   if (GetZoomEWin() == ewin)
+   if (ewin->state.zoomed)
       return;
    if (ewin->state.shaded || ewin->state.shading || ewin->state.iconified)
       return;
@@ -1270,7 +1261,7 @@ EwinUnShade(EWin * ewin)
 {
    _ewin_shade_data   *esd;
 
-   if (GetZoomEWin() == ewin)
+   if (ewin->state.zoomed)
       return;
    TIMER_DEL(ewin->timer);
    if (!ewin->state.shaded || ewin->state.shading || ewin->state.iconified)
@@ -1299,6 +1290,8 @@ EwinOpFullscreen(EWin * ewin, int source __UNUSED__, int on)
 
    if (ewin->state.fullscreen == (unsigned)on)
       return;
+   if (ewin->state.zoomed)
+      return;
 
    if (on)
      {
@@ -1312,7 +1305,18 @@ EwinOpFullscreen(EWin * ewin, int source __UNUSED__, int on)
 	     ewin->save_fs.h = ewin->client.h;
 	     ewin->save_fs.layer = EoGetLayer(ewin);
 	  }
-	ScreenGetAvailableArea(EoGetX(ewin), EoGetY(ewin), &x, &y, &w, &h);
+	if (ewin->state.placed)
+	  {
+	     x = EoGetX(ewin);
+	     y = EoGetY(ewin);
+	  }
+	else
+	  {
+	     EventsUpdateXY(&x, &y);
+	  }
+	ScreenGetAvailableArea(x, y, &x, &y, &w, &h);
+
+	ewin->state.fullscreen = 1;
 
 	/* Fixup if available space doesn't match ICCCM size constraints */
 	ICCCM_SizeMatch(ewin, w, h, &ww, &hh);
@@ -1322,13 +1326,7 @@ EwinOpFullscreen(EWin * ewin, int source __UNUSED__, int on)
 	  }
 	else
 	  {
-	     int                 l, t;
-
-	     l = (w - ww) / 2;
-	     l = (l < 0) ? 0 : l;
-	     t = (h - hh) / 2;
-	     t = (t < 0) ? 0 : t;
-	     b = BorderCreateFiller(l, w - ww - l, t, h - hh - t);
+	     b = BorderCreateFiller(ww, hh, w, h);
 	     w = ww;
 	     h = hh;
 	  }
@@ -1351,7 +1349,6 @@ EwinOpFullscreen(EWin * ewin, int source __UNUSED__, int on)
 	ewin->state.maximizing = 1;
 	EwinMoveResize(ewin, x, y, w, h);
 	ewin->state.maximizing = 0;
-	ewin->state.fullscreen = 1;
 	EwinStateUpdate(ewin);
      }
    else
