@@ -35,6 +35,7 @@
 #include "grabs.h"
 #include "groups.h"
 #include "hints.h"
+#include "screen.h"
 #include "snaps.h"
 #include "timers.h"
 #include "windowmatch.h"
@@ -154,7 +155,6 @@ EwinGetAttributes(EWin * ewin, Win win, Window xwin)
    ewin->client.w = ewin->save_max.w = ewin->save_fs.w = xwa.width;
    ewin->client.h = ewin->save_max.h = ewin->save_fs.h = xwa.height;
    ewin->client.bw = xwa.border_width;
-   ewin->client.cmap = xwa.colormap;
 
    if (EDebug(EDBUG_TYPE_SNAPS))
       Eprintf("Snap get attr  %#lx: %4d+%4d %4dx%4d: %s\n",
@@ -237,6 +237,8 @@ EwinManage(EWin * ewin)
    if (ewin->state.docked)
       ewin->inh_wm.b.border = 1;
 
+   ewin->serial = NextRequest(disp);
+
    frame = EoGetWin(ewin);
    if (!frame)
      {
@@ -354,6 +356,10 @@ EwinConfigure(EWin * ewin)
 
    EwinUpdateOpacity(ewin);
 
+   if ((ewin->border) && (!strcmp(ewin->border->name, "BORDERLESS")) &&
+       EoGetWin(ewin)->argb)
+      EoSetShadow(ewin, 0);
+
    HintsSetWindowState(ewin);
    HintsSetWindowOpacity(ewin);
 
@@ -423,7 +429,7 @@ EwinDestroy(EWin * ewin)
    Efree(ewin->ewmh.wm_icon);
    Efree(ewin->bits);
    Efree(ewin->session_id);
-   FreePmapMask(&ewin->mini_pmm);
+   PmapMaskFree(&ewin->mini_pmm);
    GroupsEwinRemove(ewin);
 
    Efree(ewin);
@@ -612,6 +618,40 @@ EwinGetPosition(const EWin * ewin, int x, int y, int grav, int *px, int *py)
    *py = y;
 }
 
+/*
+ * Keep resizing on-screen window on-screen
+ */
+static void
+EwinKeepOnScreen(const EWin * ewin, int wn, int hn, int *px, int *py)
+{
+   int                 x = *px, y = *py, w, h;
+   int                 sx, sy, sw, sh, xy;
+
+   w = EoGetW(ewin);
+   h = EoGetH(ewin);
+
+   ScreenGetAvailableArea(x, y, &sx, &sy, &sw, &sh);
+
+   /* Quit if not on-screen to begin with */
+   if (x < sx || x + w > sx + sw || y < sy || y + h > sy + sh)
+      return;
+
+   /* Attempt to keep on-screen */
+   xy = sx + sw - (w - ewin->client.w + wn);
+   if (x > xy)
+      x = xy;
+   if (x < sx)
+      x = sx;
+   xy = sy + sh - (h - ewin->client.h + hn);
+   if (y > xy)
+      y = xy;
+   if (y < sy)
+      y = sy;
+
+   *px = x;
+   *py = y;
+}
+
 void
 EwinUpdateShapeInfo(EWin * ewin)
 {
@@ -649,23 +689,26 @@ EwinPropagateShapes(EWin * ewin)
 void
 EwinStateUpdate(EWin * ewin)
 {
+   int                 fs_zo;
+
+   fs_zo = ewin->state.fullscreen || ewin->state.zoomed;
+
    ewin->state.inhibit_actions = ewin->props.no_actions;
    ewin->state.inhibit_focus = !ewin->icccm.need_input ||
       EwinInhGetWM(ewin, focus) || ewin->state.iconified;
 
-   ewin->state.inhibit_move =
-      EwinInhGetUser(ewin, move) || ewin->state.fullscreen;
+   ewin->state.inhibit_move = EwinInhGetUser(ewin, move) || fs_zo;
    ewin->state.inhibit_resize = ewin->state.iconified || ewin->state.shaded ||
       (ewin->props.no_resize_h && ewin->props.no_resize_v) ||
-      EwinInhGetUser(ewin, size) || ewin->state.fullscreen;
+      EwinInhGetUser(ewin, size) || fs_zo;
    ewin->state.inhibit_iconify = EwinInhGetWM(ewin, iconify);
    ewin->state.inhibit_shade = ewin->state.no_border ||
-      ewin->state.iconified || ewin->state.fullscreen;
+      ewin->state.iconified || fs_zo;
    ewin->state.inhibit_stick = 0;
    ewin->state.inhibit_max_hor = ewin->state.inhibit_resize ||
-      ewin->props.no_resize_h || ewin->state.fullscreen;
+      ewin->props.no_resize_h || fs_zo;
    ewin->state.inhibit_max_ver = ewin->state.inhibit_resize ||
-      ewin->props.no_resize_v || ewin->state.fullscreen;
+      ewin->props.no_resize_v || fs_zo;
    ewin->state.inhibit_fullscreeen =
       ewin->state.inhibit_move || ewin->state.inhibit_resize;
    ewin->state.inhibit_change_desk = ewin->state.iconified;
@@ -852,28 +895,25 @@ AddToFamily(EWin * ewin, Window xwin, int startup)
 	/* Place the window below the mouse pointer */
 	if (Conf.place.manual_mouse_pointer)
 	  {
-	     int                 cx, cy;
+	     int                 cx, cy, sx, sy, sw, sh;
 
 	     /* if the loser has manual placement on and the app asks to be on */
 	     /*  a desktop, then send E to that desktop so the user can place */
 	     /* the window there */
 	     DeskGoto(dsk);
 
-	     EventsGetXY(&cx, &cy);
+	     EventsUpdateXY(&cx, &cy);
+	     ScreenGetAvailableArea(cx, cy, &sx, &sy, &sw, &sh);
 
 	     /* try to center the window on the mouse pointer */
-	     cx -= EoGetW(ewin) / 2;
-	     cy -= EoGetH(ewin) / 2;
+	     x = cx - EoGetW(ewin) / 2;
+	     y = cy - EoGetH(ewin) / 2;
 
 	     /* keep it all on this screen if possible */
-	     cx = MIN(cx, WinGetW(VROOT) - EoGetW(ewin));
-	     cy = MIN(cy, WinGetH(VROOT) - EoGetH(ewin));
-	     cx = MAX(cx, 0);
-	     cy = MAX(cy, 0);
-
-	     /* this works for me... */
-	     x = cx;
-	     y = cy;
+	     x = MIN(x, sx + sw - EoGetW(ewin));
+	     y = MIN(y, sy + sh - EoGetH(ewin));
+	     x = MAX(x, sx);
+	     y = MAX(y, sy);
 	  }
 	else if (ewin->ewmh.type.b.dialog)
 	  {
@@ -907,19 +947,18 @@ AddToFamily(EWin * ewin, Window xwin, int startup)
    /* if we should slide it in and are not currently in the middle of a slide */
    if ((manplace) && (!ewin->state.placed))
      {
-	int                 rx, ry;
+	int                 cx, cy;
 
 	/* if the loser has manual placement on and the app asks to be on */
 	/*  a desktop, then send E to that desktop so the user can place */
 	/* the window there */
 	DeskGoto(dsk);
 
-	EQueryPointer(NULL, &rx, &ry, NULL, NULL);
-	Mode.events.cx = rx;
-	Mode.events.cy = ry;
+	EventsUpdateXY(&cx, &cy);
+
 	ewin->state.placed = 1;
-	x = Mode.events.cx - 8;
-	y = Mode.events.cy - 8;
+	x = cx - 8;
+	y = cy - 8;
 	GrabPointerSet(VROOT, ECSR_GRAB, 0);
 	EoSetFloating(ewin, 1);	/* Causes reparenting to root */
 	EwinOpFloatAt(ewin, OPSRC_USER, x, y);
@@ -1017,8 +1056,7 @@ EwinUnmap1(EWin * ewin)
 {
    /* The client may have been unmapped but the frame is not yet */
 
-   if (GetZoomEWin() == ewin)
-      Zoom(NULL);
+   Zoom(ewin, 0);
 
    MoveResizeEnd(ewin);
 }
@@ -1040,7 +1078,6 @@ EwinUnmap2(EWin * ewin)
 static void
 EwinWithdraw(EWin * ewin, Win to)
 {
-   Window              win;
    int                 x, y;
 
    /* Only external clients should go here */
@@ -1061,7 +1098,7 @@ EwinWithdraw(EWin * ewin, Win to)
 	y = ewin->client.y;
 	ETranslateCoordinates(EwinGetClientWin(ewin), VROOT,
 			      -ewin->border->border.left,
-			      -ewin->border->border.top, &x, &y, &win);
+			      -ewin->border->border.top, &x, &y, NULL);
 	EReparentWindow(EwinGetClientWin(ewin), to, x, y);
 	HintsDelWindowHints(ewin);
      }
@@ -1072,14 +1109,18 @@ EwinWithdraw(EWin * ewin, Win to)
 }
 
 static void
-EwinEventMapRequest(EWin * ewin, Window win)
+EwinEventMapRequest(EWin * ewin, XEvent * ev)
 {
+   Window              xwin;
+
+   xwin = ev->xmaprequest.window;
+
    if (ewin)
      {
 	if (ewin->state.state == EWIN_STATE_ICONIC)
 	   EwinDeIconify(ewin);
 	else if (ewin->state.state == EWIN_STATE_WITHDRAWN)
-	   AddToFamily(ewin, win, 0);
+	   AddToFamily(ewin, xwin, 0);
 	else
 	  {
 	     Eprintf("AddToFamily: Already managing %s %#lx\n", "A",
@@ -1090,7 +1131,7 @@ EwinEventMapRequest(EWin * ewin, Window win)
    else
      {
 	/* Check if we are already managing it */
-	ewin = EwinFindByClient(win);
+	ewin = EwinFindByClient(xwin);
 
 	/* Some clients MapRequest more than once ?!? */
 	if (ewin)
@@ -1101,7 +1142,7 @@ EwinEventMapRequest(EWin * ewin, Window win)
 	     EwinShow(ewin);
 	  }
 	else
-	   AddToFamily(NULL, win, 0);
+	   AddToFamily(NULL, xwin, 0);
      }
 }
 
@@ -1116,21 +1157,19 @@ EwinEventDestroy(EWin * ewin)
 }
 
 static void
-EwinEventReparent(EWin * ewin)
+EwinEventReparent(EWin * ewin, XEvent * ev)
 {
    Window              parent;
 
    EGrabServer();
 
-   /* Refetch parent window. We cannot rely on the one in the event. */
-   if (EoIsGone(ewin))
-      parent = None;
-   else
-      parent = EXWindowGetParent(EwinGetClientXwin(ewin));
+   parent = EoIsGone(ewin) ? None : ev->xreparent.parent;
+
    if (EDebug(EDBUG_TYPE_EWINS))
       Eprintf("EwinEventReparent %#lx st=%d parent=%#lx: %s\n",
 	      EwinGetClientXwin(ewin), ewin->state.state, parent,
 	      EwinGetTitle(ewin));
+
    if (parent != EwinGetContainerXwin(ewin))
       EwinDestroy(ewin);
 
@@ -1235,16 +1274,18 @@ EwinEventConfigureRequest(EWin * ewin, XEvent * ev)
 	 * ICCCM ones sent by us */
 	if (!EwinInhGetApp(ewin, move))
 	  {
-#if 1				/* FIXME - ??? */
+#if 0				/* FIXME - ??? */
 	     if (ev->xconfigurerequest.value_mask & CWX)
 		x = ev->xconfigurerequest.x;
 	     if (ev->xconfigurerequest.value_mask & CWY)
 		y = ev->xconfigurerequest.y;
 #else
 	     if (ev->xconfigurerequest.value_mask & CWX)
-		x = ev->xconfigurerequest.x - EoGetX(EoGetDesk(ewin));
+		x = ev->xconfigurerequest.x -
+		   (Mode.wm.win_x + EoGetX(EoGetDesk(ewin)));
 	     if (ev->xconfigurerequest.value_mask & CWY)
-		y = ev->xconfigurerequest.y - EoGetY(EoGetDesk(ewin));
+		y = ev->xconfigurerequest.y -
+		   (Mode.wm.win_y + EoGetY(EoGetDesk(ewin)));
 #endif
 	  }
 	if (!EwinInhGetApp(ewin, size))
@@ -1277,6 +1318,11 @@ EwinEventConfigureRequest(EWin * ewin, XEvent * ev)
 	     /* Correct position taking gravity into account */
 	     EwinGetPosition(ewin, x, y, 0, &x, &y);
 	  }
+	else if (ev->xconfigurerequest.value_mask & (CWWidth | CWHeight))
+	  {
+	     /* Resizing only */
+	     EwinKeepOnScreen(ewin, w, h, &x, &y);
+	  }
 
 	Mode.move.check = 0;	/* Don't restrict client requests */
 	EwinMoveResize(ewin, x, y, w, h);
@@ -1804,9 +1850,9 @@ EwinReposition(EWin * ewin)
 }
 
 void
-EwinWarpTo(EWin * ewin)
+EwinWarpTo(EWin * ewin, int force)
 {
-   if (ewin == Mode.mouse_over_ewin)
+   if (!force && ewin == Mode.mouse_over_ewin)
       return;
 
    if (ewin->state.iconified)
@@ -2226,6 +2272,8 @@ EwinsSetFree(void)
  * Event handlers
  */
 
+#define DEBUG_EWIN_EVENTS 0
+
 static int
 ActionsCheck(const char *which, EWin * ewin, XEvent * ev)
 {
@@ -2248,12 +2296,41 @@ ActionsCheck(const char *which, EWin * ewin, XEvent * ev)
    return ActionclassEvent(ac, ev, ewin);
 }
 
-#define DEBUG_EWIN_EVENTS 0
+static EWin        *
+_EwinEventEwinCheck(const char *txt, XEvent * ev, EWin * ewin)
+{
+   if ((int)(ev->xany.serial - ewin->serial) < 0)
+     {
+	Eprintf("%s: %#lx: Ignore obsolete event %d\n", txt,
+		ev->xany.window, ev->type);
+	return NULL;
+     }
+
+   ewin->serial = ev->xany.serial;
+
+   return ewin;
+}
+
+static EWin        *
+_EwinEventEwinFind(XEvent * ev, Window xwin)
+{
+   EWin               *ewin;
+
+   ewin = EwinFindByClient(xwin);
+   if (!ewin)
+      return ewin;
+
+   return _EwinEventEwinCheck("root", ev, ewin);
+}
+
 static void
 EwinHandleEventsToplevel(Win win __UNUSED__, XEvent * ev, void *prm)
 {
    EWin               *ewin = (EWin *) prm;
 
+   if (!_EwinEventEwinCheck("frm", ev, ewin))
+      return;
+
    switch (ev->type)
      {
      case ButtonPress:
@@ -2281,11 +2358,11 @@ static void
 EwinHandleEventsContainer(Win win __UNUSED__, XEvent * ev, void *prm)
 {
    EWin               *ewin = (EWin *) prm;
+   Window              xwin = EwinGetClientXwin(ewin);
+
+   if (!_EwinEventEwinCheck("cont", ev, ewin))
+      return;
 
-#if 0
-   Eprintf("EwinHandleEventsContainer: type=%2d win=%#lx: %s\n",
-	   ev->type, EwinGetClientXwin(ewin), EwinGetTitle(ewin));
-#endif
    switch (ev->type)
      {
      case ButtonPress:
@@ -2293,60 +2370,60 @@ EwinHandleEventsContainer(Win win __UNUSED__, XEvent * ev, void *prm)
 	break;
 
      case MapRequest:
-	if (ev->xmaprequest.window != EwinGetClientXwin(ewin))
+	if (ev->xmaprequest.window != xwin)
 	   break;
-	EwinEventMapRequest(ewin, ev->xmaprequest.window);
+	EwinEventMapRequest(ewin, ev);
 	break;
      case ConfigureRequest:
-	if (ev->xconfigurerequest.window != EwinGetClientXwin(ewin))
+	if (ev->xconfigurerequest.window != xwin)
 	   break;
 	EwinEventConfigureRequest(ewin, ev);
 	break;
      case ResizeRequest:
-	if (ev->xresizerequest.window != EwinGetClientXwin(ewin))
+	if (ev->xresizerequest.window != xwin)
 	   break;
 	EwinEventResizeRequest(ewin, ev);
 	break;
      case CirculateRequest:
-	if (ev->xcirculaterequest.window != EwinGetClientXwin(ewin))
+	if (ev->xcirculaterequest.window != xwin)
 	   break;
 	EwinEventCirculateRequest(ewin, ev);
 	break;
 
      case DestroyNotify:
-	if (ev->xdestroywindow.window != EwinGetClientXwin(ewin))
+	if (ev->xdestroywindow.window != xwin)
 	   break;
 	EwinEventDestroy(ewin);
 	break;
 
      case EX_EVENT_UNMAP_GONE:
-	if (ev->xunmap.window != EwinGetClientXwin(ewin))
+	if (ev->xunmap.window != xwin)
 	   break;
 	EoSetGone(ewin);
 	goto do_unmap;
      case UnmapNotify:
-	if (ev->xunmap.window != EwinGetClientXwin(ewin))
+	if (ev->xunmap.window != xwin)
 	   break;
       do_unmap:
 	EwinEventUnmap(ewin, ev);
 	break;
 
      case MapNotify:
-	if (ev->xmap.window != EwinGetClientXwin(ewin))
+	if (ev->xmap.window != xwin)
 	   break;
 	EwinEventMap(ewin, ev);
 	break;
 
      case EX_EVENT_REPARENT_GONE:
-	if (ev->xreparent.window != EwinGetClientXwin(ewin))
+	if (ev->xreparent.window != xwin)
 	   break;
 	EoSetGone(ewin);
 	goto do_reparent;
      case ReparentNotify:
-	if (ev->xreparent.window != EwinGetClientXwin(ewin))
+	if (ev->xreparent.window != xwin)
 	   break;
       do_reparent:
-	EwinEventReparent(ewin);
+	EwinEventReparent(ewin, ev);
 	break;
 
      case EX_EVENT_MAP_GONE:
@@ -2355,8 +2432,10 @@ EwinHandleEventsContainer(Win win __UNUSED__, XEvent * ev, void *prm)
 	break;
 
      default:
+#if DEBUG_EWIN_EVENTS
 	Eprintf("EwinHandleEventsContainer: type=%2d win=%#lx: %s\n",
-		ev->type, EwinGetClientXwin(ewin), EwinGetTitle(ewin));
+		ev->type, xwin, EwinGetTitle(ewin));
+#endif
 	break;
      }
 }
@@ -2366,6 +2445,9 @@ EwinHandleEventsClient(Win win __UNUSED__, XEvent * ev, void *prm)
 {
    EWin               *ewin = (EWin *) prm;
 
+   if (!_EwinEventEwinCheck("cli", ev, ewin))
+      return;
+
    switch (ev->type)
      {
      case FocusIn:
@@ -2412,7 +2494,7 @@ EwinHandleEventsRoot(Win win __UNUSED__, XEvent * ev, void *prm __UNUSED__)
    switch (ev->type)
      {
      case MapRequest:
-	EwinEventMapRequest(NULL, ev->xmaprequest.window);
+	EwinEventMapRequest(NULL, ev);
 	break;
      case ConfigureRequest:
 #if 0
@@ -2441,7 +2523,7 @@ EwinHandleEventsRoot(Win win __UNUSED__, XEvent * ev, void *prm __UNUSED__)
      case UnmapNotify:
      case EX_EVENT_UNMAP_GONE:
 	/* Catch clients unmapped after MapRequest but before being reparented */
-	ewin = EwinFindByClient(ev->xunmap.window);
+	ewin = _EwinEventEwinFind(ev, ev->xunmap.window);
 	if (!ewin)
 	   break;
 	if (ev->type == EX_EVENT_UNMAP_GONE)
@@ -2451,7 +2533,7 @@ EwinHandleEventsRoot(Win win __UNUSED__, XEvent * ev, void *prm __UNUSED__)
 
      case DestroyNotify:
 	/* Catch clients destroyed after MapRequest but before being reparented */
-	ewin = EwinFindByClient(ev->xdestroywindow.window);
+	ewin = _EwinEventEwinFind(ev, ev->xdestroywindow.window);
 	if (!ewin)
 	   break;
 	EwinEventDestroy(ewin);
@@ -2459,12 +2541,12 @@ EwinHandleEventsRoot(Win win __UNUSED__, XEvent * ev, void *prm __UNUSED__)
 
      case ReparentNotify:
      case EX_EVENT_REPARENT_GONE:
-	ewin = EwinFindByClient(ev->xreparent.window);
+	ewin = _EwinEventEwinFind(ev, ev->xreparent.window);
 	if (!ewin)
 	   break;
 	if (ev->type == EX_EVENT_REPARENT_GONE)
 	   EoSetGone(ewin);
-	EwinEventReparent(ewin);
+	EwinEventReparent(ewin, ev);
 	break;
 
      case ClientMessage:
@@ -2529,6 +2611,7 @@ static const IpcItem EwinsIpcArray[] = {
  * Module descriptor
  */
 extern const EModule ModEwins;
+
 const EModule       ModEwins = {
    "ewins", NULL,
    EwinsSighan,
