@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2009 Kim Woelders
+ * Copyright (C) 2004-2010 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -66,6 +66,7 @@ struct _ewin {
    EObj                o;
    char                type;
    Win                 win_container;
+   unsigned int        serial;
 
    const Border       *border;
    const Border       *normal_border;
@@ -74,7 +75,6 @@ struct _ewin {
    struct {
       Win                 win;
       int                 x, y, w, h, bw;
-      Colormap            cmap;
       long                event_mask;
    } client;
 
@@ -93,6 +93,7 @@ struct _ewin {
       unsigned            maximized_horz:1;
       unsigned            maximized_vert:1;
       unsigned            fullscreen:1;
+      unsigned            zoomed:1;
 
       unsigned            active:1;
       unsigned            modal:1;
@@ -243,7 +244,6 @@ struct _ewin {
    int                 area_x, area_y;
    char               *session_id;
    PmapMask            mini_pmm;
-   int                 mini_w, mini_h;
 
    int                 shape_x, shape_y, shape_w, shape_h;
    int                 req_x, req_y;
@@ -382,7 +382,7 @@ void                EwinUpdateOpacity(EWin * ewin);
 
 void                EwinChange(EWin * ewin, unsigned int flag);
 
-void                EwinWarpTo(EWin * ewin);
+void                EwinWarpTo(EWin * ewin, int force);
 
 EWin              **EwinListTransients(const EWin * ewin, int *num, int group);
 EWin              **EwinListTransientFor(const EWin * ewin, int *num);
@@ -443,7 +443,6 @@ void                EwinOpFullscreen(EWin * ewin, int source, int on);
 /* finders.c */
 EWin               *EwinFindByPtr(const EWin * ewin);
 EWin               *EwinFindByClient(Window win);
-EWin               *EwinFindByChildren(Window win);
 EWin              **EwinsFindByExpr(const char *match, int *pnum, int *pflags);
 EWin               *EwinFindByExpr(const char *match);
 
@@ -477,10 +476,29 @@ int                 EwinListStackIsRaised(const EWin * ewin);
 #define EwinListGetAll EwinListStackGet
 
 /* zoom.c */
-EWin               *GetZoomEWin(void);
+#if ENABLE_ZOOM
+void                Zoom(EWin * ewin, int on);
 void                ReZoom(EWin * ewin);
-char                InZoom(void);
-void                ZoomInit(void);
-void                Zoom(EWin * ewin);
+#else
+#define ReZoom(ewin)   do {} while(0)
+#define Zoom(ewin, on) do {} while(0)
+#endif
+
+typedef struct _ShapeWin ShapeWin;
+struct _ShapeWin {
+   EObj                o;
+   Pixmap              mask;
+   GC                  gc;
+};
+
+ShapeWin           *ShapewinCreate(int md);
+void                ShapewinDestroy(ShapeWin * sw);
+void                ShapewinShapeSet(ShapeWin * sw, int md, int x, int y, int w,
+				     int h, int bl, int br, int bt, int bb,
+				     int seqno);
+
+void                do_draw_mode_1(Drawable dr, GC gc,
+				   int a, int b, int c, int d, int bl, int br,
+				   int bt, int bb);
 
 #endif /* _EWIN_H_ */
