@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2009 Kim Woelders
+ * Copyright (C) 2003-2010 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -26,6 +26,7 @@
 #include "E.h"
 #include "desktops.h"
 #include "e16-ecore_hints.h"
+#include "events.h"
 #include "ewins.h"
 #include "hints.h"
 
@@ -170,6 +171,10 @@ EWMH_Init(Window win_wm_check)
    atom_list[atom_count++] = ECORE_X_ATOM_NET_WM_STRUT;
 
    atom_list[atom_count++] = ECORE_X_ATOM_NET_FRAME_EXTENTS;
+
+   atom_list[atom_count++] = ECORE_X_ATOM_NET_WM_USER_TIME;
+   atom_list[atom_count++] = ECORE_X_ATOM_NET_WM_USER_TIME_WINDOW;
+
    atom_list[atom_count++] = ECORE_X_ATOM_NET_WM_WINDOW_OPACITY;
 
    ecore_x_window_prop_atom_set(WinGetXwin(VROOT),
@@ -828,7 +833,9 @@ EWMH_ProcessPropertyChange(EWin * ewin, Atom atom_change)
      }
    if (atom_change == ECORE_X_ATOM_NET_WM_USER_TIME)
      {
+#if 0				/* Remove? */
 	EWMH_GetWindowUserTime(ewin);
+#endif
 	return 1;
      }
 
@@ -857,12 +864,13 @@ int
 EWMH_ProcessClientClientMessage(EWin * ewin, XClientMessageEvent * ev)
 {
    int                 source;
-   Time                ts;
+
+/* Time                ts; */
 
    if (ev->message_type == ECORE_X_ATOM_NET_ACTIVE_WINDOW)
      {
 	source = OPSRC(ev->data.l[0]);
-	ts = ev->data.l[1];
+/*	ts = ev->data.l[1]; */
 /*	cwin = ev->data.l[2]; */
 	EwinOpActivate(ewin, source, 1);
 	return 1;
@@ -1021,6 +1029,9 @@ EWMH_ProcessClientClientMessage(EWin * ewin, XClientMessageEvent * ev)
    if (ev->message_type == ECORE_X_ATOM_NET_WM_MOVERESIZE)
      {
 /*	source = OPSRC(ev->data.l[4]); */
+
+	EventsUpdateXY(NULL, NULL);
+
 	switch (ev->data.l[2])
 	  {
 	  case _NET_WM_MOVERESIZE_SIZE_TOPLEFT:
