@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2008-2009 Kim Woelders
+ * Copyright (C) 2008-2010 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -59,7 +59,7 @@ EwinFindByClient(Window win)
    return NULL;
 }
 
-EWin               *
+static EWin        *
 EwinFindByChildren(Window win)
 {
    EWin               *const *ewins;
@@ -238,7 +238,7 @@ ListWinGroupMembersForEwin(const EWin * ewin, int action, char nogroup,
       goto done;
 
    ewins = EwinListGetAll(&num);
-   if (ewins == NULL)		/* Should not be possible */
+   if (!ewins)			/* Should not be possible */
       goto done;
 
    /* Loop through window stack, bottom up */
@@ -298,7 +298,7 @@ ListWinGroupMembersForEwin(const EWin * ewin, int action, char nogroup,
      }
 
  done:
-   if (gwins == NULL)
+   if (!gwins)
      {
 	gwins = EMALLOC(EWin *, 1);
 	gwins[0] = (EWin *) ewin;
