@@ -30,6 +30,7 @@
 #include "focus.h"
 #include "grabs.h"
 #include "hints.h"
+#include "icons.h"
 #include "settings.h"
 #include "timers.h"
 #include "xwin.h"
@@ -44,6 +45,7 @@ static EWin        *focus_pending_ewin = NULL;
 static EWin        *focus_pending_new = NULL;
 static EWin        *focus_pending_raise = NULL;
 static Timer       *focus_timer_autoraise = NULL;
+static int          focus_request = 0;
 
 void
 FocusEnable(int on)
@@ -308,7 +310,7 @@ doFocusToEwin(EWin * ewin, int why)
      case FOCUS_CLICK:
 	if (ewin && ewin == Mode.focuswin)
 	   return;
-	if (ewin == NULL)	/* Unfocus */
+	if (!ewin)		/* Unfocus */
 	   break;
 	if (!FocusEwinValid(ewin, 1, why == FOCUS_CLICK, 0))
 	   return;
@@ -321,6 +323,7 @@ doFocusToEwin(EWin * ewin, int why)
 
      case FOCUS_DESK_LEAVE:
 	focus_is_set = 0;
+	/* FALLTHROUGH */
      case FOCUS_NONE:
 	ewin = NULL;
 	if (ewin == Mode.focuswin)
@@ -337,34 +340,45 @@ doFocusToEwin(EWin * ewin, int why)
 
      case FOCUS_EWIN_NEW:
 	if (Conf.focus.all_new_windows_get_focus)
-	   do_focus = 1;
-	else if (Mode.place.doing_manual)
-	   do_focus = 1;
+	   goto check_focus_new;
+
+	if (Mode.place.doing_manual)
+	   goto check_focus_new;
 
 	if (ewin->props.focus_when_mapped)
-	   do_focus = 2;
+	   goto check_focus_new;
+
+	if (Conf.focus.new_windows_get_focus_if_group_focused && Mode.focuswin)
+	  {
+	     if (EwinGetWindowGroup(ewin) == EwinGetWindowGroup(Mode.focuswin))
+		goto check_focus_new;
+	  }
 
 	if (EwinIsTransient(ewin))
 	  {
 	     if (Conf.focus.new_transients_get_focus)
 	       {
-		  do_focus = 2;
+		  do_focus = 1;
 	       }
-	     else if (Conf.focus.new_transients_get_focus_if_group_focused)
+	     else if (Conf.focus.new_transients_get_focus_if_group_focused &&
+		      Mode.focuswin)
 	       {
-		  EWin               *ewin2;
-
-		  ewin2 = EwinFindByClient(EwinGetTransientFor(ewin));
-		  if ((ewin2) && (Mode.focuswin == ewin2))
-		     do_focus = 2;
+		  if ((EwinGetTransientFor(ewin) ==
+		       EwinGetClientXwin(Mode.focuswin)) ||
+		      (EwinGetWindowGroup(ewin) ==
+		       EwinGetWindowGroup(Mode.focuswin)))
+		     do_focus = 1;
 	       }
 
-	     if (do_focus == 2)
-		DeskGotoByEwin(ewin);
+	     if (!do_focus)
+		return;
+	     DeskGotoByEwin(ewin);
+	     goto check_focus_new;
 	  }
 
-	if (!do_focus)
-	   return;
+	return;
+
+      check_focus_new:
 	if (!FocusEwinValid(ewin, 1, 0, 0))
 	   return;
 	break;
@@ -398,7 +412,7 @@ doFocusToEwin(EWin * ewin, int why)
    if (Conf.focus.warp_always)
       do_warp = 1;
    if (do_warp)
-      EwinWarpTo(ewin);
+      EwinWarpTo(ewin, 0);
 
    switch (why)
      {
@@ -410,6 +424,7 @@ doFocusToEwin(EWin * ewin, int why)
      case FOCUS_DESK_ENTER:
 	if (Conf.focus.mode == MODE_FOCUS_CLICK)
 	   break;
+	/* FALLTHROUGH */
      default:
      case FOCUS_INIT:
 	EwinListFocusRaise(ewin);
@@ -427,7 +442,8 @@ doFocusToEwin(EWin * ewin, int why)
    ICCCM_Cmap(ewin);
 
    /* Quit if pointer is not on our screen */
-   if (!EQueryPointer(NULL, NULL, NULL, NULL, NULL))
+
+   if (!Mode.events.on_screen)
      {
 	Mode.focuswin = NULL;
 	return;
@@ -484,6 +500,7 @@ FocusToEWin(EWin * ewin, int why)
 	   focus_pending_new = NULL;
 	break;
      }
+   focus_request = (int)NextRequest(disp) - 1;
 }
 
 static void
@@ -517,13 +534,56 @@ FocusNewDesk(void)
    XUngrabKeyboard(disp, CurrentTime);
 }
 
-void
-FocusCheckScreen(void)
+static void
+_FocusScreenSendEvent(Window xwin, int x, int y, Time t, int enter)
 {
-   if (EQueryPointer(NULL, NULL, NULL, NULL, NULL))
-      return;			/* On screen */
+   XEvent              xe;
 
-   FocusToEWin(NULL, FOCUS_DESK_LEAVE);
+   xe.type = (enter) ? EnterNotify : LeaveNotify;
+   xe.xcrossing.window = xwin;
+   xe.xcrossing.root = xwin;
+   xe.xcrossing.subwindow = 0;
+   xe.xcrossing.time = t;
+   xe.xcrossing.x = xe.xcrossing.x_root = x;
+   xe.xcrossing.y = xe.xcrossing.y_root = y;
+   xe.xcrossing.mode = NotifyNormal;
+   xe.xcrossing.detail = NotifyNonlinear;
+   xe.xcrossing.same_screen = (enter) ? True : False;
+   xe.xcrossing.focus = (enter) ? False : True;
+   xe.xcrossing.state = 0;
+
+   XSendEvent(disp, xwin, False, EnterWindowMask | LeaveWindowMask, &xe);
+}
+
+void
+FocusScreen(int scr)
+{
+   Window              xwin;
+   Time                t;
+   int                 x, y;
+
+   if (scr < 0 || scr >= ScreenCount(disp))
+      return;
+
+   /* IIRC warping to a different screen once did cause
+    * LeaveNotify's on the current root window. This does not
+    * happen in xorg 1.5.3 (and probably other versions).
+    * So, send LeaveNotify to current root and EnterNotify
+    * to new root. */
+
+   t = EGetTimestamp();
+
+   /* Report LeaveNotify on current root window */
+   xwin = WinGetXwin(VROOT);
+   EXQueryPointer(xwin, &x, &y, NULL, NULL);
+   _FocusScreenSendEvent(xwin, x, y, t, 0);
+
+   /* Do warp and report EnterNotify on new root window */
+   xwin = RootWindow(disp, scr);
+   x = DisplayWidth(disp, scr) / 2;
+   y = DisplayHeight(disp, scr) / 2;
+   EXWarpPointer(xwin, x, y);
+   _FocusScreenSendEvent(xwin, x, y, t, 1);
 }
 
 static void
@@ -551,26 +611,28 @@ FocusExit(void)
 void
 FocusHandleEnter(EWin * ewin, XEvent * ev)
 {
-   Window              win = ev->xcrossing.window;
-
    Mode.mouse_over_ewin = ewin;
 
-   if (!ewin)
-     {
-	/* Entering root may mean entering this screen */
-	if (win == WinGetXwin(VROOT) &&
-	    (ev->xcrossing.mode == NotifyNormal &&
-	     ev->xcrossing.detail != NotifyInferior))
-	  {
-	     FocusToEWin(NULL, FOCUS_DESK_ENTER);
-	     return;
-	  }
-     }
-
    if (ev->xcrossing.mode == NotifyUngrab &&
        ev->xcrossing.detail == NotifyNonlinearVirtual)
       return;
 
+   if ((int)ev->xcrossing.serial - focus_request < 0)
+     {
+	/* This event was caused by a request older than the latest
+	 * focus assignment request - ignore */
+	if (EDebug(EDBUG_TYPE_FOCUS))
+	   Eprintf("FocusHandleEnter: Ignore serial < %#x\n", focus_request);
+	return;
+     }
+
+   if (!ewin)
+     {
+	/* Entering root may mean entering this screen */
+	FocusToEWin(NULL, FOCUS_DESK_ENTER);
+	return;
+     }
+
    switch (Conf.focus.mode)
      {
      default:
@@ -581,22 +643,33 @@ FocusHandleEnter(EWin * ewin, XEvent * ev)
 	   FocusToEWin(ewin, FOCUS_ENTER);
 	break;
      case MODE_FOCUS_POINTER:
-	if (!ewin || FocusEwinValid(ewin, 1, 0, 0))
+	if (FocusEwinValid(ewin, 1, 0, 0))
 	   FocusToEWin(ewin, FOCUS_ENTER);
+	else
+	   FocusToEWin(NULL, FOCUS_NONE);
 	break;
      }
 }
 
 void
-FocusHandleLeave(EWin * ewin __UNUSED__, XEvent * ev)
+FocusHandleLeave(EWin * ewin, XEvent * ev)
 {
-   Window              win = ev->xcrossing.window;
+   if ((int)ev->xcrossing.serial - focus_request < 0)
+     {
+	/* This event was caused by a request older than the latest
+	 * focus assignment request - ignore */
+	if (EDebug(EDBUG_TYPE_FOCUS))
+	   Eprintf("FocusHandleLeave: Ignore serial < %#x\n", focus_request);
+	return;
+     }
 
    /* Leaving root may mean entering other screen */
-   if (win == WinGetXwin(VROOT) &&
-       (ev->xcrossing.mode == NotifyNormal &&
-	ev->xcrossing.detail != NotifyInferior))
-      FocusToEWin(NULL, FOCUS_DESK_LEAVE);
+   if (!ewin)
+     {
+	if (ev->xcrossing.mode == NotifyNormal &&
+	    ev->xcrossing.detail != NotifyInferior)
+	   FocusToEWin(NULL, FOCUS_DESK_LEAVE);
+     }
 }
 
 void
@@ -638,8 +711,9 @@ typedef struct {
       int                 mode;
       char                clickalways;
       char                new_focus;
+      char                new_focus_if_group;
       char                popup_focus;
-      char                owner_popup_focus;
+      char                popup_focus_if_group;
       char                raise_focus;
       char                warp_focus;
       char                warp_always;
@@ -659,6 +733,7 @@ typedef struct {
       char                showiconified;
       char                showalldesks;
       char                warpfocused;
+      char                show_shape;
       int                 icon_mode;
    } focuslist;
 } FocusDlgData;
@@ -674,9 +749,11 @@ CB_ConfigureFocus(Dialog * d, int val, void *data __UNUSED__)
    Conf.focus.mode = dd->focus.mode;
    Conf.focus.clickraises = dd->focus.clickalways;
    Conf.focus.all_new_windows_get_focus = dd->focus.new_focus;
+   Conf.focus.new_windows_get_focus_if_group_focused =
+      dd->focus.new_focus_if_group;
    Conf.focus.new_transients_get_focus = dd->focus.popup_focus;
    Conf.focus.new_transients_get_focus_if_group_focused =
-      dd->focus.owner_popup_focus;
+      dd->focus.popup_focus_if_group;
    Conf.focus.raise_on_next = dd->focus.raise_focus;
    Conf.focus.warp_on_next = dd->focus.warp_focus;
    Conf.focus.warp_always = dd->focus.warp_always;
@@ -692,6 +769,7 @@ CB_ConfigureFocus(Dialog * d, int val, void *data __UNUSED__)
    Conf.warplist.showiconified = dd->focuslist.showiconified;
    Conf.warplist.showalldesks = dd->focuslist.showalldesks;
    Conf.warplist.warpfocused = dd->focuslist.warpfocused;
+   Conf.warplist.show_shape = dd->focuslist.show_shape;
    Conf.warplist.icon_mode = dd->focuslist.icon_mode;
 
    ClickGrabsUpdate();
@@ -712,8 +790,10 @@ _DlgFillFocus(Dialog * d, DItem * table, void *data __UNUSED__)
    dd->focus.mode = Conf.focus.mode;
    dd->focus.clickalways = Conf.focus.clickraises;
    dd->focus.new_focus = Conf.focus.all_new_windows_get_focus;
+   dd->focus.new_focus_if_group =
+      Conf.focus.new_windows_get_focus_if_group_focused;
    dd->focus.popup_focus = Conf.focus.new_transients_get_focus;
-   dd->focus.owner_popup_focus =
+   dd->focus.popup_focus_if_group =
       Conf.focus.new_transients_get_focus_if_group_focused;
    dd->focus.raise_focus = Conf.focus.raise_on_next;
    dd->focus.warp_focus = Conf.focus.warp_on_next;
@@ -730,6 +810,7 @@ _DlgFillFocus(Dialog * d, DItem * table, void *data __UNUSED__)
    dd->focuslist.showiconified = Conf.warplist.showiconified;
    dd->focuslist.showalldesks = Conf.warplist.showalldesks;
    dd->focuslist.warpfocused = Conf.warplist.warpfocused;
+   dd->focuslist.show_shape = Conf.warplist.show_shape;
    dd->focuslist.icon_mode = Conf.warplist.icon_mode;
 
    DialogItemTableSetOptions(table, 2, 0, 0, 0);
@@ -769,6 +850,13 @@ _DlgFillFocus(Dialog * d, DItem * table, void *data __UNUSED__)
    DialogItemSetText(di, _("All new windows first get the focus"));
    DialogItemCheckButtonSetPtr(di, &dd->focus.new_focus);
 
+   di = DialogAddItem(table, DITEM_CHECKBUTTON);
+   DialogItemSetColSpan(di, 2);
+   DialogItemSetText(di,
+		     _
+		     ("New windows get the focus if their window group is focused"));
+   DialogItemCheckButtonSetPtr(di, &dd->focus.new_focus_if_group);
+
    di = DialogAddItem(table, DITEM_CHECKBUTTON);
    DialogItemSetColSpan(di, 2);
    DialogItemSetText(di, _("Only new dialog windows get the focus"));
@@ -779,7 +867,7 @@ _DlgFillFocus(Dialog * d, DItem * table, void *data __UNUSED__)
    DialogItemSetText(di,
 		     _
 		     ("Only new dialogs whose owner is focused get the focus"));
-   DialogItemCheckButtonSetPtr(di, &dd->focus.owner_popup_focus);
+   DialogItemCheckButtonSetPtr(di, &dd->focus.popup_focus_if_group);
 
    di = DialogAddItem(table, DITEM_CHECKBUTTON);
    DialogItemSetColSpan(di, 2);
@@ -850,6 +938,11 @@ _DlgFillFocus(Dialog * d, DItem * table, void *data __UNUSED__)
    DialogItemSetText(di, _("Focus windows while switching"));
    DialogItemCheckButtonSetPtr(di, &dd->focuslist.warpfocused);
 
+   di = DialogAddItem(table, DITEM_CHECKBUTTON);
+   DialogItemSetColSpan(di, 2);
+   DialogItemSetText(di, _("Outline windows while switching"));
+   DialogItemCheckButtonSetPtr(di, &dd->focuslist.show_shape);
+
    di = DialogAddItem(table, DITEM_CHECKBUTTON);
    DialogItemSetColSpan(di, 2);
    DialogItemSetText(di, _("Raise windows after focus switch"));
@@ -873,19 +966,19 @@ _DlgFillFocus(Dialog * d, DItem * table, void *data __UNUSED__)
    DialogItemSetColSpan(di, 2);
    DialogItemSetText(di, _("First E Icon, then App Icon"));
    DialogItemRadioButtonSetFirst(di, radio2);
-   DialogItemRadioButtonGroupSetVal(di, 4);
+   DialogItemRadioButtonGroupSetVal(di, EWIN_ICON_MODE_IMG_APP);
 
    di = DialogAddItem(table, DITEM_RADIOBUTTON);
    DialogItemSetColSpan(di, 2);
    DialogItemSetText(di, _("First App Icon, then E Icon"));
    DialogItemRadioButtonSetFirst(di, radio2);
-   DialogItemRadioButtonGroupSetVal(di, 3);
+   DialogItemRadioButtonGroupSetVal(di, EWIN_ICON_MODE_APP_IMG);
 
    di = DialogAddItem(table, DITEM_RADIOBUTTON);
    DialogItemSetColSpan(di, 2);
    DialogItemSetText(di, _("None"));
    DialogItemRadioButtonSetFirst(di, radio2);
-   DialogItemRadioButtonGroupSetVal(di, 0);
+   DialogItemRadioButtonGroupSetVal(di, EWIN_ICON_MODE_NONE);
    DialogItemRadioButtonGroupSetValPtr(radio2, &dd->focuslist.icon_mode);
 }
 
@@ -895,7 +988,7 @@ const DialogDef     DlgFocus = {
    N_("Focus Settings"),
    SOUND_SETTINGS_FOCUS,
    "pix/focus.png",
-   N_("Enlightenment Focus\n" "Settings Dialog\n"),
+   N_("Enlightenment Focus\n" "Settings Dialog"),
    _DlgFillFocus,
    DLG_OAC, CB_ConfigureFocus,
 };
@@ -1059,6 +1152,7 @@ static const CfgItem FocusCfgItems[] = {
    CFG_ITEM_BOOL(Conf.focus, transientsfollowleader, 1),
    CFG_ITEM_BOOL(Conf.focus, switchfortransientmap, 1),
    CFG_ITEM_BOOL(Conf.focus, all_new_windows_get_focus, 0),
+   CFG_ITEM_BOOL(Conf.focus, new_windows_get_focus_if_group_focused, 1),
    CFG_ITEM_BOOL(Conf.focus, new_transients_get_focus, 0),
    CFG_ITEM_BOOL(Conf.focus, new_transients_get_focus_if_group_focused, 1),
    CFG_ITEM_BOOL(Conf.focus, raise_on_next, 1),
@@ -1074,6 +1168,7 @@ static const CfgItem FocusCfgItems[] = {
  * Module descriptor
  */
 extern const EModule ModFocus;
+
 const EModule       ModFocus = {
    "focus", NULL,
    FocusSighan,
