@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2009 Kim Woelders
+ * Copyright (C) 2004-2010 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -89,7 +89,7 @@ HiwinRenderImageInit(Hiwin * phi)
      {
 	phi->im =
 	   EImageGrabDrawable(ewin->mini_pmm.pmap, ewin->mini_pmm.mask, 0, 0,
-			      ewin->mini_w, ewin->mini_h, 0);
+			      ewin->mini_pmm.w, ewin->mini_pmm.h, 0);
      }
 
    ESetWindowBackgroundPixmap(EoGetWin(phi), None);
