@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2009 Kim Woelders
+ * Copyright (C) 2004-2010 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -43,6 +43,8 @@ ICCCM_Init(void)
    ecore_x_icccm_init();
 #endif
 
+   Mode.current_cmap = WinGetCmap(VROOT);
+
    ICCCM_SetIconSizes();
 
    if (Mode.wm.window)
@@ -95,17 +97,6 @@ ICCCM_GetTitle(EWin * ewin)
    EwinChange(ewin, EWIN_CHANGE_NAME);
 }
 
-static void
-ICCCM_GetColormap(EWin * ewin)
-{
-   XWindowAttributes   xwa;
-
-   ewin->client.cmap = None;
-   if (XGetWindowAttributes(disp, EwinGetClientXwin(ewin), &xwa)
-       && xwa.colormap)
-      ewin->client.cmap = xwa.colormap;
-}
-
 void
 ICCCM_Delete(const EWin * ewin)
 {
@@ -176,11 +167,16 @@ ICCCM_SizeMatch(const EWin * ewin, int wi, int hi, int *pwo, int *pho)
       h = ewin->icccm.height_min;
    if (h > ewin->icccm.height_max)
       h = ewin->icccm.height_max;
+
+   if (w <= 0 || h <= 0)
+      return;
+
+   w -= ewin->icccm.base_w;
+   h -= ewin->icccm.base_h;
    if ((w > 0) && (h > 0))
      {
-	w -= ewin->icccm.base_w;
-	h -= ewin->icccm.base_h;
-	if ((w > 0) && (h > 0))
+	/* Ignore aspect ratio constraints when fullscreening */
+	if (!ewin->state.fullscreen)
 	  {
 	     aspect = ((double)w) / ((double)h);
 	     dw = ewin->icccm.w_inc / 4.;
@@ -188,16 +184,16 @@ ICCCM_SizeMatch(const EWin * ewin, int wi, int hi, int *pwo, int *pho)
 	     if (Mode.mode == MODE_RESIZE_H)
 	       {
 		  if (aspect < ewin->icccm.aspect_min)
-		     w = (int)((double)h * ewin->icccm.aspect_min + dw);
+		     h = (int)((double)w / ewin->icccm.aspect_min + dh);
 		  else if (aspect > ewin->icccm.aspect_max)
-		     w = (int)((double)h * ewin->icccm.aspect_max + dw);
+		     h = (int)((double)w / ewin->icccm.aspect_max + dh);
 	       }
 	     else if (Mode.mode == MODE_RESIZE_V)
 	       {
 		  if (aspect < ewin->icccm.aspect_min)
-		     h = (int)((double)w / ewin->icccm.aspect_min + dh);
+		     w = (int)((double)h * ewin->icccm.aspect_min + dw);
 		  else if (aspect > ewin->icccm.aspect_max)
-		     h = (int)((double)w / ewin->icccm.aspect_max + dh);
+		     w = (int)((double)h * ewin->icccm.aspect_max + dw);
 	       }
 	     else
 	       {
@@ -216,14 +212,14 @@ ICCCM_SizeMatch(const EWin * ewin, int wi, int hi, int *pwo, int *pho)
 			  w = (int)((double)h * ewin->icccm.aspect_max + dw);
 		    }
 	       }
-	     i = w / ewin->icccm.w_inc;
-	     j = h / ewin->icccm.h_inc;
-	     w = i * ewin->icccm.w_inc;
-	     h = j * ewin->icccm.h_inc;
 	  }
-	w += ewin->icccm.base_w;
-	h += ewin->icccm.base_h;
+	i = w / ewin->icccm.w_inc;
+	j = h / ewin->icccm.h_inc;
+	w = i * ewin->icccm.w_inc;
+	h = j * ewin->icccm.h_inc;
      }
+   w += ewin->icccm.base_w;
+   h += ewin->icccm.base_h;
 
    *pwo = w;
    *pho = h;
@@ -274,7 +270,6 @@ void
 ICCCM_Configure(EWin * ewin)
 {
    XEvent              ev;
-   Window              child;
 
    if (EwinIsInternal(ewin))
       return;
@@ -294,9 +289,10 @@ ICCCM_Configure(EWin * ewin)
    ev.xconfigure.y = ewin->client.y;
 #endif
    if (Mode.wm.window)
-      ETranslateCoordinates(VROOT, RROOT,
-			    ev.xconfigure.x, ev.xconfigure.y,
-			    &ev.xconfigure.x, &ev.xconfigure.y, &child);
+     {
+	ev.xconfigure.x += Mode.wm.win_x;
+	ev.xconfigure.y += Mode.wm.win_y;
+     }
    ev.xconfigure.width = ewin->client.w;
    ev.xconfigure.height = ewin->client.h;
    ev.xconfigure.border_width = 0;
@@ -328,49 +324,57 @@ ICCCM_Adopt(const EWin * ewin)
 void
 ICCCM_Cmap(EWin * ewin)
 {
+   Colormap            ecmap, dcmap, ccmap;
+   XWindowAttributes   xwa;
+   int                 i, num;
+   Ecore_X_Window     *wlist;
+
+   ecmap = Mode.current_cmap;
+   dcmap = WinGetCmap(VROOT);
+
    if (!ewin)
      {
-	if (Mode.current_cmap)
+	if (ecmap == dcmap)
+	   return;
+	ccmap = dcmap;
+	goto set_cmap;
+     }
+
+   ccmap = EwinGetClientWin(ewin)->cmap;
+
+   if (ccmap == ecmap || EoGetWin(ewin)->argb)
+      return;
+
+   /* Hack - assume that if client cmap is default cmap it doesn't have
+    * WM_COLORMAP_WINDOWS */
+   if (ccmap == dcmap)
+      goto set_cmap;
+
+   num = ecore_x_window_prop_window_list_get(EwinGetClientXwin(ewin),
+					     ECORE_X_ATOM_WM_COLORMAP_WINDOWS,
+					     &wlist);
+   if (num > 0)
+     {
+	for (i = 0; i < num; i++)
 	  {
-	     XUninstallColormap(disp, Mode.current_cmap);
-	     Mode.current_cmap = 0;
+	     if (XGetWindowAttributes(disp, wlist[i], &xwa))
+	       {
+		  if (xwa.colormap != dcmap)
+		    {
+		       XInstallColormap(disp, xwa.colormap);
+		       Mode.current_cmap = xwa.colormap;
+		    }
+	       }
 	  }
+	Efree(wlist);
 	return;
      }
 
-   if (EwinIsInternal(ewin))
-      return;
-
-   ICCCM_GetColormap(ewin);
-
-   if ((ewin->client.cmap) && (Mode.current_cmap != ewin->client.cmap))
-     {
-	XWindowAttributes   xwa;
-	int                 i, num;
-	Ecore_X_Window     *wlist;
-
-	num = ecore_x_window_prop_window_list_get(EwinGetClientXwin(ewin),
-						  ECORE_X_ATOM_WM_COLORMAP_WINDOWS,
-						  &wlist);
-	if (num > 0)
-	  {
-	     for (i = 0; i < num; i++)
-	       {
-		  if (XGetWindowAttributes(disp, wlist[i], &xwa))
-		    {
-		       if (xwa.colormap != WinGetCmap(VROOT))
-			 {
-			    XInstallColormap(disp, xwa.colormap);
-			    Mode.current_cmap = xwa.colormap;
-			 }
-		    }
-	       }
-	     Efree(wlist);
-	     return;
-	  }
-	XInstallColormap(disp, ewin->client.cmap);
-	Mode.current_cmap = ewin->client.cmap;
-     }
+ set_cmap:
+   if (EDebug(EDBUG_TYPE_FOCUS))
+      Eprintf("ICCCM_Cmap %#lx\n", ccmap);
+   XInstallColormap(disp, ccmap);
+   Mode.current_cmap = ccmap;
 }
 
 void
@@ -379,10 +383,12 @@ ICCCM_Focus(const EWin * ewin)
    if (EDebug(EDBUG_TYPE_FOCUS))
      {
 	if (ewin)
-	   Eprintf("ICCCM_Focus T=%#lx %#lx %s\n", Mode.events.time,
-		   EwinGetClientXwin(ewin), EwinGetTitle(ewin));
+	   Eprintf("ICCCM_Focus T=%#lx R=%#lx %#lx %s\n", Mode.events.time,
+		   NextRequest(disp), EwinGetClientXwin(ewin),
+		   EwinGetTitle(ewin));
 	else
-	   Eprintf("ICCCM_Focus None T=%#lx\n", Mode.events.time);
+	   Eprintf("ICCCM_Focus T=%#lx R=%#lx None\n", Mode.events.time,
+		   NextRequest(disp));
      }
 
    if (!ewin)
