@@ -98,7 +98,7 @@ TransparencyMakeColorModifier(void)
 	alpha[i] = 255 - Conf.trans.alpha;
      }
 
-   if (icm == NULL)
+   if (!icm)
       icm = EImageColorModifierCreate();
    EImageColorModifierSetTables(icm, gray, gray, gray, alpha);
 }
@@ -160,7 +160,7 @@ ThemeImageLoad(const char *file)
 	return im;
      }
 
-   f = ThemeFileFind(file);
+   f = ThemeFileFind(file, FILE_TYPE_IMAGE);
    if (f)
      {
 	im = EImageLoad(f);
@@ -259,7 +259,7 @@ ImagestateRealize(ImageState * is)
 	if (!is->im_file)
 	   return;		/* No file - quit */
 	/* not loaded, load and setup */
-	is->real_file = ThemeFileFind(is->im_file);
+	is->real_file = ThemeFileFind(is->im_file, FILE_TYPE_IMAGE);
      }
    if (is->real_file)
      {
@@ -334,8 +334,7 @@ ImageclassDestroy(ImageClass * ic)
 
    if (ic->ref_count > 0)
      {
-	DialogOK("ImageClass Error!", _("%u references remain\n"),
-		 ic->ref_count);
+	DialogOK("ImageClass Error!", _("%u references remain"), ic->ref_count);
 	return;
      }
 
@@ -694,7 +693,7 @@ ImageclassGetImage(ImageClass * ic, int active, int sticky, int state)
    if (!is)
       return NULL;
 
-   if (is->im == NULL)
+   if (!is->im)
       ImagestateRealize(is);
 
    im = is->im;
@@ -806,7 +805,7 @@ ImageclassGetImageBlended(ImageClass * ic, Win win, int w, int h, int active,
    if (!is)
       return NULL;
 
-   if (is->im == NULL)
+   if (!is->im)
       ImagestateRealize(is);
    im = is->im;
    if (!im)
@@ -1098,7 +1097,7 @@ ITApply(Win win, ImageClass * ic, ImageState * is,
 {
    int                 w, h;
 
-   if (win == NULL || !ic)
+   if (!win || !ic)
       return;
 
    w = WinGetW(win);
@@ -1117,7 +1116,7 @@ ITApply(Win win, ImageClass * ic, ImageState * is,
 	   ts = TextclassGetTextState(tc, state, active, sticky);
      }
 
-   if (is->im == NULL)
+   if (!is->im)
       ImagestateRealize(is);
 
    /* Imlib2 will not render pixmaps with dimensions > 8192 */
@@ -1170,7 +1169,7 @@ ITApply(Win win, ImageClass * ic, ImageState * is,
 		EShapeSetMaskTiled(win, 0, 0, pmm.mask, w, h);
 	  }
 
-	FreePmapMask(&pmm);
+	PmapMaskFree(&pmm);
 
 	if ((is->unloadable) || (Conf.memory_paranoia))
 	  {
@@ -1226,7 +1225,7 @@ PmapMaskTile(PmapMask * pmm, Win win, unsigned int w, unsigned int h)
    if (mask != None)
       EXCopyAreaTiled(pmm->mask, None, mask, 0, 0, w, h, 0, 0);
 
-   FreePmapMask(pmm);
+   PmapMaskFree(pmm);
    pmm->type = 0;
    pmm->w = w;
    pmm->h = h;
@@ -1241,7 +1240,7 @@ ImageclassApplyCopy(ImageClass * ic, Win win, int w, int h,
 {
    ImageState         *is;
 
-   if (pmm == NULL)
+   if (!pmm)
       return;
 
    pmm->type = 0;
@@ -1254,7 +1253,7 @@ ImageclassApplyCopy(ImageClass * ic, Win win, int w, int h,
    if (!is)
       return;
 
-   if (is->im == NULL)
+   if (!is->im)
       ImagestateRealize(is);
 
    /* Imlib2 will not render pixmaps with dimensions > 8192 */
@@ -1560,6 +1559,7 @@ static const IpcItem ImageclassIpcArray[] = {
  * Module descriptor
  */
 extern const EModule ModImageclass;
+
 const EModule       ModImageclass = {
    "imageclass", "ic",
    NULL,
