@@ -26,9 +26,16 @@
 #include "ewins.h"
 #include "iclass.h"
 #include "icons.h"
+#include "timers.h"
 #include "windowmatch.h"
 #include "xwin.h"
 
+#define EWIN_ICON_TYPE_NONE     0
+#define EWIN_ICON_TYPE_APP      1
+#define EWIN_ICON_TYPE_IMG      2
+#define EWIN_ICON_TYPE_SNAP     3
+#define EWIN_ICON_TYPE_FB       4
+
 static int
 NetwmIconFindBestSize(unsigned int *val, unsigned int len, int size)
 {
@@ -36,7 +43,7 @@ NetwmIconFindBestSize(unsigned int *val, unsigned int len, int size)
    int                 k = -1;
 
    sz = (unsigned int)size;
-   sj = sbest = 0;
+   sbest = 0;
    for (i = 0; i < len;)
      {
 	j = i;
@@ -99,20 +106,24 @@ IB_SnapEWin(EWin * ewin, int size)
 {
    /* Make snapshot of window */
    int                 w, h, ww, hh;
+   int                 was_shaded;
    EImage             *im;
    Drawable            draw;
 
    if (!EoIsShown(ewin))
       return NULL;
 
-   ww = EoGetW(ewin);
-   hh = EoGetH(ewin);
-   if (ww <= 0 || hh <= 0)
-      return NULL;
+   was_shaded = ewin->state.shaded;
 
    if (ewin->state.shaded)
       EwinInstantUnShade(ewin);
    EwinRaise(ewin);
+   IdlersRun();
+
+   ww = EoGetW(ewin);
+   hh = EoGetH(ewin);
+   if (ww <= 0 || hh <= 0)
+      return NULL;
 
    /* Oversample for nicer snapshots */
    IB_IconGetSize(ww, hh, size, 4, &w, &h);
@@ -136,6 +147,9 @@ IB_SnapEWin(EWin * ewin, int size)
      }
    EImageSetHasAlpha(im, 1);
 
+   if (was_shaded != ewin->state.shaded)
+      EwinInstantShade(ewin, 0);
+
    return im;
 }
 
@@ -202,7 +216,7 @@ IB_GetFallbackIcon(EWin * ewin, int size)
    ImageClass         *ic;
    EImage             *im;
 
-   im = ThemeImageLoad("pix/default.png");
+   im = ThemeImageLoad("icons/default.png");
    if (im)
       return im;
 
