@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2009 Kim Woelders
+ * Copyright (C) 2004-2010 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -101,7 +101,7 @@ SetEwinBoolean(const char *txt, char *item, const char *value, int set)
 
    vnew = vold = *item != 0;	/* Remember old value */
 
-   if (value == NULL || value[0] == '\0')
+   if (!value || value[0] == '\0')
       vnew = !vold;
    else if (!strcmp(value, "on"))
       vnew = 1;
@@ -669,10 +669,9 @@ IpcWinop(const WinOp * wop, EWin * ewin, const char *prm)
 	break;
 
      case EWIN_OP_ZOOM:
-	if (InZoom())
-	   Zoom(NULL);
-	else
-	   Zoom(ewin);
+	on = ewin->state.zoomed;
+	if (SetEwinBoolean(wop->name, &on, param1, 1))
+	   Zoom(ewin, on);
 	break;
 
      case EWIN_OP_LAYER:
@@ -1045,7 +1044,6 @@ IPC_Debug(const char *params)
      {
 	l = 0;
 	sscanf(p, "%1000s %n", param, &l);
-	p += l;
 	if (!strncmp(param, "on", 2))
 	  {
 	     XSynchronize(disp, True);
@@ -1226,7 +1224,7 @@ IPC_Reparent(const char *params)
    char                param2[FILEPATH_LEN_MAX];
    EWin               *ewin, *enew;
 
-   if (params == NULL)
+   if (!params)
       return;
 
    sscanf(params, "%100s %100s", param1, param2);
@@ -1267,16 +1265,7 @@ IPC_Warp(const char *params)
      {
 	x = (Dpy.screen + 1) % ScreenCount(disp);
 	sscanf(params, "%*s %i", &x);
-	if (x >= 0 && x < ScreenCount(disp))
-	  {
-	     EXWarpPointer(RootWindow(disp, x), DisplayWidth(disp, x) / 2,
-			   DisplayHeight(disp, x) / 2);
-	     /* IIRC warping to a different screen once did cause
-	      * LeaveNotify's on the current root window. This does not
-	      * happen in xorg 1.5.3 (and probably other versions).
-	      * So, check and focus out if left. */
-	     FocusCheckScreen();
-	  }
+	FocusScreen(x);
      }
    else
      {
@@ -1878,7 +1867,7 @@ IPC_Help(const char *params)
 	  {
 	     ipc = lst[i];
 	     if (strcmp(params, ipc->name) &&
-		 (ipc->nick == NULL || strcmp(params, ipc->nick)))
+		 (!ipc->nick || strcmp(params, ipc->nick)))
 		continue;
 
 	     nick = (ipc->nick) ? ipc->nick : "";
