@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007-2009 Kim Woelders
+ * Copyright (C) 2007-2010 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -53,7 +53,6 @@ typedef struct {
    int                 scale;	/* Zoom level */
    int                 sx, sy;	/* Scene x,y */
    int                 sw, sh;	/* Scene wxh */
-   char                mode;
    char                bpress;
    char                filter;
    char                grabbing;
@@ -374,6 +373,8 @@ _MagEwinInit(EWin * ewin)
 {
    MagWindow          *mw = (MagWindow *) ewin->data;
 
+   mw->ewin = ewin;
+
    EwinSetTitle(ewin, mw->title);
    EwinSetClass(ewin, "Magnifier", "Enlightenment_Magnifier");
 
@@ -507,6 +508,7 @@ static const IpcItem MagwinIpcArray[] = {
  * Module descriptor
  */
 extern const EModule ModMagwin;
+
 const EModule       ModMagwin = {
    "magwin", NULL,
    NULL,
