@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2009 Kim Woelders
+ * Copyright (C) 2004-2010 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -193,6 +193,8 @@ _MenuEwinInit(EWin * ewin)
 {
    Menu               *m = (Menu *) ewin->data;
 
+   m->ewin = ewin;
+
    EwinSetTitle(ewin, _(m->title));
    EwinSetClass(ewin, m->name, "Enlightenment_Menu");
 
@@ -335,7 +337,6 @@ MenuShow(Menu * m, char noshow)
 
    ewin = AddInternalToFamily(m->win, m->style->border_name, EWIN_TYPE_MENU,
 			      &_MenuEwinOps, m);
-   m->ewin = ewin;
    if (ewin)
      {
 	ewin->client.event_mask |= KeyPressMask;
@@ -623,9 +624,11 @@ MenuEmpty(Menu * m, int destroying)
 	Efree(mi->text);
 	Efree(mi->params);
 	for (j = 0; j < 3; j++)
-	   FreePmapMask(&(mi->pmm[j]));
+	   PmapMaskFree(&(mi->pmm[j]));
 	if (!destroying && mi->win)
 	   EDestroyWindow(mi->win);
+	else
+	   EventCallbackUnregister(mi->win, MenuItemHandleEvents, mi);
 	ImageclassFree(mi->icon_iclass);
 	Efree(mi);
      }
@@ -634,7 +637,7 @@ MenuEmpty(Menu * m, int destroying)
    m->num = 0;
    m->sel_item = NULL;
 
-   FreePmapMask(&m->pmm);
+   PmapMaskFree(&m->pmm);
 
    m->last_change = 0;
    m->filled = 0;
@@ -651,10 +654,10 @@ MenuFreePixmaps(Menu * m)
 	mi = m->items[i];
 
 	for (j = 0; j < 3; j++)
-	   FreePmapMask(mi->pmm + j);
+	   PmapMaskFree(mi->pmm + j);
      }
 
-   FreePmapMask(&m->pmm);
+   PmapMaskFree(&m->pmm);
 
    m->last_change = 0;
    m->filled = 0;
@@ -923,7 +926,7 @@ MenuRedraw(Menu * m)
 	for (i = 0; i < m->num; i++)
 	  {
 	     for (j = 0; j < 3; j++)
-		FreePmapMask(&(m->items[i]->pmm[j]));
+		PmapMaskFree(&(m->items[i]->pmm[j]));
 
 	  }
 	m->redraw = 0;
@@ -931,7 +934,7 @@ MenuRedraw(Menu * m)
 
    if (!m->style->use_item_bg)
      {
-	FreePmapMask(&m->pmm);
+	PmapMaskFree(&m->pmm);
 	ImageclassApplyCopy(m->style->bg_iclass, m->win, m->w, m->h, 0,
 			    0, STATE_NORMAL, &m->pmm, IC_FLAG_MAKE_MASK,
 			    ST_MENU);
@@ -990,7 +993,7 @@ MenuDrawItem(Menu * m, MenuItem * mi, char shape, int state)
 				      IC_FLAG_MAKE_MASK, item_type);
 		  EXCopyAreaTiled(pmm.pmap, pmm.mask, mi_pmm->pmap,
 				  0, 0, w, h, 0, 0);
-		  FreePmapMask(&pmm);
+		  PmapMaskFree(&pmm);
 	       }
 	     EXFreeGC(gc);
 	  }
@@ -1000,7 +1003,7 @@ MenuDrawItem(Menu * m, MenuItem * mi, char shape, int state)
 				 IC_FLAG_MAKE_MASK, item_type);
 	     EXCopyAreaTiled(pmm.pmap, pmm.mask, mi_pmm->pmap,
 			     0, 0, w, h, 0, 0);
-	     FreePmapMask(&pmm);
+	     PmapMaskFree(&pmm);
 	  }
 
 	if (mi->text)
@@ -1166,7 +1169,7 @@ MenusShowNamed(const char *name, const char *param)
 int
 MenusActive(void)
 {
-   return Mode_menus.first != NULL;
+   return ! !Mode_menus.first;
 }
 
 static void
@@ -1203,7 +1206,7 @@ MenuFindNextItem(Menu * m, MenuItem * mi, int inc)
 {
    int                 i;
 
-   if (mi == NULL)
+   if (!mi)
      {
 	if (m->num > 0)
 	   return m->items[0];
@@ -1282,13 +1285,13 @@ MenuEventKeyPress(Menu * m, XEvent * ev)
 	goto check_activate;
 
      case XK_Right:
-	if (mi == NULL)
+	if (!mi)
 	   goto check_next;
 	m = mi->child;
 	if (!m || m->num <= 0)
 	   break;
 	ewin = m->ewin;
-	if (ewin == NULL || !EwinIsMapped(ewin))
+	if (!ewin || !EwinIsMapped(ewin))
 	   break;
 	mi = MenuFindItemByChild(m, m->child);
 	goto check_activate;
@@ -1837,7 +1840,15 @@ MenuStyleConfigLoad(FILE * fs)
 	     goto done;
 	  case CONFIG_CLASSNAME:
 	     ms = MenuStyleCreate(s2);
-	     break;
+	     continue;
+	  }
+
+	/* ms needed */
+	if (!ms)
+	   break;
+
+	switch (i1)
+	  {
 	  case CONFIG_TEXT:
 	     ms->tclass = TextclassAlloc(s2, 1);
 	     break;
@@ -2158,7 +2169,7 @@ const DialogDef     DlgMenus = {
    N_("Menu Settings"),
    SOUND_SETTINGS_MENUS,
    "pix/place.png",
-   N_("Enlightenment Menu\n" "Settings Dialog\n"),
+   N_("Enlightenment Menu\n" "Settings Dialog"),
    _DlgFillMenus,
    DLG_OAC, CB_ConfigureMenus,
 };
@@ -2242,6 +2253,7 @@ static const CfgItem MenusCfgItems[] = {
  * Module descriptor
  */
 extern const EModule ModMenus;
+
 const EModule       ModMenus = {
    "menus", "menu",
    MenusSighan,
