@@ -26,7 +26,6 @@
 #include "cursors.h"
 #include "desktops.h"
 #include "emodule.h"
-#include "events.h"
 #include "ewins.h"
 #include "focus.h"
 #include "grabs.h"
@@ -36,6 +35,14 @@
 #include "xwin.h"
 #include <X11/keysym.h>
 
+#if ENABLE_OLDMOVRES
+#define MODE_MOVE_MAX	5
+#define MOVE_SIZE_MAX	4
+#else
+#define MODE_MOVE_MAX	2
+#define MOVE_SIZE_MAX	2
+#endif
+
 static struct {
    Win                 events;
    EWin               *ewin;
@@ -98,7 +105,8 @@ MoveResizeMoveStart(EWin * ewin, int kbd, int constrained, int nogroup)
    Mode_mr.using_kbd = kbd;
    Mode_mr.nogroup = nogroup;
 
-   EventsGetXY(&cx, &cy);
+   cx = Mode.events.cx;
+   cy = Mode.events.cy;
 
    SoundPlay(SOUND_MOVE_START);
 
@@ -115,11 +123,13 @@ MoveResizeMoveStart(EWin * ewin, int kbd, int constrained, int nogroup)
    gwins = ListWinGroupMembersForEwin(ewin, GROUP_ACTION_MOVE, nogroup
 				      || Mode.move.swap, &num);
 
-   if (Conf.movres.mode_move < 0 || Conf.movres.mode_move > 5)
+   if (Conf.movres.mode_move < 0 || Conf.movres.mode_move > MODE_MOVE_MAX)
       Conf.movres.mode_move = 0;
    Mode_mr.mode = Conf.movres.mode_move;
+#if ENABLE_OLDMOVRES
    if (num > 1 && Conf.movres.mode_move == 5)
       Mode_mr.mode = 0;
+#endif
    Mode_mr.grab_server = _NeedServerGrab(Mode_mr.mode);
 
    for (i = 0; i < num; i++)
@@ -255,7 +265,11 @@ _MoveResizeMoveResume(void)
 
    GrabPointerSet(Mode_mr.events, ECSR_ACT_MOVE, 1);
 
+#if ENABLE_OLDMOVRES
    fl = (Mode_mr.mode == 5) ? 4 : 0;
+#else
+   fl = 0;
+#endif
    if (Mode.mode == MODE_MOVE_PENDING)
      {
 	Mode.mode = MODE_MOVE;
@@ -305,11 +319,12 @@ MoveResizeResizeStart(EWin * ewin, int kbd, int hv)
 
    Mode_mr.ewin = ewin;
 
-   EventsGetXY(&cx, &cy);
+   cx = Mode.events.cx;
+   cy = Mode.events.cy;
 
    SoundPlay(SOUND_RESIZE_START);
 
-   if (Conf.movres.mode_resize < 0 || Conf.movres.mode_resize > 4)
+   if (Conf.movres.mode_resize < 0 || Conf.movres.mode_resize > MOVE_SIZE_MAX)
       Conf.movres.mode_resize = 0;
    Mode_mr.mode = Conf.movres.mode_resize;
    Mode_mr.using_kbd = kbd;
@@ -504,6 +519,7 @@ _MoveResizeMoveHandleMotion(void)
 
    if (Mode.mode == MODE_MOVE_PENDING)
      {
+	Mode.mode = MODE_MOVE;
 	if (Mode_mr.grab_server)
 	  {
 	     EGrabServer();
@@ -522,7 +538,6 @@ _MoveResizeMoveHandleMotion(void)
 	     if (Conf.movres.mode_move == 0)
 		Mode_mr.mode = 0;
 	  }
-	Mode.mode = MODE_MOVE;
 	dx = Mode.events.mx - Mode_mr.start_x;
 	dy = Mode.events.my - Mode_mr.start_y;
      }
@@ -787,6 +802,7 @@ _MoveResizeHandleKey(unsigned int key)
      case XK_Escape:
 	Mode_mr.cur_x = Mode_mr.start_x;
 	Mode_mr.cur_y = Mode_mr.start_y;
+	/* FALLTHROUGH */
      case XK_Return:
 	end = 1;
 	break;
