@@ -262,7 +262,7 @@ PagerHiwinUpdate(Hiwin * phi, Pager * p __UNUSED__, EWin * ewin)
       return;
 
    im = EImageGrabDrawable(ewin->mini_pmm.pmap, None, 0, 0,
-			   ewin->mini_w, ewin->mini_h, 0);
+			   ewin->mini_pmm.w, ewin->mini_pmm.h, 0);
    EImageRenderOnDrawable(im, EoGetWin(phi), 0, 0, 0, EoGetW(phi), EoGetH(phi));
    EImageDecache(im);
 }
@@ -288,7 +288,7 @@ PagerEwinUpdateMini(Pager * p, EWin * ewin)
    update = 0;
    if (!ewin->mini_pmm.pmap)
       update = 1;
-   if (ewin->mini_w != w || ewin->mini_h != h)
+   if (ewin->mini_pmm.w != w || ewin->mini_pmm.h != h)
       update = 1;
 
    if (serdif > 0 && ewin->type != EWIN_TYPE_PAGER &&
@@ -306,12 +306,7 @@ PagerEwinUpdateMini(Pager * p, EWin * ewin)
 
    p->do_update = 1;
 
-   FreePmapMask(&ewin->mini_pmm);
-
-   ewin->mini_w = w;
-   ewin->mini_h = h;
-   ewin->mini_pmm.type = 0;
-   ewin->mini_pmm.pmap = ECreatePixmap(p->win, w, h, 0);
+   PmapMaskInit(&ewin->mini_pmm, EoGetWin(ewin), w, h);
 
    draw = None;
    if (pager_mode != PAGER_MODE_SIMPLE)
@@ -327,13 +322,13 @@ PagerEwinUpdateMini(Pager * p, EWin * ewin)
 	ImageClass         *ic;
 
 	ic = ImageclassFind("PAGER_WIN", 1);
-	ImageclassApplySimple(ic, p->win, ewin->mini_pmm.pmap,
+	ImageclassApplySimple(ic, EoGetWin(ewin), ewin->mini_pmm.pmap,
 			      STATE_NORMAL, 0, 0, w, h);
 	Dprintf("Use Iclass, pmap=%#lx\n", ewin->mini_pmm.pmap);
      }
    else
      {
-	ScaleRect(EoGetWin(ewin), draw, p->win, ewin->mini_pmm.pmap,
+	ScaleRect(EoGetWin(ewin), draw, EoGetWin(ewin), ewin->mini_pmm.pmap,
 		  0, 0, EoGetW(ewin), EoGetH(ewin), 0, 0, w, h, HIQ);
 	Dprintf("Grab scaled, pmap=%#lx\n", ewin->mini_pmm.pmap);
      }
@@ -354,6 +349,10 @@ doPagerUpdate(Pager * p)
    int                 pager_mode = PagersGetMode();
    Pixmap              pmap;
 
+#if USE_COMPOSITE
+   Picture             pager_pict, pict, alpha;
+#endif
+
    p->update_phase = 0;
    DesksGetAreaSize(&ax, &ay);
    DeskGetArea(p->dsk, &cx, &cy);
@@ -419,6 +418,9 @@ doPagerUpdate(Pager * p)
 	  }
      }
 
+#if USE_COMPOSITE
+   pager_pict = EPictureCreate(NULL, pmap);
+#endif
    for (i = num - 1; i >= 0; i--)
      {
 	EWin               *ewin;
@@ -435,15 +437,33 @@ doPagerUpdate(Pager * p)
 
 	if (ewin->mini_pmm.pmap)
 	  {
+#if USE_COMPOSITE
+	     /*      pmap set by           depth determined by
+	      * PagerEwinUpdateMini()           ewin
+	      * PagerEwinUpdateFromPager()      p->win
+	      */
+	     pict = EPictureCreate(ewin->mini_pmm.depth == WinGetDepth(p->win) ?
+				   p->win : EoGetWin(ewin),
+				   ewin->mini_pmm.pmap);
+	     alpha = ECompMgrWinGetAlphaPict(EoObj(ewin));
+	     XRenderComposite(disp, PictOpOver, pict, alpha, pager_pict,
+			      0, 0, 0, 0, wx, wy, ww, wh);
+	     EPictureDestroy(pict);
+#else
+#if 0				/* Mask is currently not set anywhere */
 	     if (ewin->mini_pmm.mask)
 	       {
 		  XSetClipMask(disp, gc, ewin->mini_pmm.mask);
 		  XSetClipOrigin(disp, gc, wx, wy);
 	       }
+#endif
 	     XCopyArea(disp, ewin->mini_pmm.pmap, pmap, gc, 0, 0,
 		       ww, wh, wx, wy);
+#if 0				/* Mask is currently not set anywhere */
 	     if (ewin->mini_pmm.mask)
 		XSetClipMask(disp, gc, None);
+#endif
+#endif
 	  }
 	else
 	  {
@@ -453,6 +473,9 @@ doPagerUpdate(Pager * p)
 	     XFillRectangle(disp, pmap, gc, wx, wy, ww, wh);
 	  }
      }
+#if USE_COMPOSITE
+   EPictureDestroy(pager_pict);
+#endif
 
    if (!update_screen_included)
      {
@@ -619,6 +642,8 @@ _PagerEwinInit(EWin * ewin)
    Pager              *p = (Pager *) ewin->data;
    char                s[128];
 
+   p->ewin = ewin;
+
    Esnprintf(s, sizeof(s), "Pager-%i", p->dsk->num);
    EwinSetTitle(ewin, s);
    Esnprintf(s, sizeof(s), "%i", p->dsk->num);
@@ -703,7 +728,6 @@ PagerShow(Pager * p)
 
    ewin = AddInternalToFamily(p->win, "PAGER", EWIN_TYPE_PAGER,
 			      &_PagerEwinOps, p);
-   p->ewin = ewin;
    if (!ewin)
       return;
 
@@ -882,21 +906,7 @@ PagerEwinUpdateFromPager(Pager * p, EWin * ewin)
    if (!gc)
       gc = EXCreateGC(WinGetPmap(p->win), 0, NULL);
 
-   /* NB! If the pixmap/mask was created by imlib, free it. Due to imlibs */
-   /*     image/pixmap cache it may be in use elsewhere. */
-   if (ewin->mini_pmm.pmap &&
-       ((ewin->mini_pmm.type) || (ewin->mini_w != w) || (ewin->mini_h != h)))
-      FreePmapMask(&ewin->mini_pmm);
-
-   if (!ewin->mini_pmm.pmap)
-     {
-	ewin->mini_w = w;
-	ewin->mini_h = h;
-	ewin->mini_pmm.type = 0;
-	ewin->mini_pmm.pmap = ECreatePixmap(p->win, w, h, 0);
-	ewin->mini_pmm.mask = None;
-     }
-
+   PmapMaskInit(&ewin->mini_pmm, p->win, w, h);
    if (!ewin->mini_pmm.pmap)
       return;
 
@@ -1197,14 +1207,11 @@ static void
 PagerHandleMotion(Pager * p, int x, int y)
 {
    EWin               *ewin;
-   int                 on_screen;
 
    if (!Conf_pagers.enable)
       return;
 
-   on_screen = EQueryPointer(p->win, &x, &y, NULL, NULL);
-
-   if (on_screen && x >= 0 && x < p->w && y >= 0 && y < p->h)
+   if (Mode.events.on_screen && x >= 0 && x < p->w && y >= 0 && y < p->h)
       ewin = EwinInPagerAt(p, x, y);
    else
       ewin = NULL;
@@ -1257,19 +1264,22 @@ PagersUpdateBackground(Desk * dsk)
 }
 
 static void
-PagerSetHiQ(char onoff)
+_EwinsMiniFree(void)
 {
    EWin               *const *lst;
    int                 i, num;
 
-   Conf_pagers.hiq = onoff;
-
    lst = EwinListGetAll(&num);
    for (i = 0; i < num; i++)
-     {
-	lst[i]->mini_w = 0;
-	lst[i]->mini_h = 0;
-     }
+      PmapMaskFree(&(lst[i]->mini_pmm));
+}
+
+static void
+PagerSetHiQ(char onoff)
+{
+   Conf_pagers.hiq = onoff;
+
+   _EwinsMiniFree();
 
    PagersUpdateBackground(NULL);
 
@@ -1285,19 +1295,11 @@ _PagerSetSnap(Pager * p, void *prm __UNUSED__)
 static void
 PagersSetMode(int mode)
 {
-   EWin               *const *lst;
-   int                 i, num;
-
    if (mode == Conf_pagers.mode)
       return;
    Conf_pagers.mode = mode;
 
-   lst = EwinListGetAll(&num);
-   for (i = 0; i < num; i++)
-     {
-	lst[i]->mini_w = 0;
-	lst[i]->mini_h = 0;
-     }
+   _EwinsMiniFree();
 
    PagersUpdateBackground(NULL);
 
@@ -1635,7 +1637,11 @@ PagerHiwinEvent(Win win __UNUSED__, XEvent * ev, void *prm)
 	switch (Mode.mode)
 	  {
 	  case MODE_NONE:
-	     PagerHandleMotion(p, ev->xmotion.x, ev->xmotion.y);
+	     /* Translate x,y to pager window coordinates */
+	     ETranslateCoordinates(RROOT, p->win,
+				   ev->xbutton.x_root, ev->xbutton.y_root,
+				   &px, &py, NULL);
+	     PagerHandleMotion(p, px, py);
 	     break;
 
 	  case MODE_PAGER_DRAG_PENDING:
@@ -1988,7 +1994,7 @@ const DialogDef     DlgPagers = {
    N_("Pager Settings"),
    SOUND_SETTINGS_PAGER,
    "pix/pager.png",
-   N_("Enlightenment Desktop & Area\n" "Pager Settings Dialog\n"),
+   N_("Enlightenment Desktop & Area\n" "Pager Settings Dialog"),
    _DlgFillPagers,
    DLG_OAC, CB_ConfigurePager,
 };
@@ -2005,7 +2011,6 @@ PagersSighan(int sig, void *prm)
      {
      case ESIGNAL_INIT:
 	memset(&Mode_pagers, 0, sizeof(Mode_pagers));
-	EDirMake(EDirUserCache(), "cached/pager");
 	break;
      case ESIGNAL_CONFIGURE:
 	break;
@@ -2172,6 +2177,7 @@ static const CfgItem PagersCfgItems[] = {
  * Module descriptor
  */
 extern const EModule ModPagers;
+
 const EModule       ModPagers = {
    "pagers", "pg",
    PagersSighan,
