@@ -21,23 +21,155 @@
  * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
-#include "E.h"
+#include "config.h"
+#if ENABLE_OLDMOVRES
 #include "piximg.h"
+#include "util.h"
 #include "xwin.h"
+#if USE_XRENDER
+#include <X11/extensions/Xrender.h>
+
+struct _PixImg {
+   int                 w, h;
+   Picture             pict;
+   Picture             alpha;
+   Picture             buf;
+   Pixmap              pmap;
+   Pixmap              mask;
+   GC                  gc;
+};
+
+PixImg             *
+PixImgCreate(Win win, GC gc, int w, int h)
+{
+   PixImg             *pi;
+   XRenderPictFormat  *pictfmt;
+   XRenderPictureAttributes pa;
+
+   pi = ECALLOC(PixImg, 1);
+   if (!pi)
+      return NULL;
+
+   pi->w = w;
+   pi->h = h;
+   pi->gc = gc;
+
+   if (win)
+     {
+	pa.subwindow_mode = IncludeInferiors;
+	pictfmt = XRenderFindVisualFormat(disp, WinGetVisual(win));
+	pi->pict = XRenderCreatePicture(disp, WinGetXwin(win), pictfmt,
+					CPSubwindowMode, &pa);
+     }
+   else
+     {
+	pi->pict = EPictureCreateBuffer(VROOT, w, h, &pi->pmap);
+     }
+
+   return pi;
+}
+
+void
+PixImgDestroy(PixImg * pi)
+{
+   if (!pi)
+      return;
+
+   XRenderFreePicture(disp, pi->pict);
+   if (pi->pmap != None)
+      XFreePixmap(disp, pi->pmap);
+   if (pi->mask != None)
+      XFreePixmap(disp, pi->mask);
+
+   Efree(pi);
+}
+
+void
+PixImgSetMask(PixImg * pi, Pixmap mask, int x, int y)
+{
+   XRenderPictureAttributes pa;
+
+   switch (mask)
+     {
+     case 0:
+	pa.clip_mask = None;
+	XRenderChangePicture(disp, pi->pict, CPClipMask, &pa);
+	break;
+     case 1:
+	pa.clip_x_origin = x;
+	pa.clip_y_origin = y;
+	pa.clip_mask = pi->mask;
+	XRenderChangePicture(disp, pi->pict,
+			     CPClipXOrigin | CPClipYOrigin | CPClipMask, &pa);
+	break;
+     default:
+	pi->mask = mask;
+	break;
+     }
+}
+
+void
+PixImgFill(PixImg * pi, Drawable draw, int x, int y)
+{
+   XCopyArea(disp, draw, pi->pmap, pi->gc, x, y, pi->w, pi->h, 0, 0);
+}
+
+#include "eimage.h"
+void
+PixImgPaste(PixImg * src, PixImg * dst, int xs, int ys,
+	    int w, int h, int xt, int yt)
+{
+   XRenderComposite(disp, PictOpSrc, src->pict, None, dst->pict,
+		    xs, ys, 0, 0, xt, yt, w, h);
+}
+
+void
+PixImgBlend(PixImg * src, PixImg * xxx, PixImg * dst, Drawable draw,
+	    int x, int y, int w, int h)
+{
+   if (dst->alpha == None)
+     {
+	dst->alpha = EPictureCreateSolid(WinGetXwin(VROOT), 1, 0x80, 0);
+	dst->buf =
+	   EPictureCreateBuffer(VROOT, WinGetW(VROOT), WinGetH(VROOT), NULL);
+     }
+   XRenderComposite(disp, PictOpSrc, src->pict, None, dst->buf,
+		    x, y, 0, 0, x, y, w, h);
+   XRenderComposite(disp, PictOpOver, xxx->pict, dst->alpha, dst->buf,
+		    0, 0, 0, 0, x, y, w, h);
+   XRenderComposite(disp, PictOpSrc, dst->buf, None, dst->pict,
+		    x, y, 0, 0, x, y, w, h);
+   src = NULL;
+   draw = None;
+}
+
+#else
 #include <sys/ipc.h>
 #include <sys/shm.h>
 #include <X11/Xutil.h>
 #include <X11/extensions/XShm.h>
 
+struct _PixImg {
+   XImage             *xim;
+   XShmSegmentInfo    *shminfo;
+   Drawable            draw;
+   Pixmap              mask;
+   GC                  gc;
+};
+
 PixImg             *
-PixImgCreate(int w, int h)
+PixImgCreate(Win win, GC gc, int w, int h)
 {
    PixImg             *pi;
 
-   pi = EMALLOC(PixImg, 1);
+   pi = ECALLOC(PixImg, 1);
    if (!pi)
       return NULL;
 
+   if (win)
+      pi->draw = WinGetXwin(win);
+   pi->gc = gc;
+
    pi->shminfo = EMALLOC(XShmSegmentInfo, 1);
    if (pi->shminfo)
      {
@@ -85,9 +217,29 @@ PixImgDestroy(PixImg * pi)
    shmctl(pi->shminfo->shmid, IPC_RMID, 0);
    XDestroyImage(pi->xim);
    Efree(pi->shminfo);
+   if (pi->mask)
+      XFreePixmap(disp, pi->mask);
    Efree(pi);
 }
 
+void
+PixImgSetMask(PixImg * pi, Pixmap mask, int x, int y)
+{
+   switch (mask)
+     {
+     case 0:
+	XSetClipMask(disp, pi->gc, None);
+	break;
+     case 1:
+	XSetClipMask(disp, pi->gc, pi->mask);
+	XSetClipOrigin(disp, pi->gc, x, y);
+	break;
+     default:
+	pi->mask = mask;
+	break;
+     }
+}
+
 static int
 _fix_bounds(int *px, int *py, int *pw, int *ph, int *pox, int *poy)
 {
@@ -144,7 +296,7 @@ PixImgFill(PixImg * pi, Drawable draw, int x, int y)
 }
 
 void
-PixImgPaste(PixImg * pi, Drawable draw, GC gc, int xs, int ys,
+PixImgPaste(PixImg * src, PixImg * dst, int xs, int ys,
 	    int w, int h, int xt, int yt)
 {
    /* FIXME - No bounds checking if (xs,ys) != (xt,yt) */
@@ -156,11 +308,12 @@ PixImgPaste(PixImg * pi, Drawable draw, GC gc, int xs, int ys,
 	yt = ys;
      }
 
-   XShmPutImage(disp, draw, gc, pi->xim, xs, ys, xt, yt, w, h, False);
+   XShmPutImage(disp, dst->draw, dst->gc, src->xim, xs, ys, xt, yt, w, h,
+		False);
 }
 
 void
-PixImgBlend(PixImg * s1, PixImg * s2, PixImg * dst, Drawable draw, GC gc,
+PixImgBlend(PixImg * s1, PixImg * s2, PixImg * dst, Drawable draw,
 	    int x, int y, int w, int h)
 {
    int                 i, j, ox, oy;
@@ -368,7 +521,7 @@ PixImgBlend(PixImg * s1, PixImg * s2, PixImg * dst, Drawable draw, GC gc,
 			  pptr3 = (unsigned short *)ptr3;
 			  pp1 = *pptr1;
 			  pp2 = *pptr2;
-			  *pptr3++ =
+			  *pptr3 =
 			     ((pp1 >> 1) &
 			      ((0x78 << 7) | (0x78 << 2) | (0x78 >> 3)))
 			     +
@@ -471,5 +624,9 @@ PixImgBlend(PixImg * s1, PixImg * s2, PixImg * dst, Drawable draw, GC gc,
 	  }
 	break;
      }
-   XShmPutImage(disp, draw, gc, dst->xim, ox, oy, x, y, w, h, False);
+   XShmPutImage(disp, draw, dst->gc, dst->xim, ox, oy, x, y, w, h, False);
 }
+
+#endif /* USE_XRENDER */
+
+#endif /* ENABLE_OLDMOVRES */
