@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2009 Kim Woelders
+ * Copyright (C) 2004-2010 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -118,6 +118,7 @@ _DlgFillMoveResize(Dialog * d __UNUSED__, DItem * table, void *data __UNUSED__)
    DialogItemRadioButtonSetFirst(di, radio2);
    DialogItemRadioButtonGroupSetVal(di, 2);
 
+#if ENABLE_OLDMOVRES
    di = DialogAddItem(table, DITEM_RADIOBUTTON);
    DialogItemSetText(di, _("Shaded"));
    DialogItemRadioButtonSetFirst(di, radio1);
@@ -137,15 +138,17 @@ _DlgFillMoveResize(Dialog * d __UNUSED__, DItem * table, void *data __UNUSED__)
    DialogItemSetText(di, _("Semi-Solid"));
    DialogItemRadioButtonSetFirst(di, radio2);
    DialogItemRadioButtonGroupSetVal(di, 4);
-   DialogItemRadioButtonGroupSetValPtr(radio2, &dd->resize);
 
    di = DialogAddItem(table, DITEM_RADIOBUTTON);
    DialogItemSetText(di, _("Translucent"));
    DialogItemRadioButtonSetFirst(di, radio1);
    DialogItemRadioButtonGroupSetVal(di, 5);
-   DialogItemRadioButtonGroupSetValPtr(radio1, &dd->move);
 
-   di = DialogAddItem(table, DITEM_NONE);
+   DialogAddItem(table, DITEM_NONE);
+#endif /* ENABLE_OLDMOVRES */
+
+   DialogItemRadioButtonGroupSetValPtr(radio1, &dd->move);
+   DialogItemRadioButtonGroupSetValPtr(radio2, &dd->resize);
 
    di = DialogAddItem(table, DITEM_CHECKBUTTON);
    DialogItemSetColSpan(di, 2);
@@ -233,7 +236,7 @@ const DialogDef     DlgMoveResize = {
    N_("Move & Resize Settings"),
    SOUND_SETTINGS_MOVERESIZE,
    "pix/moveres.png",
-   N_("Enlightenment Move & Resize\n" "Method Settings Dialog\n"),
+   N_("Enlightenment Move & Resize\n" "Method Settings Dialog"),
    _DlgFillMoveResize,
    DLG_OAC, CB_ConfigureMoveResize,
 };
@@ -395,7 +398,7 @@ _DlgFillPlacement(Dialog * d __UNUSED__, DItem * table, void *data __UNUSED__)
    DialogItemRadioButtonGroupSetVal(di, 4);
    DialogItemRadioButtonGroupSetValPtr(radio, &dd->slide_mode);
 
-   di = DialogAddItem(table, DITEM_NONE);
+   DialogAddItem(table, DITEM_NONE);
 
    di = DialogAddItem(table, DITEM_TEXT);
    DialogItemSetFill(di, 0, 0);
@@ -468,7 +471,7 @@ const DialogDef     DlgPlacement = {
    N_("Window Placement Settings"),
    SOUND_SETTINGS_PLACEMENT,
    "pix/place.png",
-   N_("Enlightenment Window Placement\n" "Settings Dialog\n"),
+   N_("Enlightenment Window Placement\n" "Settings Dialog"),
    _DlgFillPlacement,
    DLG_OAC, CB_ConfigurePlacement,
 };
@@ -548,7 +551,7 @@ const DialogDef     DlgMisc = {
    N_("Miscellaneous Settings"),
    SOUND_SETTINGS_MISCELLANEOUS,
    "pix/miscellaneous.png",
-   N_("Enlightenment Miscellaneous\n" "Settings Dialog\n"),
+   N_("Enlightenment Miscellaneous\n" "Settings Dialog"),
    _DlgFillMisc,
    DLG_OAC, CB_ConfigureMiscellaneous,
 };
@@ -685,7 +688,7 @@ const DialogDef     DlgComposite = {
    N_("Composite Settings"),
    SOUND_SETTINGS_COMPOSITE,
    "pix/pager.png",
-   N_("Enlightenment Composite\n" "Settings Dialog\n"),
+   N_("Enlightenment Composite\n" "Settings Dialog"),
    _DlgFillComposite,
    DLG_OAC, CB_ConfigureComposite,
 };
