@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2009 Kim Woelders
+ * Copyright (C) 2004-2010 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -51,7 +51,7 @@ SetupX(const char *dstr)
    if (!dstr)
       dstr = getenv("DISPLAY");
    if (!dstr)
-      dstr = ":0";
+      dstr = ":0.0";
 
    /* Open a connection to the diplay nominated by the DISPLAY variable */
    err = EDisplayOpen(dstr, Dpy.screen);
@@ -125,7 +125,7 @@ SetupX(const char *dstr)
    Dpy.pixel_black = BlackPixel(disp, Dpy.screen);
    Dpy.pixel_white = WhitePixel(disp, Dpy.screen);
 
-   EDisplaySetErrorHandlers(HandleXIOError);
+   EDisplaySetErrorHandlers(EventShowError, HandleXIOError);
 
    /* Root defaults */
    RROOT = ERegisterWindow(DefaultRootWindow(disp), NULL);
@@ -186,6 +186,7 @@ SetupX(const char *dstr)
       KeyCode             nl, sl;
       unsigned int        numlock, scrollock;
       int                 i;
+
       int                 masks[8] = {
 	 ShiftMask, LockMask, ControlMask, Mod1Mask, Mod2Mask, Mod3Mask,
 	 Mod4Mask, Mod5Mask
@@ -232,5 +233,4 @@ SetupX(const char *dstr)
    }
 
    ScreenInit();
-   ZoomInit();
 }
