@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2009 Kim Woelders
+ * Copyright (C) 2004-2010 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -564,7 +564,6 @@ typedef struct {
    char                snap_location;
    char                snap_layer;
    char                snap_sticky;
-   char                snap_icon;
    char                snap_shaded;
    char                snap_cmd;
    char                snap_group;
@@ -707,11 +706,11 @@ _DlgFillSnap(Dialog * d, DItem * table, void *data)
 	  {
 	     sd->match.name = 1;
 	     sd->match.clss = 1;
-	     sd->match.role = ewin->icccm.wm_role != NULL;
+	     sd->match.role = ! !ewin->icccm.wm_role;
 	  }
 	else
 	  {
-	     sd->match.title = EwinGetIcccmName(ewin) != NULL;
+	     sd->match.title = ! !EwinGetIcccmName(ewin);
 	  }
      }
 
@@ -783,7 +782,6 @@ _DlgFillSnap(Dialog * d, DItem * table, void *data)
 	     int                 i = 0, slice, last;
 
 	     s[0] = 0;
-	     slice = 64;
 	     while ((i <= (int)strlen(ewin->icccm.wm_command))
 		    && (i < (int)(sizeof(s) / 4)))
 	       {
@@ -1065,7 +1063,7 @@ const DialogDef     DlgRemember = {
    N_("Remembered Windows Settings"),
    SOUND_SETTINGS_PAGER,
    "pix/snapshots.png",
-   N_("Enlightenment Remembered\n" "Windows Settings Dialog\n"),
+   N_("Enlightenment Remembered\n" "Windows Settings Dialog"),
    _DlgFillRemember,
    DLG_OC, CB_ApplyRemember,
 };
@@ -1159,7 +1157,7 @@ SnapshotsSaveReal(void *data __UNUSED__)
       Eprintf("SnapshotsSaveReal: %s\n", buf);
    E_mv(s, buf);
    if (!isfile(buf))
-      Alert(_("Error saving snaps file\n"));
+      Alert(_("Error saving snaps file"));
 
    GroupsSave();
 
@@ -1185,24 +1183,16 @@ SnapshotsSpawn(void)
 }
 
 /* load all snapped info */
-void
-SnapshotsLoad(void)
+static int
+_SnapshotsLoad(FILE * fs)
 {
    Snapshot           *sn = NULL;
    char                buf[4096], *s;
-   FILE               *f;
    int                 res_w, res_h, a, b, c, d;
 
-   GroupsLoad();
-
-   Esnprintf(buf, sizeof(buf), "%s.snapshots", EGetSavePrefix());
-   f = fopen(buf, "r");
-   if (!f)
-      return;
-
    res_w = WinGetW(VROOT);
    res_h = WinGetH(VROOT);
-   while (fgets(buf, sizeof(buf), f))
+   while (fgets(buf, sizeof(buf), fs))
      {
 	s = strchr(buf, ':');
 	if (!s)
@@ -1391,7 +1381,20 @@ SnapshotsLoad(void)
 #endif
 	  }
      }
-   fclose(f);
+
+   return 0;
+}
+
+void
+SnapshotsLoad(void)
+{
+   char                s[4096];
+
+   GroupsLoad();
+
+   Esnprintf(s, sizeof(s), "%s.snapshots", EGetSavePrefix());
+
+   ConfigFileLoad(s, NULL, _SnapshotsLoad, 0);
 }
 
 /* make a client window conform to snapshot info */
@@ -1499,7 +1502,7 @@ SnapshotEwinUnmatch(EWin * ewin)
    Snapshot           *sn;
 
    sn = ewin->snap;
-   if (sn == NULL)
+   if (!sn)
       return;
 
    ewin->snap = NULL;
@@ -1598,7 +1601,7 @@ static void
 _SnapShow(void *data, void *prm)
 {
    Snapshot           *sn = (Snapshot *) data;
-   int                 full = prm != NULL;
+   int                 full = ! !prm;
    char                buf[FILEPATH_LEN_MAX];
    const char         *name;
 
