@@ -58,14 +58,10 @@ TextstateCreate(const char *font)
    if (!ts)
       return NULL;
 
-   ts->style.mode = MODE_WRAP_CHAR;
    ts->style.orientation = FONT_TO_RIGHT;
 
    if (font)
-     {
-	ts->fontname = TextstateFontLookup(font);
-	ts->style.mode = MODE_VERBATIM;
-     }
+      ts->fontname = TextstateFontLookup(font);
 
    return ts;
 }
@@ -122,8 +118,7 @@ TextclassDestroy(TextClass * tc)
 {
    if (tc->ref_count > 0)
      {
-	DialogOK("TextClass Error!", _("%u references remain\n"),
-		 tc->ref_count);
+	DialogOK("TextClass Error!", _("%u references remain"), tc->ref_count);
 	return;
      }
    Efree(tc->name);
@@ -333,9 +328,6 @@ TextclassConfigLoad(FILE * fs)
 	  case TEXT_ORIENTATION:
 	     ts->style.orientation = atoi(s2);
 	     continue;
-	  case TEXT_MODE:
-	     ts->style.mode = atoi(s2);
-	     continue;
 	  case TEXT_EFFECT:
 	     ts->style.effect = atoi(s2);
 	     continue;
@@ -503,6 +495,7 @@ static const IpcItem TextclassIpcArray[] = {
  * Module descriptor
  */
 extern const EModule ModTextclass;
+
 const EModule       ModTextclass = {
    "textclass", "tc",
    NULL,
