@@ -48,6 +48,7 @@
 #define DEBUG_PIXMAP 0
 
 EDisplay            Dpy;
+Display            *disp;
 
 #if USE_COMPOSITE
 static Visual      *argb_visual = NULL;
@@ -185,6 +186,7 @@ EXidSet(Window xwin, Win parent, int x, int y, int w, int h, int depth,
    win->depth = depth;
    win->visual = visual;
    win->cmap = cmap;
+   win->argb = depth == 32;
 #if DEBUG_XWIN
    Eprintf("EXidSet: %#lx\n", win->xwin);
 #endif
@@ -362,7 +364,7 @@ ECreateArgbWindow(Win parent, int x, int y, int w, int h, Win cwin)
 }
 
 #if USE_GLX
-Win
+static              Win
 ECreateWindowVD(Win parent, int x, int y, int w, int h,
 		Visual * vis, unsigned int depth)
 {
@@ -403,11 +405,8 @@ ECreateObjectWindow(Win parent, int x, int y, int w, int h, int saveunder,
 	break;
 #if USE_GLX
      case WIN_TYPE_GLX:	/* Internal GL */
-	argb = 1;
 	win =
 	   ECreateWindowVD(parent, x, y, w, h, EGlGetVisual(), EGlGetDepth());
-	if (win)
-	   win->argb = 1;
 	return win;
 #endif
      }
@@ -416,7 +415,6 @@ ECreateObjectWindow(Win parent, int x, int y, int w, int h, int saveunder,
       win = ECreateArgbWindow(parent, x, y, w, h, cwin);
    else
       win = ECreateWindow(parent, x, y, w, h, saveunder);
-   win->argb = argb;
 #else
    win = ECreateWindow(parent, x, y, w, h, saveunder);
    type = 0;
@@ -577,7 +575,7 @@ EDestroyWindow(Win win)
       return;
 
 #if DEBUG_XWIN
-   Eprintf("ExDestroyWindow: %p %#lx\n", win, win->xwin);
+   Eprintf("EDestroyWindow: %p %#lx\n", win, win->xwin);
 #endif
    if (win->parent != None)
      {
@@ -686,6 +684,9 @@ ECreateWinFromXwin(Window xwin)
    win->depth = depth;
    win->visual = WinGetVisual(VROOT);
    win->cmap = WinGetCmap(VROOT);
+#if DEBUG_XWIN
+   Eprintf("EXidWFX: %p %#lx\n", win, win->xwin);
+#endif
 
    return win;
 }
@@ -793,8 +794,8 @@ EReparentWindow(Win win, Win parent, int x, int y)
 #if 0
    Eprintf
       ("EReparentWindow: %p %#lx: %d %#lx->%#lx %d,%d %dx%d -> %d,%d\n",
-       win, win->xwin, win->mapped, win->parent, parent->xwin,
-       win->x, win->y, win->w, win->h, x, y);
+       win, win->xwin, win->mapped, (win->parent) ? win->parent->xwin : None,
+       parent->xwin, win->x, win->y, win->w, win->h, x, y);
 #endif
    if (parent == win->parent)
      {
@@ -1137,7 +1138,7 @@ EXWarpPointer(Window xwin, int x, int y)
    XWarpPointer(disp, None, xwin, 0, 0, 0, 0, x, y);
 }
 
-static              Bool
+Bool
 EXQueryPointer(Window xwin, int *px, int *py, Window * pchild,
 	       unsigned int *pmask)
 {
@@ -1699,22 +1700,25 @@ int
 EDisplayOpen(const char *dstr, int scr)
 {
    char                dbuf[256], *s;
+   unsigned int        ddpy, dscr;
 
-   if (scr >= 0)
-     {
-	/* Override screen */
-	Esnprintf(dbuf, sizeof(dbuf) - 10, "%s", dstr);
-	s = strchr(dbuf, ':');
-	if (s)
-	  {
-	     s = strchr(s, '.');
-	     if (s)
-		*s = '\0';
-	  }
-	Esnprintf(dbuf + strlen(dbuf), 10, ".%d", scr);
-	dstr = dbuf;
-     }
+   if (!dstr)
+      goto do_open;
 
+   Esnprintf(dbuf, sizeof(dbuf), "%s", dstr);
+   s = strchr(dbuf, ':');
+   if (!s)
+      return -1;
+   s++;
+
+   ddpy = dscr = 0;
+   sscanf(s, "%u.%u", &ddpy, &dscr);
+   if (scr >= 0)		/* Override screen */
+      dscr = scr;
+   Esnprintf(s, sizeof(dbuf) - (s - dbuf), "%u.%u", ddpy, dscr);
+   dstr = dbuf;
+
+ do_open:
 #ifdef USE_ECORE_X
    ecore_x_init(dstr);
    disp = ecore_x_display_get();
@@ -1756,26 +1760,20 @@ EDisplayDisconnect(void)
    disp = NULL;
 }
 
-static int
-HandleXError(Display * dpy, XErrorEvent * ev)
-{
-   char                buf[64];
+static EXErrorHandler *EXErrorFunc = NULL;
+static EXIOErrorHandler *EXIOErrorFunc = NULL;
 
-   if (EDebug(1))
-     {
-	XGetErrorText(dpy, ev->error_code, buf, 63);
-	Eprintf("*** ERROR: xid=%#lx error=%i req=%i/%i: %s\n",
-		ev->resourceid, ev->error_code,
-		ev->request_code, ev->minor_code, buf);
-     }
+static int
+HandleXError(Display * dpy __UNUSED__, XErrorEvent * ev)
+{
+   if (EDebug(1) && EXErrorFunc)
+      EXErrorFunc(ev);
 
    Dpy.last_error_code = ev->error_code;
 
    return 0;
 }
 
-static void         (*EXIOErrorFunc) (void) = NULL;
-
 static int
 HandleXIOError(Display * dpy __UNUSED__)
 {
@@ -1788,9 +1786,10 @@ HandleXIOError(Display * dpy __UNUSED__)
 }
 
 void
-EDisplaySetErrorHandlers(void (*fatal) (void))
+EDisplaySetErrorHandlers(EXErrorHandler * error, EXIOErrorHandler * fatal)
 {
    /* set up an error handler for then E would normally have fatal X errors */
+   EXErrorFunc = error;
    XSetErrorHandler(HandleXError);
 
    /* set up a handler for when the X Connection goes down */
@@ -1957,19 +1956,19 @@ EWindowGetPixmap(const Win win)
 #define _G(x) (((x) >>  8) & 0xff)
 #define _B(x) (((x)      ) & 0xff)
 
-#if 0
 Picture
-EPictureCreate(Window win, int depth, Visual * vis)
+EPictureCreate(Win win, Drawable draw)
 {
    Picture             pict;
    XRenderPictFormat  *pictfmt;
 
-   pictfmt = XRenderFindVisualFormat(disp, vis);
-   pict = XRenderCreatePicture(disp, win, pictfmt, 0, 0);
+   if (!win)
+      win = VROOT;
+   pictfmt = XRenderFindVisualFormat(disp, WinGetVisual(win));
+   pict = XRenderCreatePicture(disp, draw, pictfmt, 0, 0);
 
    return pict;
 }
-#endif
 
 Picture
 EPictureCreateSolid(Window xwin, int argb, unsigned int a, unsigned int rgb)
@@ -2017,6 +2016,12 @@ EPictureCreateBuffer(Win win, int w, int h, Pixmap * ppmap)
    return pict;
 }
 
+void
+EPictureDestroy(Picture pict)
+{
+   XRenderFreePicture(disp, pict);
+}
+
 void
 EPictureSetClip(Picture pict, XserverRegion clip)
 {
@@ -2174,6 +2179,22 @@ ERegionSubtract(XserverRegion dst, XserverRegion src)
    XFixesSubtractRegion(disp, dst, dst, src);
 }
 
+void
+ERegionIntersectOffset(XserverRegion dst, int dx, int dy, XserverRegion src,
+		       XserverRegion tmp)
+{
+   Display            *dpy = disp;
+   XserverRegion       rgn;
+
+   rgn = src;
+   if (dx != 0 || dy != 0)
+     {
+	rgn = ERegionCopy(tmp, src);
+	XFixesTranslateRegion(dpy, rgn, dx, dy);
+     }
+   XFixesIntersectRegion(dpy, dst, dst, rgn);
+}
+
 void
 ERegionSubtractOffset(XserverRegion dst, int dx, int dy, XserverRegion src,
 		      XserverRegion tmp)
