@@ -29,7 +29,6 @@
 #include "xtypes.h"
 
 typedef struct {
-   Display            *disp;
    char               *name;
    int                 screens;
    int                 screen;
@@ -45,8 +44,8 @@ typedef struct {
 } EDisplay;
 
 __EXPORT__ extern EDisplay Dpy;
+__EXPORT__ extern Display *disp;
 
-#define disp  Dpy.disp
 #define RROOT Dpy.rroot
 #define VROOT Dpy.vroot
 
@@ -55,7 +54,11 @@ void                EXInit(void);
 int                 EDisplayOpen(const char *dstr, int scr);
 void                EDisplayClose(void);
 void                EDisplayDisconnect(void);
-void                EDisplaySetErrorHandlers(void (*fatal) (void));
+
+typedef void        (EXErrorHandler) (const XErrorEvent *);
+typedef void        (EXIOErrorHandler) (void);
+void                EDisplaySetErrorHandlers(EXErrorHandler * error,
+					     EXIOErrorHandler * fatal);
 
 void                EGrabServer(void);
 void                EUngrabServer(void);
@@ -128,6 +131,7 @@ Win                 ELookupXwin(Window xwin);
 #define             WinGetDepth(win)		((win)->depth)
 #define             WinGetVisual(win)		((win)->visual)
 #define             WinGetCmap(win)		((win)->cmap)
+#define             WinGetNumRect(win)		((win)->num_rect)
 #define             WinIsMapped(win)		((win)->mapped != 0)
 #define             WinIsShaped(win)		((win)->num_rect != 0)
 
@@ -147,8 +151,6 @@ Win                 ECreateWindow(Win parent, int x, int y, int w, int h,
 				  int saveunder);
 Win                 ECreateArgbWindow(Win parent, int x, int y, int w, int h,
 				      Win cwin);
-Win                 ECreateWindowVD(Win parent, int x, int y, int w, int h,
-				    Visual * vis, unsigned int depth);
 Win                 ECreateClientWindow(Win parent, int x, int y, int w, int h);
 
 #define WIN_TYPE_CLIENT     0
@@ -222,6 +224,8 @@ Pixmap              EWindowGetShapePixmapInverted(Win win);
 
 Bool                EQueryPointer(Win win, int *px, int *py,
 				  Window * pchild, unsigned int *pmask);
+Bool                EXQueryPointer(Window xwin, int *px, int *py,
+				   Window * pchild, unsigned int *pmask);
 
 unsigned int        EAllocColor(Colormap cmap, unsigned int argb);
 
@@ -278,12 +282,14 @@ Atom                EInternAtom(const char *name);
 
 typedef struct {
    char                type;
+   char                depth;
    Pixmap              pmap;
    Pixmap              mask;
-   int                 w, h;
+   unsigned short      w, h;
 } PmapMask;
 
-void                FreePmapMask(PmapMask * pmm);
+void                PmapMaskInit(PmapMask * pmm, Win win, int w, int h);
+void                PmapMaskFree(PmapMask * pmm);
 
 #if USE_COMPOSITE
 #include <X11/extensions/Xfixes.h>
@@ -304,8 +310,11 @@ void                ERegionSetRect(XserverRegion rgn, int x, int y, int w,
 				   int h);
 void                ERegionTranslate(XserverRegion rgn, int dx, int dy);
 void                ERegionIntersect(XserverRegion dst, XserverRegion src);
-void                ERegionUnion(XserverRegion dst, XserverRegion src);
 void                ERegionSubtract(XserverRegion dst, XserverRegion src);
+void                ERegionUnion(XserverRegion dst, XserverRegion src);
+void                ERegionIntersectOffset(XserverRegion dst, int dx, int dy,
+					   XserverRegion src,
+					   XserverRegion tmp);
 void                ERegionSubtractOffset(XserverRegion dst, int dx, int dy,
 					  XserverRegion src, XserverRegion tmp);
 void                ERegionUnionOffset(XserverRegion dst, int dx, int dy,
@@ -317,12 +326,12 @@ void                ERegionShow(const char *txt, XserverRegion rgn,
 				void (*prf) (const char *fmt, ...));
 
 #include <X11/extensions/Xrender.h>
-#if 0
-Picture             EPictureCreate(Window win, int depth, Visual * vis);
-#endif
+
+Picture             EPictureCreate(Win win, Drawable draw);
 Picture             EPictureCreateSolid(Window xwin, int argb,
 					unsigned int a, unsigned int rgb);
 Picture             EPictureCreateBuffer(Win win, int w, int h, Pixmap * ppmap);
+void                EPictureDestroy(Picture pict);
 void                EPictureSetClip(Picture pict, XserverRegion clip);
 
 Pixmap              EWindowGetPixmap(const Win win);
